@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/admin/datatree.php,v 1.7.2.1 2005/01/03 12:25:29 jan Exp $
+ * $Horde: horde/admin/datatree.php,v 1.7.2.4 2006/02/01 09:30:46 selsky Exp $
  *
- * Copyright 2004-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2004-2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -68,7 +68,7 @@ require HORDE_TEMPLATES . '/admin/common-header.inc';
 $notification->notify();
 $tree->renderTree();
 if ($show) {
-    echo '<br /><div class="text" style="white-space:pre"><a name="show"></a>';
+    echo '<br /><div class="text" style="white-space:pre"><a id="show"></a>';
     print_r($data);
     print_r($attributes);
     echo '</div>';
