@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/admin/groups.php,v 1.50.2.5 2006/01/01 21:28:05 jan Exp $
+ * $Horde: horde/admin/groups.php,v 1.50.2.6 2006/07/13 09:01:53 jan Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -54,7 +54,7 @@ case 'addchildform':
         $notification->push(sprintf(_("\"%s\" was not created: %s."), $child->getShortName(), $result->getMessage()), 'horde.error');
     } else {
         $notification->push(sprintf(_("\"%s\" was added to the groups system."), $child->getShortName()), 'horde.success');
-        $group = &$child;
+        $group = $child;
         $form = 'edit.inc';
         $reload = true;
     }
@@ -150,7 +150,6 @@ case 'editform':
 }
 
 switch ($form) {
-
 case 'addchild.inc':
     $notification->push('document.add_child.child.focus()', 'javascript');
     break;
@@ -162,6 +161,13 @@ case 'edit.inc':
         $notification->push($users, 'horde.error');
         $users = array();
     }
+    $all_users = $group->listAllUsers();
+    if (is_a($all_users, 'PEAR_Error')) {
+        $notification->push($all_users, 'horde.error');
+        $all_users = array();
+    }
+    $inherited_users = array_diff($all_users, $users);
+
     if ($auth->hasCapability('list')) {
         $user_list = $auth->listUsers();
         if (is_a($user_list, 'PEAR_Error')) {
@@ -181,7 +187,7 @@ require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/admin/common-header.inc';
 $notification->notify(array('listeners' => 'status'));
 if (!empty($form)) {
-    include HORDE_TEMPLATES . '/admin/groups/' . $form;
+    require HORDE_TEMPLATES . '/admin/groups/' . $form;
 }
 
 /* Get the perms tree. */
@@ -199,7 +205,7 @@ $edit_img = Horde::img('edit.png', _("Edit Group"));
 $delete_img = Horde::img('delete.png', _("Delete Group"));
 
 /* Set up the tree. */
-$tree = &Horde_Tree::singleton('admin_groups', 'javascript');
+$tree = Horde_Tree::factory('admin_groups', 'javascript');
 $tree->setOption(array('alternate' => true, 'hideHeaders' => true));
 $tree->setHeader(array(array('width' => '50%')));
 
@@ -213,24 +219,25 @@ if ($cid > 0) {
 }
 
 foreach ($nodes as $id => $node) {
-    $node_class = ($cid == $id) ? array('class' => 'selected') : array();
+    $node_params = ($cid == $id) ? array('class' => 'selected') : array();
     if ($id == DATATREE_ROOT) {
         $add_img = Horde::img('group.png', _("Add New Group"));
         $add_link = Horde::link(Util::addParameter($add, 'cid', $id), _("Add New Group")) . $add_img . '</a>';
 
         $base_node_params = $icondir + array('icon' => 'administration.png');
-        $tree->addNode($id, null, _("All Groups"), 0, true, $base_node_params + $node_class, array($spacer, $add_link));
+        $tree->addNode($id, null, _("All Groups"), 0, true, $base_node_params + $node_params, array($spacer, $add_link));
     } else {
+        $node_params['url'] = Util::addParameter($edit, 'cid', $id);
         $add_img = Horde::img('group.png', _("Add Child Group"));
         $add_link = Horde::link(Util::addParameter($add, 'cid', $id), _("Add Child Group")) . $add_img . '</a>';
-        $edit_link = Horde::link(Util::addParameter($edit, 'cid', $id), _("Edit Group")) . $edit_img . '</a>';
         $delete_link = Horde::link(Util::addParameter($delete, 'cid', $id), _("Delete Group")) . $delete_img . '</a>';
 
         $parent_id = $groups->getGroupParent($id);
-        $group_extra = array($spacer, $add_link, $edit_link, $delete_link);
-        $tree->addNode($id, $parent_id, $groups->getGroupShortName($node), $groups->getLevel($id) + 1, (isset($cid_parents[$id])) ? true : false, $group_node + $node_class, $group_extra);
+        $group_extra = array($spacer, $add_link, $delete_link);
+        $tree->addNode($id, $parent_id, $groups->getGroupShortName($node), $groups->getLevel($id) + 1, (isset($cid_parents[$id])) ? true : false, $group_node + $node_params, $group_extra);
     }
 }
 
+echo '<h1 class="header">' . Horde::img('group.png') . ' ' . _("Groups") . '</h1>';
 $tree->renderTree();
 require HORDE_TEMPLATES . '/common-footer.inc';
