@@ -1,11 +1,12 @@
 <?php
 /**
- * $Horde: horde/admin/perms/index.php,v 1.10.10.1 2005/01/03 12:25:29 jan Exp $
+ * $Horde: horde/admin/perms/index.php,v 1.10.10.3 2006/01/01 21:28:05 jan Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2005-2006 Jan Schneider <jan@horde.org>
  *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you did
+ * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
 @define('HORDE_BASE', dirname(__FILE__) . '/../..');
@@ -16,8 +17,7 @@ if (!Auth::isAdmin()) {
     Horde::authenticationFailureRedirect();
 }
 
-$form = null;
-$cid = Util::getFormData('cid');
+$perm_id = Util::getFormData('perm_id');
 
 $title = _("Permissions Administration");
 require HORDE_TEMPLATES . '/common-header.inc';
@@ -26,6 +26,6 @@ $notification->notify(array('listeners' => 'status'));
 
 require_once 'Horde/Perms/UI.php';
 $ui = &new Perms_UI($perms);
-$ui->renderTree($cid);
+$ui->renderTree($perm_id);
 
 require HORDE_TEMPLATES . '/common-footer.inc';
