@@ -1,14 +1,14 @@
 <?php
 /**
- * $Horde: horde/admin/phpshell.php,v 1.24.10.1 2005/01/03 12:25:29 jan Exp $
+ * $Horde: horde/admin/phpshell.php,v 1.24.10.8 2006/02/24 22:48:29 chuck Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
-define('HORDE_BASE', dirname(__FILE__) . '/..');
+@define('HORDE_BASE', dirname(__FILE__) . '/..');
 require_once HORDE_BASE . '/lib/base.php';
 require_once 'Horde/Menu.php';
 require_once 'Horde/Help.php';
@@ -21,16 +21,22 @@ $title = _("PHP Shell");
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/admin/common-header.inc';
 
-$apps = $registry->listApps();
+$apps_tmp = $registry->listApps();
+$apps = array();
+foreach ($apps_tmp as $app) {
+    $apps[$app] = $registry->get('name', $app);
+}
+asort($apps);
 $application = Util::getFormData('app', 'horde');
 ?>
+<div style="padding:10px">
 <form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="post">
 <?php Util::pformInput() ?>
 
-<table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td class="header"><?php echo _("Application") ?></td></tr></table>
+<h1 class="header"><?php echo _("Application") ?></h1><br />
 <select name="app">
-<?php foreach ($apps as $app): ?>
-  <option value="<?php echo $app ?>"<?php if ($application == $app) echo ' selected="selected"' ?>><?php echo $registry->get('name', $app) ?></option>
+<?php foreach ($apps as $app => $name): ?>
+  <option value="<?php echo $app ?>"<?php if ($application == $app) echo ' selected="selected"' ?>><?php echo $name ?></option>
 <?php endforeach; ?>
 </select><br /><br />
 <?php
@@ -44,39 +50,40 @@ if ($command = trim(Util::getFormData('php'))) {
 
     require_once 'Horde/MIME/Viewer.php';
     require_once 'Horde/MIME/Viewer/source.php';
-    $pretty = highlight_string('<?php ' . $command . "\n", true);
-    $pretty = str_replace(array('&lt;?php',
+    $pretty = highlight_string('<?php ' . $command, true);
+    $pretty = str_replace(array('&lt;?php ',
+                                '<font color="#000000"><font color="#007700">&lt;?</font><font color="#0000BB">php </font>',
                                 "\r\n",
                                 "\r",
-                                "<code><font color=\"#000000\">\n",
-                                "\n</code>",
-                                "\n</font></code>"),
+                                "\n",
+                                '<br />'),
                           array('',
-                                "\n",
-                                "\n",
-                                '<code><font color="#000000">',
-                                '</code>',
-                                '</font></code>'),
+                                '',
+                                '',
+                                '',
+                                '',
+                                "\n"),
                           $pretty);
     $pretty = MIME_Viewer_Source::lineNumber(trim($pretty));
 
-    echo '<table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td class="header">' . _("PHP Code") . '</td></tr></table><br />';
+    echo '<h1 class="header">' . _("PHP Code") . '</h1><br />';
     echo $pretty;
 
-    echo '<br /><table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td class="header">' . _("Results") . '</td></tr></table>';
-    echo '<table cellpadding="4" border="0"><tr><td class="text"><pre>';
+    echo '<br /><h1 class="header">' . _("Results") . '</h1><br />';
+    echo '<pre class="text">';
     eval($command);
-    echo '</pre></td></tr></table><br />';
+    echo '</pre><br />';
 }
 ?>
 
 <textarea class="fixed" name="php" rows="10" cols="60">
 <?php if (!empty($command)) echo htmlspecialchars($command) ?></textarea>
 <br />
-<input type="submit" class="button" value="<?php echo _("Execute") ?>">
+<input type="submit" class="button" value="<?php echo _("Execute") ?>" />
 <?php echo Help::link('admin', 'admin-phpshell') ?>
 
 </form>
+</div>
 <?php
 
 require HORDE_TEMPLATES . '/common-footer.inc';
