@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: horde/admin/setup/index.php,v 1.28.4.3 2005/01/31 09:28:27 jan Exp $
+ * $Horde: horde/admin/setup/index.php,v 1.28.4.12 2006/03/28 12:31:08 jan Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -45,7 +45,7 @@ function _uploadFTP($params)
     $params['hostspec'] = 'localhost';
     $vfs = &VFS::singleton('ftp', $params);
     if (is_a($vfs, 'PEAR_Error')) {
-        $notification->push(sprintf(_("Could not connect to server '%s' using FTP: %s"), $params['hostspec'], $vfs->getMessage()), 'horde.error');
+        $notification->push(sprintf(_("Could not connect to server \"%s\" using FTP: %s"), $params['hostspec'], $vfs->getMessage()), 'horde.error');
         return false;
     }
 
@@ -67,12 +67,13 @@ function _uploadFTP($params)
         $write = $vfs->writeData($path, 'conf.php', $config);
         if (is_a($write, 'PEAR_Error')) {
             $no_errors = false;
-            $notification->push(sprintf(_("Could not write configuration for '%s': %s"), $app, $write->getMessage()), 'horde.error');
+            $notification->push(sprintf(_("Could not write configuration for \"%s\": %s"), $app, $write->getMessage()), 'horde.error');
         } else {
-            $notification->push(sprintf(_("Successfully wrote %s"), $path . '/conf.php'), 'horde.success');
+            $notification->push(sprintf(_("Successfully wrote %s"), Util::realPath($path . '/conf.php')), 'horde.success');
             unset($_SESSION['_config'][$app]);
         }
     }
+    $registry->clearCache();
     return $no_errors;
 }
 
@@ -96,12 +97,20 @@ foreach ($a as $app) {
     $path = $registry->get('fileroot', $app) . '/config';
 
     $conf_link = Util::addParameter($conf_url, 'app', $app);
-    $conf_link = Horde::link($conf_link, sprintf(_("Configure %s"), $app), '', '', '', sprintf(_("Configure %s"), $app));
+    $conf_link = Horde::link($conf_link, sprintf(_("Configure %s"), $app));
     $apps[$i]['sort'] = $registry->get('name', $app) . ' (' . $app . ')';
     $apps[$i]['name'] = $conf_link . $apps[$i]['sort'] . '</a>';
+    $apps[$i]['version'] = '';
+    if (is_readable($registry->get('fileroot', $app) . '/lib/version.php')) {
+        require $registry->get('fileroot', $app) . '/lib/version.php';
+        $version_constant = String::upper($app) . '_VERSION';
+        if (defined($version_constant)) {
+            $apps[$i]['version'] = constant($version_constant);
+        }
+    }
     if (!file_exists($path . '/conf.php')) {
         /* No conf.php exists. */
-        $apps[$i]['conf'] = $conf_link . $error;
+        $apps[$i]['conf'] = $conf_link . $error . '</a>';
         $apps[$i]['status'] = _("Missing configuration. You have to generate it now if you want to use this application.");
     } else {
         /* A conf.php exists, get the xml version. */
@@ -120,9 +129,9 @@ foreach ($a as $app) {
         }
 
         if ($xml_ver != $php_ver) {
-            /* Versions are not the same, configuration needs updating. */
+            /* Versions are not the same, configuration is out of date. */
             $apps[$i]['conf'] = $conf_link . $error . '</a>';
-            $apps[$i]['status'] = _("Configuration needs updating.");
+            $apps[$i]['status'] = _("Configuration is out of date.");
             continue;
         } else {
             /* Configuration is ok. */
@@ -135,10 +144,6 @@ foreach ($a as $app) {
 /* Sort the apps by name. */
 require_once 'Horde/Array.php';
 Horde_Array::arraySort($apps, 'sort');
-$i = 0;
-foreach (array_keys($apps) as $app) {
-    $apps[$app]['class'] = ($i++ % 2) ? 'item1' : 'item0';
-}
 
 /* Set up any actions that may be offered. */
 $actions = array();
@@ -148,19 +153,19 @@ if (!empty($_SESSION['_config'])) {
     $url = Horde::applicationUrl('admin/setup/diff.php');
     $action = _("Show differences between currently saved and the newly generated configuration.");
     $actions[] = array('icon' => Horde::img('search.png', '', 'align="middle"', $registry->getImageDir('horde')),
-                       'link' => Horde::link('', $action, '', '', 'popup(\'' . $url . '\',640, 480); return false;') . $action . '</a>');
+                       'link' => Horde::link('#', '', '', '', 'popup(\'' . $url . '\',640, 480); return false;') . $action . '</a>');
 
     $url = Horde::applicationUrl('admin/setup/scripts.php');
     /* Action to download the configuration upgrade PHP script. */
     $url = Util::addParameter($url, array('setup' => 'conf', 'type' => 'php'));
     $action = _("Download generated configuration as PHP script.");
     $actions[] = array('icon' => Horde::img('download.png', '', 'align="middle"', $registry->getImageDir('horde')),
-                       'link' => Horde::link($url, $action, '', '', '', $action) . $action . '</a>');
+                       'link' => Horde::link($url) . $action . '</a>');
     /* Action to save the configuration upgrade PHP script. */
     $url = Util::addParameter($url, 'save', 'tmp');
     $action = _("Save generated configuration as a PHP script to your server's temporary directory.");
     $actions[] = array('icon' => Horde::img('save.png', '', 'align="middle"', $registry->getImageDir('horde')),
-                       'link' => Horde::link($url, $action, '', '', '', $action) . $action . '</a>');
+                       'link' => Horde::link($url) . $action . '</a>');
 
     /* Set up the form for FTP upload of scripts. */
     require_once 'Horde/Form.php';
@@ -195,7 +200,7 @@ if (file_exists(Horde::getTempDir() . '/horde_setup_upgrade.php')) {
     $url = Util::addParameter($url, 'clean', 'tmp');
     $action = _("Remove saved script from server's temporary directory.");
     $actions[] = array('icon' => Horde::img('delete.png', '', 'align="middle"', $registry->getImageDir('horde')),
-                       'link' => Horde::link($url, $action, '', '', '', $action) . $action . '</a>');
+                       'link' => Horde::link($url) . $action . '</a>');
 }
 
 /* Set up the template. */
@@ -207,6 +212,7 @@ $template->set('notify', Util::bufferOutput(array($notification, 'notify')));
 $template->setOption('gettext', true);
 
 $title = sprintf(_("%s Setup"), $registry->get('name', 'horde'));
+Horde::addScriptFile('stripe.js', 'horde', true);
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/admin/common-header.inc';
 echo $template->fetch(HORDE_TEMPLATES . '/admin/setup/index.html');
