@@ -4,7 +4,7 @@
  * of PHP upgrade scripts for conf.php files either as download or saved to the
  * server's temporary directory.
  *
- * $Horde: horde/admin/setup/scripts.php,v 1.9.10.5 2006/01/19 18:04:00 slusarz Exp $
+ * $Horde: horde/admin/setup/scripts.php,v 1.9.10.6 2006/06/16 08:24:27 jan Exp $
  *
  * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -47,7 +47,7 @@ $data = '';
 if ($setup == 'conf' && $type == 'php') {
     /* A bit ugly here, save PHP code into a string for creating the script
      * to be run at the command prompt. */
-    $data = '#!/usr/local/bin/php' . "\n";
+    $data = '#!/usr/bin/php' . "\n";
     $data .= '<?php' . "\n";
     foreach ($_SESSION['_config'] as $app => $php) {
         $path = $registry->get('fileroot', $app) . '/config';
