@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/admin/sqlshell.php,v 1.18.10.1 2005/01/03 12:25:29 jan Exp $
+ * $Horde: horde/admin/sqlshell.php,v 1.18.10.9 2006/02/24 22:48:29 chuck Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -19,30 +19,29 @@ if (!Auth::isAdmin()) {
 }
 
 $title = _("SQL Shell");
+Horde::addScriptFile('stripe.js', 'horde', true);
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/admin/common-header.inc';
 
 ?>
+<div style="padding:10px">
 <form name="sqlshell" action="<?php echo $_SERVER['PHP_SELF'] ?>" method="post">
 <?php Util::pformInput() ?>
 
 <?php
+
+$dbh = &DB::connect($conf['sql']);
+if (is_a($dbh, 'PEAR_Error')) {
+    Horde::fatal($dbh, __FILE__, __LINE__);
+}
+$dbh->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
+
 if (Util::getFormData('list-tables')) {
     $description = 'LIST TABLES';
-    $dbh = &DB::connect($conf['sql']);
-    if (is_a($dbh, 'PEAR_Error')) {
-        $result = $dbh;
-    } else {
-        $result = $dbh->getListOf('tables');
-    }
+    $result = $dbh->getListOf('tables');
 } elseif (Util::getFormData('list-dbs')) {
     $description = 'LIST DATABASES';
-    $dbh = &DB::connect($conf['sql']);
-    if (is_a($dbh, 'PEAR_Error')) {
-        $result = $dbh;
-    } else {
-        $result = $dbh->getListOf('databases');
-    }
+    $result = $dbh->getListOf('databases');
 } elseif ($command = trim(Util::getFormData('sql'))) {
     // Keep a cache of prior queries for convenience.
     if (!isset($_SESSION['_sql_query_cache'])) {
@@ -57,26 +56,21 @@ if (Util::getFormData('list-tables')) {
     }
 
     // Parse out the query results.
-    $dbh = &DB::connect($conf['sql']);
-    if (is_a($dbh, 'PEAR_Error')) {
-        $result = $dbh;
-    } else {
-        $result = $dbh->query(String::convertCharset($command, NLS::getCharset(), $conf['sql']['charset']));
-    }
+    $result = $dbh->query(String::convertCharset($command, NLS::getCharset(), $conf['sql']['charset']));
 }
 
 if (isset($result)) {
     if (isset($command)) {
-        echo '<table cellpadding="2" cellspacing="0" border="0" width="100%"><tr><td class="header">' . _("Query") . '</td></tr><tr><td class="text"><pre>' . htmlspecialchars($command) . '</pre></td></tr></table>';
+        echo '<h1 class="header">' . _("Query") . '</h1><br /><pre class="text">' . htmlspecialchars($command) . '</pre>';
     }
 
-    echo '<table width="100%" cellpadding="2" cellspacing="0" border="0"><tr><td class="header">' . _("Results") . '</td></tr><tr><td>';
+    echo '<h1 class="header">' . _("Results") . '</h1><br />';
 
     if (is_a($result, 'PEAR_Error')) {
-        echo '<pre>'; var_dump($result); echo '</pre>';
+        echo '<pre class="text">'; var_dump($result); echo '</pre>';
     } else {
         if (is_object($result)) {
-            echo '<table border="0" cellpadding="1" cellspacing="1" class="item">';
+            echo '<table cellspacing="1" class="item striped">';
             $first = true;
             $i = 0;
             while ($row = $result->fetchRow(DB_FETCHMODE_ASSOC)) {
@@ -88,33 +82,31 @@ if (isset($result)) {
                     echo '</tr>';
                     $first = false;
                 }
-                echo '<tr class="item' . ($i % 2) . '">';
+                echo '<tr>';
                 foreach ($row as $val) {
                     echo '<td class="fixed">' . (empty($val) ? '&nbsp;' : htmlspecialchars(String::convertCharset($val, $conf['sql']['charset']))) . '</td>';
                 }
                 echo '</tr>';
-                $i++;
             }
             echo '</table>';
         } elseif (is_array($result)) {
-            echo '<table border="0" cellpadding="1" cellspacing="1" class="item">';
+            echo '<table cellspacing="1" class="item striped">';
             $first = true;
-            foreach ($result as $i => $val) {
+            $i = 0;
+            foreach ($result as $val) {
                 if ($first) {
                     echo '<tr><th align="left">' . (isset($description) ? htmlspecialchars($description) : '&nbsp;') . '</th></tr>';
                     $first = false;
                 }
-                echo '<tr class="item' . ($i % 2) . '">';
-                echo '<td class="fixed">' . (empty($val) ? '&nbsp;' : htmlspecialchars(String::convertCharset($val, $conf['sql']['charset']))) . '</td>';
-                echo '</tr>';
+                echo '<tr><td class="fixed">' . (empty($val) ? '&nbsp;' : htmlspecialchars(String::convertCharset($val, $conf['sql']['charset']))) . '</td></tr>';
             }
             echo '</table>';
         } else {
-            echo '<b>' . _("Success") . '</b>';
+            echo '<strong>' . _("Success") . '</strong>';
         }
     }
 
-    echo '</td></tr></table><br />';
+    echo '<br />';
 }
 ?>
 
@@ -130,15 +122,20 @@ if (isset($result)) {
   <br />
 <?php endif; ?>
 
-<textarea class="fixed" name="sql" rows="10" cols="60" wrap="hard">
+<textarea class="fixed" name="sql" rows="10" cols="60">
 <?php if (!empty($command)) echo htmlspecialchars($command) ?></textarea>
 <br />
-<input type="submit" class="button" value="<?php echo _("Execute") ?>">
-<input type="submit" class="button" name="list-tables" value="<?php echo _("List Tables") ?>">
-<input type="submit" class="button" name="list-dbs" value="<?php echo _("List Databases") ?>">
+<input type="submit" class="button" value="<?php echo _("Execute") ?>" />
+<input type="button" class="button" value="<?php echo _("Clear Query") ?>" onclick="document.sqlshell.sql.value=''" />
+<?php if (!empty($command)): ?>
+<input type="reset" class="button" value="<?php echo _("Restore Last Query") ?>" />
+<?php endif; ?>
+<?php if ($dbh->getSpecialQuery('tables') !== null): ?><input type="submit" class="button" name="list-tables" value="<?php echo _("List Tables") ?>" /> <?php endif; ?>
+<?php if ($dbh->getSpecialQuery('databases') !== null): ?><input type="submit" class="button" name="list-dbs" value="<?php echo _("List Databases") ?>" /> <?php endif; ?>
 <?php echo Help::link('admin', 'admin-sqlshell') ?>
 
 </form>
+</div>
 <?php
 
 require HORDE_TEMPLATES . '/common-footer.inc';
