@@ -3,10 +3,10 @@
 $block_name = _("Account Information");
 
 /**
- * $Horde: horde/lib/Block/account.php,v 1.7.2.7 2007/02/02 11:03:22 jan Exp $
+ * $Horde: horde/lib/Block/account.php,v 1.7.2.4 2006/03/10 17:28:44 jan Exp $
  *
- * Copyright 2001-2007 Eric Rostetter <eric.rostetter@physics.utexas.edu>
- * Copyright 2005-2007 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2006 Eric Rostetter <eric.rostetter@physics.utexas.edu>
+ * Copyright 2005-2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -43,7 +43,6 @@ class Horde_Block_Horde_account extends Horde_Block {
             break;
         case 'localhost':
         case 'ldap':
-        case 'kolab':
             $class = 'Accounts_Driver_' . $conf['accounts']['driver'];
             $mydriver = &new $class($conf['accounts']['params']);
             break;
@@ -126,7 +125,7 @@ class Horde_Block_Horde_account extends Horde_Block {
  * Accounts_Driver:: defines an API for getting/displaying account information
  * for a user for the accounts module.
  *
- * Copyright 2001-2007 Eric Rostetter <eric.rostetter@physics.utexas.edu>
+ * Copyright 2001-2006 Eric Rostetter <eric.rostetter@physics.utexas.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -152,7 +151,8 @@ class Accounts_Driver {
      */
     function getUsername()
     {
-        return String::lower(Auth::getBareAuth());
+        $auth = explode('@', Auth::getAuth());
+        return String::lower($auth[0]);
     }
 
     /**
@@ -162,7 +162,8 @@ class Accounts_Driver {
      */
     function getRealm()
     {
-        return (string)Auth::getAuthDomain();
+        $auth = explode('@', Auth::getAuth());
+        return isset($auth[1]) ? $auth[1] : '';
     }
 
     /**
@@ -236,7 +237,7 @@ class Accounts_Driver {
  * local accounts on the local machine.  The exception is the quota support.
  * See that routine for additional comments.
  *
- * Copyright 2002-2007 Eric Jon Rostetter <eric.rostetter@physics.utexas.edu>
+ * Copyright 2002-2006 Eric Jon Rostetter <eric.rostetter@physics.utexas.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -404,7 +405,7 @@ class Accounts_Driver_localhost extends Accounts_Driver {
  * The ldap class attempts to return user information stored in an ldap
  * directory service.
  *
- * Copyright 2001-2007 Eric Rostetter <eric.rostetter@physics.utexas.edu>
+ * Copyright 2001-2006 Eric Rostetter <eric.rostetter@physics.utexas.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -446,16 +447,6 @@ class Accounts_Driver_ldap extends Accounts_Driver {
     }
 
 
-    /**
-     * A wrapper method for anonymous binding.
-     *
-     * @return boolean  False if binding failed.
-     */
-    function _ldapBind()
-    {
-        return @ldap_bind($this->_ds);
-    }
-
     /**
      * Returns the user account from the ldap source.
      *
@@ -486,7 +477,7 @@ class Accounts_Driver_ldap extends Accounts_Driver {
             }
 
             // bind as anonymous
-            $result = $this->_ldapBind();
+            $result = @ldap_bind($this->_ds);
             if (!$result) {
                 return PEAR::raiseError(_("Could not bind to LDAP server."));
             }
@@ -507,18 +498,6 @@ class Accounts_Driver_ldap extends Accounts_Driver {
         return $information;
     }
 
-    /**
-     * Returns the username. Since this method is called for authenticating
-     * in the parent class, we also have the option to NOT strip the domain
-     * name if there is one. This is a configuration checkbox.
-     *
-     * @return string  The username.
-     */
-    function getUsername()
-    {
-        return $this->_params['strip'] ? Auth::getBareAuth() : Auth::getAuth();
-    }
-
     /**
      * Returns the user's full name.
      *
@@ -622,46 +601,3 @@ class Accounts_Driver_ldap extends Accounts_Driver {
     }
 
 }
-
-/**
- * The kolab driver class is merely an extension to the ldap class. It reuses
- * existing Kolab configuration instead of requiring another set of
- * parameters. It also binds using a set internal user (normally this is
- * cn=nobody,cn=internal), so that account information can be fetched even for
- * internal accounts.
- *
- * @author mzizka@hotmail.com
- */
-class Accounts_Driver_kolab extends Accounts_Driver_ldap {
-
-    /**
-     * Constructs a new Accounts_Driver_kolab object. Uses Kolab configuration.
-     *
-     * @param array $params  A hash containing connection parameters.
-     */
-    function Accounts_Driver_kolab($params = array())
-    {
-        $ldap_params = array('host'   => $GLOBALS['conf']['kolab']['ldap']['server'],
-                             'port'   => $GLOBALS['conf']['kolab']['ldap']['port'],
-                             'basedn' => $GLOBALS['conf']['kolab']['ldap']['basedn'],
-                             'phpdn'  => $GLOBALS['conf']['kolab']['ldap']['phpdn'],
-                             'phppw'  => $GLOBALS['conf']['kolab']['ldap']['phppw']);
-        $params = array_merge($ldap_params, $params);
-        parent::Accounts_Driver_ldap($params);
-    }
-
-    /**
-     * Overrides the binding method so it uses the Kolab user instead.
-     * Typically this will be the internal nobody user.
-     *
-     * @return boolean  False if binding failed.
-     */
-    function _ldapBind()
-    {
-        if (!empty($this->_params['phpdn'])) {
-           return @ldap_bind($this->_ds, $this->_params['phpdn'], $this->_params['phppw']);
-        }
-        return parent::_ldapBind();
-    }
-
-}
