@@ -3,11 +3,12 @@
  * Possible strings from weather.com, just to have them in the source for
  * localization reasons.
  *
- * $Horde: horde/lib/Block/weatherdotcom_strings.php,v 1.1.2.5 2006/02/21 10:50:47 jan Exp $
+ * $Horde: horde/lib/Block/weatherdotcom_strings.php,v 1.1.2.6 2006/05/03 17:07:27 jan Exp $
  */
 
 _("AM Clouds");
 _("AM Light Rain");
+_("AM Light Snow");
 _("AM Rain");
 _("AM Showers");
 _("AM Snow Showers");
@@ -19,6 +20,7 @@ _("Fair");
 _("Few Showers");
 _("Few Snow Showers");
 _("Fog");
+_("Freezing Drizzle");
 _("Haze");
 _("Heavy T-Storm");
 _("Isolated T-Storms");
