@@ -7,7 +7,7 @@ include_once 'Horde/Util.php';
  * The Horde:: class provides the functionality shared by all Horde
  * applications.
  *
- * $Horde: framework/Horde/Horde.php,v 1.489.2.44 2006/03/24 00:40:38 chuck Exp $
+ * $Horde: framework/Horde/Horde.php,v 1.489.2.54 2006/07/31 08:49:47 jan Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -288,12 +288,6 @@ HTML;
     {
         global $_horde_script_files, $registry;
 
-        /* If it has been requested in the session to disable javascript,
-         * insert the script to test for it being enabled again. */
-        if (isset($_SESSION['callbacks']['browser.disableJavascript'])) {
-            Horde::addScriptFile('test_javascript.js', 'horde');
-        }
-
         /* If there is no javascript available, there's no point in including
          * the rest of the files. */
         if (!$GLOBALS['browser']->hasFeature('javascript')) {
@@ -596,9 +590,10 @@ HTML;
             $url = $uri;
         }
 
-        if (($append_session == 1) ||
-            (($append_session == 0) &&
-             !isset($_COOKIE[session_name()]))) {
+        if (empty($GLOBALS['conf']['session']['use_only_cookies']) &&
+            (($append_session == 1) ||
+             (($append_session == 0) &&
+              !isset($_COOKIE[session_name()])))) {
             $url = Util::addParameter($url, session_name(), session_id());
         }
 
@@ -629,38 +624,43 @@ HTML;
      */
     function applicationUrl($uri, $full = false, $append_session = 0)
     {
-        global $registry;
-
-        /* Store the webroot in a local variable. */
-        $webroot = $registry->get('webroot');
-
         if ($full) {
             return Horde::url($uri, $full, $append_session);
-        } elseif (substr($webroot, -1) == '/') {
-            return Horde::url($webroot . $uri, $full, $append_session);
-        } else {
-            return Horde::url($webroot . '/' . $uri, $full, $append_session);
         }
+
+        if (substr($uri, 0, 1) != '/') {
+            $webroot = $GLOBALS['registry']->get('webroot');
+            if (substr($webroot, -1) != '/') {
+                $webroot .= '/';
+            }
+            $uri = $webroot . $uri;
+        }
+
+        return Horde::url($uri, $full, $append_session);
     }
 
     /**
-     * Returns an external link passed through the dereferer to strip session
-     * IDs from the referer.
+     * Returns an external link passed through the dereferrer to strip session
+     * IDs from the referrer.
      *
      * @param string $url   The external URL to link to.
      * @param boolean $tag  If true, a complete <a> tag is returned, only the
      *                      url otherwise.
      *
-     * @return string  The correct link to the dereferer script.
+     * @return string  The correct link to the dereferrer script.
      */
     function externalUrl($url, $tag = false)
     {
-        $ext = Horde::url($GLOBALS['registry']->get('webroot', 'horde') .
-                          '/services/go.php', true, -1);
+        if (isset($_COOKIE[session_name()])) {
+            $ext = $url;
+        } else {
+            $ext = Horde::url($GLOBALS['registry']->get('webroot', 'horde') .
+                              '/services/go.php', true, -1);
 
-        /* We must make sure there are no &amp's in the URL. */
-        $url = preg_replace(array('/(=?.*?)&amp;(.*?=)/', '/(=?.*?)&amp;(.*?=)/'), '$1&$2', $url);
-        $ext = Util::addParameter($ext, 'url', $url);
+            /* We must make sure there are no &amp's in the URL. */
+            $url = preg_replace(array('/(=?.*?)&amp;(.*?=)/', '/(=?.*?)&amp;(.*?=)/'), '$1&$2', $url);
+            $ext = Util::addParameter($ext, 'url', $url);
+        }
         if ($tag) {
             $ext = Horde::link($ext, $url, '', '_blank');
         }
@@ -864,13 +864,13 @@ HTML;
     /**
      * Returns a session-id-ified version of $SCRIPT_NAME resp. $PHP_SELF.
      *
-     * @param boolean $query_string  Include any QUERY_STRING?
+     * @param boolean $script_params Include script parameters like QUERY_STRING and PATH_INFO?
      * @param boolean $nocache       Include a nocache parameter in the URL?
      * @param boolean $full          Return a full URL?
      *
      * @return string  The requested URI.
      */
-    function selfUrl($query_string = false, $nocache = true, $full = false,
+    function selfUrl($script_params = false, $nocache = true, $full = false,
                      $force_ssl = false)
     {
         if (substr(php_sapi_name(), 0, 3) == 'cgi') {
@@ -884,8 +884,13 @@ HTML;
                 $_SERVER['PHP_SELF'];
         }
 
-        if ($query_string && !empty($_SERVER['QUERY_STRING'])) {
-            $url .= '?' . $_SERVER['QUERY_STRING'];
+        if ($script_params) {
+            if (!empty($_SERVER['PATH_INFO'])) {
+                $url .= $_SERVER['PATH_INFO'];
+            }
+            if (!empty($_SERVER['QUERY_STRING'])) {
+                $url .= '?' . $_SERVER['QUERY_STRING'];
+            }
         }
 
         $url = Horde::url($url, $full, 0, $force_ssl);
@@ -938,6 +943,9 @@ HTML;
         if (is_array($attr)) {
             $attributes = array_merge($attributes, $attr);
         }
+        if (empty($attributes['title'])) {
+            $attributes['title'] = '';
+        }
 
         $img = '<img';
         foreach ($attributes as $attribute => $value) {
@@ -1017,8 +1025,8 @@ HTML;
         /* Compress output if requested and possible. */
         if ($GLOBALS['conf']['compress_pages'] &&
             !$GLOBALS['browser']->hasQuirk('buggy_compression') &&
-            ini_get('zlib.output_compression') == '' &&
-            ini_get('zend_accelerator.compress_all') == '' &&
+            !(bool)ini_get('zlib.output_compression') &&
+            !(bool)ini_get('zend_accelerator.compress_all') &&
             ini_get('output_handler') != 'ob_gzhandler') {
             if (ob_get_level()) {
                 ob_end_clean();
@@ -1101,7 +1109,7 @@ HTML;
      */
     function stylesheetLink($apps = null, $theme = '', $inherit = true)
     {
-        if ($theme !== false && empty($theme)) {
+        if ($theme === '' && isset($GLOBALS['prefs'])) {
             $theme = $GLOBALS['prefs']->getValue('theme');
         }
 
@@ -1201,6 +1209,13 @@ HTML;
         global $conf;
 
         ini_set('url_rewriter.tags', 0);
+        if (!empty($conf['session']['use_only_cookies'])) {
+            ini_set('session.use_only_cookies', 1);
+            if (!empty($conf['cookie']['domain']) &&
+                strpos($conf['server']['name'], '.') === false) {
+                Horde::logMessage('Session cookies will not work without a FQDN and with a non-empty cookie domain.', __FILE__, __LINE__, PEAR_LOG_WARNING);
+            }
+        }
         session_set_cookie_params($conf['session']['timeout'],
                                   $conf['cookie']['path'], $conf['cookie']['domain'], $conf['use_ssl'] == 1 ? 1 : 0);
         session_cache_limiter($conf['session']['cache_limiter']);
@@ -1235,30 +1250,6 @@ HTML;
         }
     }
 
-    /**
-     * This function is triggered when the session is loaded. It checks for
-     * any callbacks stored in the session that need to be run immediately
-     * the session is loaded.
-     * The way to store the callbacks is:
-     * <pre>
-     * $_SESSION['callbacks']['<class object>.<function>'] = true;
-     * </pre>
-     *
-     * Any objects that are not available in $GLOBALS will be silently
-     * ignored.
-     */
-    function sessionCallbacks()
-    {
-        if (isset($_SESSION['callbacks'])) {
-            foreach (array_keys($_SESSION['callbacks']) as $callback) {
-                list($class, $function) = explode('.', $callback);
-                if (isset($GLOBALS[$class])) {
-                    call_user_func(array(&$GLOBALS[$class], $function));
-                }
-            }
-        }
-    }
-
     /**
      * Returns an un-used access key from the label given.
      *
@@ -1474,27 +1465,6 @@ HTML;
         return $error;
     }
 
-    /**
-     * Return the initial page to load when accessing Horde.
-     *
-     * @return string  The URL of the initial page.
-     */
-    function initialPage()
-    {
-        global $prefs, $registry, $perms;
-
-        $initial_app = $prefs->getValue('initial_application');
-        if (!empty($initial_app) && $registry->hasPermission($initial_app)) {
-            return Horde::url($registry->getInitialPage($initial_app), true);
-        } elseif (isset($registry->applications['horde']['initial_page'])) {
-            return Horde::applicationUrl($registry->applications['horde']['initial_page'], true);
-        } elseif (Auth::getAuth()) {
-            return Horde::applicationUrl('services/portal/', true);
-        } else {
-            return Horde::applicationUrl('login.php', true);
-        }
-    }
-
     /**
      * Returns the specified permission for the current user.
      *
@@ -1524,39 +1494,4 @@ HTML;
         return $allowed;
     }
 
-    /**
-     * Returns an array of available menu items when in a Horde script.
-     *
-     * @return array  Available menu items.
-     */
-    function getHordeMenu()
-    {
-        global $registry, $prefs;
-
-        $menu = array();
-
-        /* The home page button. If an initial application has been set in the
-         * prefs this will default to that application. Otherwise it will go
-         * to the portal screen. */
-        $initial_app = $prefs->getValue('initial_application');
-        if (!empty($initial_app)) {
-            $url = Horde::url($registry->getInitialPage($initial_app));
-        } else {
-            $url = Horde::applicationUrl('services/portal/');
-        }
-        $menu[] = array('url' => $url,
-                        'text' =>  _("Home"),
-                        'icon' => 'horde.png',
-                        'icon_path' => $registry->getImageDir());
-
-        if (Auth::isAdmin()) {
-            $menu[] = array('url' => Horde::applicationUrl('admin/'),
-                            'text' =>  _("_Administration"),
-                            'icon' => 'administration.png',
-                            'icon_path' => $registry->getImageDir());
-        }
-
-        return $menu;
-    }
-
 }
