@@ -9,15 +9,14 @@
  * you want to directly authenticate users with this driver, instead
  * of relying on transparent auth.
  *
- * $Horde: framework/Auth/Auth/http.php,v 1.21.10.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/http.php,v 1.21.10.9 2006/01/01 21:28:07 jan Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.21.10.1 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -27,7 +26,7 @@ class Auth_http extends Auth {
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array $capabilities
+     * @var array
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -38,16 +37,15 @@ class Auth_http extends Auth {
 
     /**
      * Array of usernames and hashed passwords.
-     * @var array $_users
+     *
+     * @var array
      */
     var $_users = array();
 
     /**
      * Constructs a new HTTP authentication object.
      *
-     * @access public
-     *
-     * @param optional array $params  A hash containing parameters.
+     * @param array $params  A hash containing parameters.
      */
     function Auth_http($params = array())
     {
@@ -90,7 +88,7 @@ class Auth_http extends Auth {
     function _authenticate($userId, $credentials)
     {
         if (empty($credentials['password'])) {
-            Horde::fatal(PEAR::raiseError(_("No password provided for HTTP authentication.")), __FILE__, __LINE__);
+            Horde::fatal(_("No password provided for HTTP authentication."), __FILE__, __LINE__);
         }
 
         if (empty($this->_users[$userId])) {
@@ -108,13 +106,12 @@ class Auth_http extends Auth {
     }
 
     /**
-     * Return the URI of the login screen for this authentication
-     * object.
+     * Return the URI of the login screen for this authentication object.
      *
      * @access private
      *
-     * @param optional string $app  The application to use.
-     * @param optional string $url  The URL to redirect to after login.
+     * @param string $app  The application to use.
+     * @param string $url  The URL to redirect to after login.
      *
      * @return string  The login screen URI.
      */
@@ -134,8 +131,6 @@ class Auth_http extends Auth {
     /**
      * List all users in the system.
      *
-     * @access public
-     *
      * @return mixed  The array of userIds, or a PEAR_Error object on failure.
      */
     function listUsers()
@@ -147,16 +142,14 @@ class Auth_http extends Auth {
      * Automatic authentication: Find out if the client has HTTP
      * authentication info present.
      *
-     * @access public
-     *
      * @return boolean  Whether or not the client is allowed.
      */
     function transparent()
     {
         if (!empty($_SERVER['PHP_AUTH_USER']) &&
             !empty($_SERVER['PHP_AUTH_PW'])) {
-            $this->setAuth($_SERVER['PHP_AUTH_USER'],
-                           array('password' => $_SERVER['PHP_AUTH_PW'],
+            $this->setAuth(Util::dispelMagicQuotes($_SERVER['PHP_AUTH_USER']),
+                           array('password' => Util::dispelMagicQuotes($_SERVER['PHP_AUTH_PW']),
                                  'transparent' => 1));
             return true;
         }
