@@ -4,9 +4,6 @@
  * authentication system.
  *
  * Optional parameters:<pre>
- *  'folder'          The initial folder / mailbox to open.
- *                    Should be null for 'imap' and 'nntp' protocols.
- *                    DEFAULT: null
  *  'hostspec'        The hostname or IP address of the server.
  *                    DEFAULT: 'localhost'
  *  'port'            The server port to which we will connect.
@@ -30,13 +27,12 @@
  *
  *
  * If setting up as Horde auth handler in conf.php, this is a sample entry:<pre>
- *   $conf['auth']['params']['folder'] = 'INBOX';
  *   $conf['auth']['params']['hostspec'] = 'imap.example.com';
  *   $conf['auth']['params']['port'] = 143;
  *   $conf['auth']['params']['protocol'] = 'imap/notls/novalidate-cert';</pre>
  *
  *
- * $Horde: framework/Auth/Auth/imap.php,v 1.28.10.8 2006/01/01 21:28:07 jan Exp $
+ * $Horde: framework/Auth/Auth/imap.php,v 1.28.10.9 2006/05/31 19:39:48 slusarz Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Gaudenz Steinlin <gaudenz.steinlin@id.unibe.ch>
@@ -65,7 +61,6 @@ class Auth_imap extends Auth {
         }
 
         $default_params = array(
-            'folder' => null,
             'hostspec' => 'localhost',
             'port' => '143',
             'protocol' => 'imap',
@@ -85,9 +80,6 @@ class Auth_imap extends Auth {
                                             $this->_params['hostspec'],
                                             $this->_params['port'],
                                             $this->_params['protocol']);
-            if (!empty($this->_params['folder'])) {
-                $this->_params['dsn'] .= $this->_params['folder'];
-            }
         }
     }
 
