@@ -2,15 +2,14 @@
 /**
  * Class for setting up Horde Blocks using the Horde_Form:: classes.
  *
- * Copyright 2004-2005 Marko Djukic <marko@oblo.com>
+ * Copyright 2004-2006 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Block/Block/UI.php,v 1.8.10.1 2005/01/03 12:18:54 jan Exp $
+ * $Horde: framework/Block/Block/UI.php,v 1.8.10.5 2006/01/02 17:46:35 jan Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.8.10.1 $
  * @since   Horde 3.0
  * @package Horde_Block
  */
@@ -27,17 +26,17 @@ class Horde_Block_UI {
         $this->_blocks = &Horde_Block_Collection::singleton();
     }
 
-    function &setForm(&$form)
+    function setForm(&$form)
     {
         $this->_form = &$form;
     }
 
-    function &setVars(&$vars)
+    function setVars(&$vars)
     {
         $this->_vars = &$vars;
     }
 
-    function &setupEditForm($field = 'block')
+    function setupEditForm($field = 'block')
     {
         if (is_null($this->_vars)) {
             /* No existing vars set, get them now. */
