@@ -9,7 +9,7 @@ require_once 'Horde/String.php';
  * Browser identification is performed by examining the HTTP_USER_AGENT
  * environment variable provided by the web server.
  *
- * $Horde: framework/Browser/Browser.php,v 1.153.2.42 2006/03/15 17:00:02 chuck Exp $
+ * $Horde: framework/Browser/Browser.php,v 1.153.2.47 2006/07/17 09:52:00 jan Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -125,6 +125,7 @@ class Browser {
         'RufusBot',
         'Scooter',
         'Seekbot',
+        'sproose',
         'Teoma',
         'TheSuBot',
         'TurnitinBot',
@@ -377,7 +378,6 @@ class Browser {
                     $this->setFeature('accesskey');
                     $this->setFeature('optgroup');
                     $this->setFeature('xmlhttpreq');
-                    $this->setQuirk('scrollbar_in_way');
                     break;
 
                 case 6:
@@ -996,7 +996,7 @@ class Browser {
         /* Overwrite Pragma: and other caching headers for IE. */
         if ($this->hasQuirk('cache_ssl_downloads')) {
             header('Expires: 0');
-            header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
+            header('Cache-Control: must-revalidate');
             header('Pragma: public');
         }
     }
@@ -1051,8 +1051,8 @@ class Browser {
 
     /**
      * Escape characters in javascript code if the browser requires it.
-     * %23, %26, and %2B (for IE) and %27 need to be escaped or else
-     * jscript will interpret it as a single quote, pound sign, or
+     * %23, %26, and %2B (for some browsers) and %27 need to be escaped or
+     * else javascript will interpret it as a single quote, pound sign, or
      * ampersand and refuse to work.
      *
      * @param string $code  The JS code to escape.
@@ -1064,7 +1064,8 @@ class Browser {
         $from = $to = array();
 
         if ($this->isBrowser('msie') ||
-            ($this->isBrowser('mozilla') && ($this->getMajor() >= 5))) {
+            ($this->isBrowser('mozilla') && ($this->getMajor() >= 5)) ||
+            $this->isBrowser('konqueror')) {
             $from = array('%23', '%26', '%2B');
             $to = array(urlencode('%23'), urlencode('%26'), urlencode('%2B'));
         }
@@ -1096,19 +1097,4 @@ class Browser {
         return isset($_SESSION['__browser']['ie_version']) ? $_SESSION['__browser']['ie_version'] : null;
     }
 
-    /**
-     * Explicit disabling of javascript.
-     * This will override any automatic detection of available javascript
-     * support in the user's browser. This function is called as part of the
-     * session callbacks.
-     *
-     * @since Horde 3.1
-     */
-    function disableJavascript()
-    {
-        $this->setFeature('javascript', false);
-        $this->setFeature('dom', false);
-        $this->setFeature('rte', false);
-    }
-
 }
