@@ -4,10 +4,10 @@
  * the various caching backends.  It also provides functions for
  * checking in, retrieving, and flushing a cache.
  *
- * $Horde: framework/Cache/Cache.php,v 1.31.10.1 2005/01/03 12:18:54 jan Exp $
+ * $Horde: framework/Cache/Cache.php,v 1.31.10.11 2006/01/01 21:28:10 jan Exp $
  *
- * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -19,6 +19,21 @@
  */
 class Horde_Cache {
 
+    /**
+     * Construct a new Horde_Cache object.
+     *
+     * @param array $params  Parameter array.
+     */
+    function Horde_Cache($params = array())
+    {
+        /* Only do garbage collection if asked for, and then only 1% of the
+         * time we create an object. */
+        if (!empty($params['gc']) &&
+            (rand(0, 99) == 0)) {
+            $this->_doGC($params['gc']);
+        }
+    }
+
     /**
      * Attempts to retrieve a cached object and return it to the
      * caller.
@@ -90,30 +105,38 @@ class Horde_Cache {
      *
      * @return boolean  Success or failure.
      */
-    function expire($key, $lifetime = 1)
+    function expire($key)
     {
         return true;
     }
 
     /**
-     * Attempts to return a concrete Horde_Cache instance based on
-     * $driver.
+     * Do any garbage collection needed for the driver.
      *
-     * @access public
+     * @private
      *
-     * @param mixed $driver           The type of concrete Horde_Cache subclass to
-     *                                return. This is based on the storage
-     *                                driver ($driver). The code is
-     *                                dynamically included. If $driver is an
-     *                                array, then we will look in
-     *                                $driver[0]/lib/Cache/ for the subclass
-     *                                implementation named $driver[1].php.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters a
-     *                                subclass might need.
+     * @abstract
      *
-     * @return object Horde_Cache  The newly created concrete Horde_Cache instance,
-     *                             or false on error.
+     * @param integer $secs  The minimum amount of time (in seconds) required
+     *                       before a cache item is removed.
+     */
+    function _doGC($secs)
+    {
+    }
+
+    /**
+     * Attempts to return a concrete Horde_Cache instance based on $driver.
+     *
+     * @param mixed $driver  The type of concrete Horde_Cache subclass to
+     *                       return. If $driver is an array, then we will look
+     *                       in $driver[0]/lib/Cache/ for the subclass
+     *                       implementation named $driver[1].php.
+     * @param array $params  A hash containing any additional
+     *                       configuration or connection parameters a subclass
+     *                       might need.
+     *
+     * @return Horde_Cache  The newly created concrete Horde_Cache instance, or
+     *                      false on error.
      */
     function &factory($driver, $params = array())
     {
@@ -124,7 +147,8 @@ class Horde_Cache {
 
         $driver = basename($driver);
         if (empty($driver) || $driver == 'none') {
-            return $cache = &new Horde_Cache($params);
+            $cache = &new Horde_Cache($params);
+            return $cache;
         }
 
         if (!empty($app)) {
@@ -134,12 +158,15 @@ class Horde_Cache {
         } else {
             @include_once 'Horde/Cache/' . $driver . '.php';
         }
+
         $class = 'Horde_Cache_' . $driver;
         if (class_exists($class)) {
-            return $cache = &new $class($params);
+            $cache = &new $class($params);
         } else {
-            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
+            $cache = PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
+
+        return $cache;
     }
 
     /**
@@ -154,23 +181,15 @@ class Horde_Cache {
      * This method must be invoked as:
      * $var = &Horde_Cache::singleton()
      *
-     * @access public
+     * @param mixed $driver  The type of concrete Horde_Cache subclass to
+     *                       return. If $driver is an array, then we will look
+     *                       in $driver[0]/lib/Cache/ for the subclass
+     *                       implementation named $driver[1].php.
+     * @param array $params  A hash containing any additional configuration or
+     *                       connection parameters a subclass might need.
      *
-     * @param mixed $driver           The type of concrete Horde_Cache subclass to
-     *                                return. This is based on the storage
-     *                                driver ($driver). The code is
-     *                                dynamically included. If $driver is an
-     *                                array, then we will look in
-     *                                $driver[0]/lib/Cache/ for the subclass
-     *                                implementation named $driver[1].php.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters a
-     *                                subclass might need.
-     *
-     * @since Horde 2.2
-     *
-     * @return object Horde_Cache  The concrete Horde_Cache reference,
-     *                             or false on error.
+     * @return Horde_Cache  The concrete Horde_Cache reference, or false on
+     *                      error.
      */
     function &singleton($driver, $params = array())
     {
