@@ -1,59 +1,74 @@
 <?php
 /**
- * The Cipher_des:: class implements the Cipher interface enryption data
+ * The Cipher_des:: class implements the Cipher interface encryption data
  * using the Data Encryption Standard (DES) algorithm as define in FIPS46-3.
  *
- * $Horde: framework/Cipher/Cipher/des.php,v 1.4.12.1 2005/01/03 12:18:55 jan Exp $
+ * $Horde: framework/Cipher/Cipher/des.php,v 1.4.12.7 2006/01/01 21:28:10 jan Exp $
  *
- * Copyright 2003-2005 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2003-2006 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 1.4.12.1 $
  * @since   Horde 3.0
  * @package Horde_Cipher
  */
 class Horde_Cipher_des extends Horde_Cipher {
 
-    /* Initial Permutation */
+    /**
+     * Initial Permutation
+     *
+     * @var array
+     */
     var $ip = array(
-           58, 50, 42, 34, 26, 18, 10,  2,
-           60, 52, 44, 36, 28, 20, 12,  4,
-           62, 54, 46, 38, 30, 22, 14,  6,
-           64, 56, 48, 40, 32, 24, 16,  8,
-           57, 49, 41, 33, 25, 17,  9,  1,
-           59, 51, 43, 35, 27, 19, 11,  3,
-           61, 53, 45, 37, 29, 21, 13,  5,
-           63, 55, 47, 39, 31, 23, 15,  7
+        58, 50, 42, 34, 26, 18, 10,  2,
+        60, 52, 44, 36, 28, 20, 12,  4,
+        62, 54, 46, 38, 30, 22, 14,  6,
+        64, 56, 48, 40, 32, 24, 16,  8,
+        57, 49, 41, 33, 25, 17,  9,  1,
+        59, 51, 43, 35, 27, 19, 11,  3,
+        61, 53, 45, 37, 29, 21, 13,  5,
+        63, 55, 47, 39, 31, 23, 15,  7
     );
 
-    /* Final Permutation IP^-1 */
+    /**
+     * Final Permutation IP^-1
+     *
+     * @var array
+     */
     var $fp = array(
-           40,  8, 48, 16, 56, 24, 64, 32,
-           39,  7, 47, 15, 55, 23, 63, 31,
-           38,  6, 46, 14, 54, 22, 62, 30,
-           37,  5, 45, 13, 53, 21, 61, 29,
-           36,  4, 44, 12, 52, 20, 60, 28,
-           35,  3, 43, 11, 51, 19, 59, 27,
-           34,  2, 42, 10, 50, 18, 58, 26,
-           33,  1, 41,  9, 49, 17, 57, 25
+        40,  8, 48, 16, 56, 24, 64, 32,
+        39,  7, 47, 15, 55, 23, 63, 31,
+        38,  6, 46, 14, 54, 22, 62, 30,
+        37,  5, 45, 13, 53, 21, 61, 29,
+        36,  4, 44, 12, 52, 20, 60, 28,
+        35,  3, 43, 11, 51, 19, 59, 27,
+        34,  2, 42, 10, 50, 18, 58, 26,
+        33,  1, 41,  9, 49, 17, 57, 25
     );
 
-    /* E Bit Selection Table  */
+    /**
+     * E Bit Selection Table
+     *
+     * @var array
+     */
     var $e = array(
-           32,  1,  2,  3,  4,  5,
-            4,  5,  6,  7,  8,  9,
-            8,  9, 10, 11, 12, 13,
-           12, 13, 14, 15, 16, 17,
-           16, 17, 18, 19, 20, 21,
-           20, 21, 22, 23, 24, 25,
-           24, 25, 26, 27, 28, 29,
-           28, 29, 30, 31, 32,  1
+        32,  1,  2,  3,  4,  5,
+         4,  5,  6,  7,  8,  9,
+         8,  9, 10, 11, 12, 13,
+        12, 13, 14, 15, 16, 17,
+        16, 17, 18, 19, 20, 21,
+        20, 21, 22, 23, 24, 25,
+        24, 25, 26, 27, 28, 29,
+        28, 29, 30, 31, 32,  1
     );
 
-    /* S boxes */
+    /**
+     * S boxes
+     *
+     * @var array
+     */
     var $_s = array(
         /* S1 */
         1 => array(
@@ -63,7 +78,7 @@ class Horde_Cipher_des extends Horde_Cipher {
            15, 12,  8,  2,  4,  9,  1,  7,  5, 11,  3, 14, 10,  0,  6, 13
         ),
 
-       /* S2 */
+        /* S2 */
         2 => array(
            15,  1,  8, 14,  6, 11,  3,  4,  9,  7,  2, 13, 12,  0,  5, 10,
             3, 13,  4,  7, 15,  2,  8, 14, 12,  0,  1, 10,  6,  9, 11,  5,
@@ -113,68 +128,83 @@ class Horde_Cipher_des extends Horde_Cipher {
 
         /* S8 */
         8 => array(
-           13,  2,  8,  4,  6, 15, 11,  1, 10,  9,  3, 14,  5,  0, 12,  7,
-            1, 15, 13,  8, 10,  3,  7,  4, 12,  5,  6, 11,  0, 14,  9,  2,
-            7, 11,  4,  1,  9, 12, 14,  2,  0,  6, 10, 13, 15,  3,  5,  8,
-            2,  1, 14,  7,  4, 10,  8, 13, 15, 12,  9,  0,  3,  5,  6, 11
+            13,  2,  8,  4,  6, 15, 11,  1, 10,  9,  3, 14,  5,  0, 12,  7,
+             1, 15, 13,  8, 10,  3,  7,  4, 12,  5,  6, 11,  0, 14,  9,  2,
+             7, 11,  4,  1,  9, 12, 14,  2,  0,  6, 10, 13, 15,  3,  5,  8,
+             2,  1, 14,  7,  4, 10,  8, 13, 15, 12,  9,  0,  3,  5,  6, 11
         )
     );
 
-    /* Primitive function */
+    /**
+     * Primitive function
+     *
+     * @var array
+     */
     var $p = array(
-           16,  7, 20, 21,
-           29, 12, 28, 17,
-            1, 15, 23, 26,
-            5, 18, 31, 10,
-            2,  8, 24, 14,
-           32, 27,  3,  9,
-           19, 13, 30,  6,
-           22, 11,  4, 25
+        16,  7, 20, 21,
+        29, 12, 28, 17,
+         1, 15, 23, 26,
+         5, 18, 31, 10,
+         2,  8, 24, 14,
+        32, 27,  3,  9,
+        19, 13, 30,  6,
+        22, 11,  4, 25
     );
 
-    /* Permuted Choice Table */
-    var $pc1 = array(
-       57, 49, 41, 33, 25, 17,  9,
-        1, 58, 50, 42, 34, 26, 18,
-       10,  2, 59, 51, 43, 35, 27,
-       19, 11,  3, 60, 52, 44, 36,
-
-       63, 55, 47, 39, 31, 23, 15,
-        7, 62, 54, 46, 38, 30, 22,
-       14,  6, 61, 53, 45, 37, 29,
-       21, 13,  5, 28, 20, 12,  4
-    );
-
-    /* number left rotations of pc1 */
-    var $shifts = array(
-       1, 1, 2, 2, 2, 2, 2, 2,
-       1, 2, 2, 2, 2, 2, 2, 1
-    );
-
-    /* Permuted Choice Table 2 */
-    var $pc2 = array(
-       14, 17, 11, 24,  1,  5,
-        3, 28, 15,  6, 21, 10,
-       23, 19, 12,  4, 26,  8,
-       16,  7, 27, 20, 13,  2,
-       41, 52, 31, 37, 47, 55,
-       30, 40, 51, 45, 33, 48,
-       44, 49, 39, 56, 34, 53,
-       46, 42, 50, 36, 29, 32
-    );
-
-    /* Key Schedule */
-    var $_Ks = array();
-
-    /* Constructor */
-    function Horde_Cipher_des($params = null)
-    {
-    }
-
     /**
-     * Set the key to be used for en/decryption
+     * Permuted Choice Table
      *
-     * @param String $key   The key to use
+     * @var array
+     */
+    var $pc1 = array(
+        57, 49, 41, 33, 25, 17,  9,
+         1, 58, 50, 42, 34, 26, 18,
+        10,  2, 59, 51, 43, 35, 27,
+        19, 11,  3, 60, 52, 44, 36,
+
+        63, 55, 47, 39, 31, 23, 15,
+         7, 62, 54, 46, 38, 30, 22,
+        14,  6, 61, 53, 45, 37, 29,
+        21, 13,  5, 28, 20, 12,  4
+    );
+
+    /**
+     * Number left rotations of pc1
+     *
+     * @var array
+     */
+    var $shifts = array(
+        1, 1, 2, 2, 2, 2, 2, 2,
+        1, 2, 2, 2, 2, 2, 2, 1
+    );
+
+    /**
+     * Permuted Choice Table 2
+     *
+     * @var array
+     */
+    var $pc2 = array(
+        14, 17, 11, 24,  1,  5,
+         3, 28, 15,  6, 21, 10,
+        23, 19, 12,  4, 26,  8,
+        16,  7, 27, 20, 13,  2,
+        41, 52, 31, 37, 47, 55,
+        30, 40, 51, 45, 33, 48,
+        44, 49, 39, 56, 34, 53,
+        46, 42, 50, 36, 29, 32
+    );
+
+    /**
+     * Key Schedule
+     *
+     * @var array
+     */
+    var $_Ks = array();
+
+    /**
+     * Set the key to be used for en/decryption.
+     *
+     * @param string $key  The key to use.
      */
     function setKey($key)
     {
@@ -184,9 +214,9 @@ class Horde_Cipher_des extends Horde_Cipher {
     }
 
     /**
-     * Return the size of the blocks that this cipher needs
+     * Return the size of the blocks that this cipher needs.
      *
-     * @return Integer  The number of characters per block
+     * @return integer  The number of characters per block.
      */
     function getBlockSize()
     {
@@ -194,12 +224,12 @@ class Horde_Cipher_des extends Horde_Cipher {
     }
 
     /**
-     * Encrypt a block on data.
+     * Encrypt a block of data.
      *
-     * @param String $block         The data to encrypt
-     * @param optional String $key  The key to use
+     * @param string $block  The data to encrypt.
+     * @param string $key    The key to use.
      *
-     * @return String the encrypted output
+     * @return string  The encrypted output.
      */
     function encryptBlock($block, $key = null)
     {
@@ -227,12 +257,12 @@ class Horde_Cipher_des extends Horde_Cipher {
     }
 
     /**
-     * Decrypt a block on data.
+     * Decrypt a block of data.
      *
-     * @param String $block         The data to decrypt
-     * @param optional String $key  The key to use
+     * @param string $block  The data to decrypt.
+     * @param string $key    The key to use.
      *
-     * @return String the decrypted output
+     * @return string  The decrypted output.
      */
     function decryptBlock($block, $key = null)
     {
@@ -262,9 +292,9 @@ class Horde_Cipher_des extends Horde_Cipher {
     /**
      * Put an input string through an initial permutation
      *
-     * @param   $input  Input String
+     * @param string $input  Input string.
      *
-     * @return  String  Permutated String
+     * @return string  Permutated string.
      */
     function _initialPerm($input)
     {
@@ -289,16 +319,15 @@ class Horde_Cipher_des extends Horde_Cipher {
     }
 
     /**
-     * Put an input string through a final permutation
+     * Put an input string through a final permutation.
      *
-     * @param   $input  Input String
+     * @param string $input  Input string.
      *
-     * @return  String  Permutated String
+     * @return string  Permutated string.
      */
     function _finalPerm($input)
     {
         // TODO: Some stylie bitwise thing instead.
-
         $input_bin = '';
         for ($i = 0; $i < 8; $i++) {
             $input_bin .= str_pad(decbin(ord($input[$i])), 8, '0', STR_PAD_LEFT);
@@ -320,6 +349,11 @@ class Horde_Cipher_des extends Horde_Cipher {
 
     /**
      * f() The permutation function.
+     *
+     * @param string $input  Input string.
+     * @param integer $round  The round.
+     *
+     * @return string  The output string.
      */
     function _f($input, $round)
     {
@@ -363,9 +397,11 @@ class Horde_Cipher_des extends Horde_Cipher {
     }
 
     /**
-     * Create the complete key shedule
+     * Create the complete key shedule.
      *
-     * @param array $key
+     * @param string $key  The key to use.
+     *
+     * @return array Key schedule.
      */
     function _keySchedule($key)
     {
@@ -402,4 +438,5 @@ class Horde_Cipher_des extends Horde_Cipher {
 
         return $ks;
     }
+
 }
