@@ -4,39 +4,48 @@
  * to be read.
  *
  * This class is based on code by:
- * Anotny Raijekov <dev@strategma.bg>
+ * Antony Raijekov <dev@strategma.bg>
  * http://uruds.gateway.bg/zeos/
  *
- * $Horde: framework/Compress/Compress/dbx.php,v 1.3.12.1 2005/01/03 12:18:56 jan Exp $
+ * $Horde: framework/Compress/Compress/dbx.php,v 1.3.12.9 2006/01/01 21:28:11 jan Exp $
  *
- * Copyright 2003-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.3.12.1 $
  * @since   Horde 3.0
  * @package Horde_Compress
  */
-class Horde_Compress_dbx extends Horde_Compress
-{
-    var $mails;
-    var $tmp;
+class Horde_Compress_dbx extends Horde_Compress {
+
+    /**
+     * TODO
+     *
+     * @var array
+     */
+    var $_mails = array();
+
+    /**
+     * TODO
+     *
+     * @var array
+     */
+    var $_tmp = array();
 
     /**
      * Decompresses a DBX file and gets information from it.
      *
-     * @access public
-     *
      * @param string $data  The dbx file data.
+     * @param array $params  Any
      *
      * @return mixed  The requested data.
      */
-    function &decompress(&$data, $params = null)
+    function decompress(&$data, $params = null)
     {
-        $this->mails = array();
-        $this->tmp = array();
+        $this->_mails = array();
+        $this->_tmp = array();
         $position = 0xC4;
         $header_info = unpack('Lposition/LDataLength/nHeaderLength/nFlagCount', substr($data, $position, 12));
         $position += 12;
@@ -45,18 +54,25 @@ class Horde_Compress_dbx extends Horde_Compress
             $position = 0x30;
             $buf = unpack('Lposition', substr($data, $position, 4));
             $position = $buf['position'];
-            $result = $this->readIndex($data, $position);
+            $result = $this->_readIndex($data, $position);
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
             }
         }
-        return $this->mails;
+        return $this->_mails;
     }
 
     /**
      * Returns a null-terminated string from the specified data.
+     *
+     * @access private
+     *
+     * @param string &$buf  TODO
+     * @param integer $pos  TODO
+     *
+     * @return string  TODO
      */
-    function readString(&$buf, $pos)
+    function _readString(&$buf, $pos)
     {
         if ($len = strpos(substr($buf, $pos), chr(0))) {
             return substr($buf, $pos, $len);
@@ -64,14 +80,24 @@ class Horde_Compress_dbx extends Horde_Compress
         return '';
     }
 
-    function readMessage(&$data, $position)
+    /**
+     * TODO
+     *
+     * @access private
+     *
+     * @param string &$data      TODO
+     * @param integer $position  TODO
+     *
+     * @return string  TODO
+     */
+    function _readMessage(&$data, $position)
     {
         $msg = '';
+        $part = 0;
+
         if ($position > 0) {
             $IndexItemsCount = array_pop(unpack('S', substr($data, 0xC4, 4)));
             if ($IndexItemsCount > 0) {
-                $msg = '';
-                $part = 0;
                 while ($position < strlen($data)) {
                     $part++;
                     $s = substr($data, $position, 528);
@@ -79,7 +105,6 @@ class Horde_Compress_dbx extends Horde_Compress
                         break;
                     }
                     $msg_item = unpack('LFilePos/LUnknown/LItemSize/LNextItem/a512Content', $s);
-                    //var_dump($msg_item);
                     if ($msg_item['FilePos'] != $position) {
                         return PEAR::raiseError(_("Invalid file format"));
                     }
@@ -92,10 +117,21 @@ class Horde_Compress_dbx extends Horde_Compress
                 }
             }
         }
+
         return $msg;
     }
 
-    function readMessageInfo(&$data, $position)
+    /**
+     * TODO
+     *
+     * @access private
+     *
+     * @param string &$data      TODO
+     * @param integer $position  TODO
+     *
+     * @return array  TODO
+     */
+    function _readMessageInfo(&$data, $position)
     {
         $message_info = array();
         $msg_header = unpack('Lposition/LDataLength/SHeaderLength/SFlagCount', substr($data, $position, 12));
@@ -113,64 +149,59 @@ class Horde_Compress_dbx extends Horde_Compress
         $DataBuffer = substr($data, $position, $size);
         $position += $size;
         $message_info = array();
-        //process flags
+
+        $flag_array = array(
+            0x1 => 'MsgFlags',
+            0x2 => 'Sent',
+            0x4 => 'position',
+            0x7 => 'MessageID',
+            0x8 => 'Subject',
+            0x9 => 'From_reply',
+            0xA => 'References',
+            0xB => 'Newsgroup',
+            0xD => 'From',
+            0xE => 'Reply_To',
+            0x12 => 'Received',
+            0x13 => 'Receipt',
+            0x1A => 'Account',
+            0x1B => 'AccountID',
+            0x80 => 'Msg',
+            0x81 => 'MsgFlags',
+            0x84 => 'position',
+            0x91 => 'size',
+        );
+
+        /* Process flags */
         for ($i = 0; $i < $flags; $i++) {
             $pos = 0;
             $f = array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4)));
 
-            switch ($f & 0xFF) {
+            $mask = $f & 0xFF;
+            switch ($mask) {
             case 0x1:
                 $pos = $pos + ($f >> 8);
-                $message_info['MsgFlags'] = array_pop(unpack('C', substr($DataBuffer, $pos, 1)));
-                $pos++;
-                $message_info['MsgFlags'] += array_pop(unpack('C', substr($DataBuffer, $pos, 1))) * 256;
-                $pos++;
+                $message_info['MsgFlags'] = array_pop(unpack('C', substr($DataBuffer, $pos++, 1)));
+                $message_info['MsgFlags'] += array_pop(unpack('C', substr($DataBuffer, $pos++, 1))) * 256;
                 $message_info['MsgFlags'] += array_pop(unpack('C', substr($DataBuffer, $pos, 1))) * 65536;
                 break;
 
             case 0x2:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['Sent'] = array_pop(unpack('L', substr($DataBuffer, $pos, 4)));
-                break;
-
             case 0x4:
                 $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['position'] = array_pop(unpack('L', substr($DataBuffer, $pos, 4)));
+                $message_info[$flag_array[$mask]] = array_pop(unpack('L', substr($DataBuffer, $pos, 4)));
                 break;
 
             case 0x7:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['MessageID'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0x8:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['Subject'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0x9:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['From_reply'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0xA:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['References'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0xB:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['Newsgroup'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0xD:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['From'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0xE:
+            case 0x13:
+            case 0x1A:
                 $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['Reply_To'] = $this->readstring($DataBuffer, $pos);
+                $message_info[$flag_array[$mask]] = $this->_readString($DataBuffer, $pos);
                 break;
 
             case 0x12:
@@ -178,35 +209,16 @@ class Horde_Compress_dbx extends Horde_Compress
                 $message_info['Received'] = array_pop(unpack('L', substr($DataBuffer, $pos, 4)));
                 break;
 
-            case 0x13:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['Receipt'] = $this->readstring($DataBuffer, $pos);
-                break;
-
-            case 0x1A:
-                $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['Account'] = $this->readstring($DataBuffer, $pos);
-                break;
-
             case 0x1B:
                 $pos += array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                $message_info['AccountID'] = intval($this->readstring($DataBuffer, $pos));
+                $message_info['AccountID'] = intval($this->_readString($DataBuffer, $pos));
                 break;
 
             case 0x80:
-                $message_info['Msg'] = array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                break;
-
             case 0x81:
-                $message_info['MsgFlags'] = array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                break;
-
             case 0x84:
-                $message_info['position'] = array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
-                break;
-
             case 0x91:
-                $message_info['size'] = array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
+                $message_info[$flag_array[$mask]] = array_pop(unpack('L', substr($FlagsBuffer, $i * 4, 4))) >> 8;
                 break;
             }
         }
@@ -214,78 +226,49 @@ class Horde_Compress_dbx extends Horde_Compress
         return $message_info;
     }
 
-    function readIndex(&$data, $position)
+    /**
+     * TODO
+     *
+     * @access private
+     *
+     * @param string &$data      TODO
+     * @param integer $position  TODO
+     */
+    function _readIndex(&$data, $position)
     {
-        //var_dump($position);
         $index_header = unpack('LFilePos/LUnknown1/LPrevIndex/LNextIndex/LCount/LUnknown', substr($data, $position, 24));
-        //var_dump($index_header);
         if ($index_header['FilePos'] != $position) {
             return PEAR::raiseError(_("Invalid file format"));
         }
 
         // Push it into list of processed items.
-        $this->tmp[$position] = true;
+        $this->_tmp[$position] = true;
         if (($index_header['NextIndex'] > 0) &&
-            empty($this->tmp[$index_header['NextIndex']])) {
-            $this->readIndex($data, $index_header['NextIndex']);
+            empty($this->_tmp[$index_header['NextIndex']])) {
+            $this->_readIndex($data, $index_header['NextIndex']);
         }
         if (($index_header['PrevIndex'] > 0) &&
-            empty($this->tmp[$index_header['PrevIndex']])) {
-            $this->readIndex($data, $index_header['PrevIndex']);
+            empty($this->_tmp[$index_header['PrevIndex']])) {
+            $this->_readIndex($data, $index_header['PrevIndex']);
         }
         $position += 24;
         $icount = $index_header['Count'] >> 8;
-        //var_dump($icount);
         if ($icount > 0) {
             $buf = substr($data, $position, 12 * $icount);
             for ($i = 0; $i < $icount; $i++) {
                 $hdr_buf = substr($buf, $i * 12, 12);
                 $IndexItem = unpack('LHeaderPos/LChildIndex/LUnknown', $hdr_buf);
-                //var_dump($IndexItem);
                 if ($IndexItem['HeaderPos'] > 0) {
-                    if (false && strtolower($this->fname) == 'folders.dbx')
-                        //read_folder($fp,$IndexItem['HeaderPos']);
-                        print 'Read folder not implemented in v1.0a<br>';
-                    else {
-                        $mail['info'] = $this->readMessageInfo($data, $IndexItem['HeaderPos']);
-                        $mail['content'] = $this->readMessage($data, $mail['info']['position']);
-                        $this->mails[] = $mail;
-                    }
-               }
+                    $mail['info'] = $this->_readMessageInfo($data, $IndexItem['HeaderPos']);
+                    $mail['content'] = $this->_readMessage($data, $mail['info']['position']);
+                    $this->_mails[] = $mail;
+                }
                 if (($IndexItem['ChildIndex'] > 0) &&
-                    empty($this->tmp[$IndexItem['ChildIndex']])) {
-                    $this->readIndex($fp, $IndexItem['ChildIndex']);
+                    empty($this->_tmp[$IndexItem['ChildIndex']])) {
+                    $this->_readIndex($fp, $IndexItem['ChildIndex']);
                 }
             }
         }
     }
 
-    //debug function to display human readble message flags (Just for debugging purpose)
-    function decode_flags($x)
-    {
-        $decode_flag['DOWNLOADED']              = 0x1;
-        $decode_flag['MARKED']                  = 0x20;
-        $decode_flag['READED']                  = 0x80;
-        $decode_flag['DOWNLOAD_LATER']          = 0x100;
-        $decode_flag['NEWS_MSG']                = 0x800;  // to verify
-        $decode_flag['ATTACHMENTS']             = 0x4000;
-        $decode_flag['REPLY']                   = 0x80000;
-        $decode_flag['INSPECT_CONVERSATION']    = 0x400000;
-        $decode_flag['IGNORE_CONVERSATION']     = 0x800000;
-
-        $decoded_flags = '';
-
-        if(($x & $decode_flag['NEWS_MSG']) != 0) $decoded_flags .= "NEWS MESSAGE\n<br>";
-        if(($x & $decode_flag['DOWNLOAD_LATER']) != 0) $decoded_flags .= "DOWNLOAD LATER\n<br>";
-        if(($x & $decode_flag['DOWNLOADED']) != 0) $decoded_flags .= "DOWNLOADED\n<br>";
-        if(($x & $decode_flag['READED']) != 0) $decoded_flags .= "READED\n<br>";
-        if(($x & $decode_flag['MARKED']) != 0) $decoded_flags .= "MARKED\n<br>";
-        if(($x & $decode_flag['ATTACHMENTS']) != 0) $decoded_flags .= "ATTACHMENTS\n<br>";
-        if(($x & $decode_flag['REPLY']) != 0) $decoded_flags .= "REPLY\n<br>";
-        if(($x & $decode_flag['INSPECT_CONVERSATION']) != 0) $decoded_flags .= "INSPECT CONVERSATION\n<br>";
-        if(($x & $decode_flag['IGNORE_CONVERSATION']) != 0) $decoded_flags .= "IGNORE CONVERSATION\n<br>";
-
-        return $decoded_flags;
-    }
-
 }
