@@ -1,4 +1,7 @@
 <?php
+
+require_once 'Horde/Form.php';
+
 /**
  * The Config:: package provides a framework for managing the
  * configuration of Horde applications, writing conf.php files from
@@ -13,7 +16,7 @@
  *
  *   http://alexandre.alapetite.net/doc-alex/domxml-php4-php5/
  *
- * $Horde: framework/Horde/Horde/Config.php,v 1.80.2.15 2006/03/10 00:13:31 jan Exp $
+ * $Horde: framework/Horde/Horde/Config.php,v 1.80.2.26 2006/06/01 23:44:32 jan Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -109,23 +112,30 @@ class Horde_Config {
     }
 
     /**
-     * Reads the application's conf.xml file and builds an associative
-     * array from its XML tree.
+     * Reads the application's conf.xml file and builds an associative array
+     * from its XML tree.
+     *
+     * @param array $custom_conf   Any settings that shall be included in the
+     *                             generated configuration.
      *
      * @return array  An associative array representing the configuration tree.
      */
-    function readXMLConfig()
+    function readXMLConfig($custom_conf = null)
     {
-        if (is_null($this->_xmlConfigTree)) {
+        if (is_null($this->_xmlConfigTree) || $custom_conf) {
             require_once 'Horde/Text.php';
 
             global $registry;
             $path = $registry->get('fileroot', $this->_app) . '/config';
 
-            /* Fetch the current conf.php contents. */
-            @eval($this->getPHPConfig());
-            if (isset($conf)) {
-                $this->_currentConfig = $conf;
+            if ($custom_conf) {
+                $this->_currentConfig = $custom_conf;
+            } else {
+                /* Fetch the current conf.php contents. */
+                @eval($this->getPHPConfig());
+                if (isset($conf)) {
+                    $this->_currentConfig = $conf;
+                }
             }
 
             /* Load the DOM object. */
@@ -190,12 +200,14 @@ class Horde_Config {
      * Generates the content of the application's configuration file.
      *
      * @param Variables $formvars  The processed configuration form data.
+     * @param array $custom_conf   Any settings that shall be included in the
+     *                             generated configuration.
      *
      * @return string  The content of the generated configuration file.
      */
-    function generatePHPConfig($formvars)
+    function generatePHPConfig($formvars, $custom_conf = null)
     {
-        $this->readXMLConfig();
+        $this->readXMLConfig($custom_conf);
         $this->getPHPConfig();
 
         $this->_phpConfig = "<?php\n";
@@ -300,7 +312,7 @@ class Horde_Config {
                     break;
 
                 case 'int':
-                    if ($val != '') {
+                    if ($val !== '') {
                         $value = (int)$val;
                     }
                     break;
@@ -383,13 +395,20 @@ class Horde_Config {
                 break;
 
             case 'configswitch':
+                $values = $this->_getSwitchValues($node, $ctx);
                 if ($quote) {
                     $default = $this->_default($curctx, $this->_getNodeOnlyText($node));
                 } else {
                     $default = $this->_defaultRaw($curctx, $this->_getNodeOnlyText($node));
                 }
+                if ($default === '') {
+                    $default = key($values);
+                }
+                if (is_bool($default)) {
+                    $default = $default ? 'true' : 'false';
+                }
                 $conf[$name] = array('desc' => $desc,
-                                     'switch' => $this->_getSwitchValues($node, $ctx),
+                                     'switch' => $values,
                                      'default' => $default);
                 break;
 
@@ -400,6 +419,12 @@ class Horde_Config {
                 } else {
                     $default = $this->_defaultRaw($curctx, $this->_getNodeOnlyText($node));
                 }
+                if ($default === '') {
+                    $default = key($values);
+                }
+                if (is_bool($default)) {
+                    $default = $default ? 'true' : 'false';
+                }
                 $conf[$name] = array('_type' => 'enum',
                                      'required' => $required,
                                      'quote' => $quote,
@@ -793,7 +818,7 @@ class Horde_Config {
                             'desc' => 'Absolute path to the database file',
                             'default' => $this->_default($ctx . '|database', '')),
                         'mode' => array(
-                            '_type' => 'octal',
+                            '_type' => 'text',
                             'desc' => 'The mode to open the file with',
                             'default' => $this->_default($ctx . '|mode', '0644')),
                         'charset' => $charset)),
@@ -863,6 +888,9 @@ class Horde_Config {
                 'desc' => 'What VFS driver should we use?',
                 'default' => $this->_default($ctx . '|' . $node->get_attribute('switchname'), 'horde'),
                 'switch' => array(
+                    'none' => array(
+                        'desc' => 'None',
+                        'fields' => array()),
                     'horde' => array(
                         'desc' => 'Horde defaults',
                         'fields' => array()),
@@ -1071,8 +1099,7 @@ class Horde_Config {
             break;
 
         case 'list-horde-languages':
-            global $nls;
-            return $nls['languages'];
+            return array_map(create_function('$val', 'return preg_replace(array("/&#x([0-9a-f]{4});/ie", "/(&[^;]+;)/e"), array("String::convertCharset(pack(\"H*\", \"$1\"), \"ucs-2\", \"' . NLS::getCharset() . '\")", "String::convertCharset(html_entity_decode(\"$1\", ENT_COMPAT, \"iso-8859-1\"), \"iso-8859-1\", \"' . NLS::getCharset() . '\")"), $val);'), $GLOBALS['nls']['languages']);
             break;
 
         case 'list-blocks':
@@ -1217,6 +1244,9 @@ class ConfigForm extends Horde_Form {
             } elseif (isset($configitem['_type'])) {
                 $required = (isset($configitem['required'])) ? $configitem['required'] : true;
                 $type = $configitem['_type'];
+                // FIXME: multienum fields can well be required, meaning that
+                // you need to select at least one entry. Changing this before
+                // Horde 4.0 would break a lot of configuration files though.
                 if ($type == 'multienum' || $type == 'header' ||
                     $type == 'description') {
                     $required = false;
