@@ -26,7 +26,7 @@ require_once 'PEAR.php';
  * Abstract class to handle different kinds of Data formats and to
  * help data exchange between Horde applications and external sources.
  *
- * $Horde: framework/Data/Data.php,v 1.80.10.11 2006/01/28 15:52:05 chuck Exp $
+ * $Horde: framework/Data/Data.php,v 1.80.10.12 2006/08/08 17:15:22 jan Exp $
  *
  * Copyright 1999-2006 Jan Schneider <jan@horde.org>
  *
@@ -202,36 +202,44 @@ class Horde_Data extends PEAR {
     /**
      * Maps a date/time string to an associative array.
      *
+     * The method signature has changed in Horde 3.1.3.
+     *
      * @access private
      *
-     * @param string $date       The date.
-     * @param string $type       One of 'date', 'time' or 'datetime'.
-     * @param string $delimiter  The character that seperates the different
-     *                           date/time parts.
-     * @param string $format     If 'ampm' and $date contains a time we assume
-     *                           that it is in AM/PM format.
+     * @param string $date   The date.
+     * @param string $type   One of 'date', 'time' or 'datetime'.
+     * @param array $params  Two-dimensional array with additional information
+     *                       about the formatting. Possible keys are:<pre>
+     *                       delimiter -- The character that seperates the
+     *                                    different date/time parts.
+     *                       format -- If 'ampm' and $date contains a time we
+     *                                 assume that it is in AM/PM format.
+     *                       order -- If $type is 'datetime' the order of the
+     *                                day and time parts: -1 (timestamp), 0
+     *                                (day/time), 1 (time/day).
+     * @param integer $key   The key to use for $params.
      *
      * @return string  The date or time in ISO format.
      */
-    function mapDate($date, $type, $delimiter, $format = null)
+    function mapDate($date, $type, $params, $key)
     {
         switch ($type) {
         case 'date':
         case 'monthday':
         case 'monthdayyear':
-            $dates = explode($delimiter, $date);
+            $dates = explode($params['delimiter'][$key], $date);
             if (count($dates) != 3) {
                 return $date;
             }
-            $index = array_flip(explode('/', $format));
+            $index = array_flip(explode('/', $params['format'][$key]));
             return $dates[$index['year']] . '-' . $dates[$index['month']] . '-' . $dates[$index['mday']];
 
         case 'time':
-            $dates = explode($delimiter, $date);
+            $dates = explode($params['delimiter'][$key], $date);
             if (count($dates) < 2 || count($dates) > 3) {
                 return $date;
             }
-            if ($format == 'ampm') {
+            if ($params['format'][$key] == 'ampm') {
                 if (strpos(strtolower($dates[count($dates)-1]), 'pm') !== false) {
                     if ($dates[0] !== '12') {
                         $dates[0] += 12;
@@ -239,12 +247,32 @@ class Horde_Data extends PEAR {
                 } elseif ($dates[0] == '12') {
                     $dates[0] = '0';
                 }
-                $dates[count($dates)-1] = (int) $dates[count($dates)-1];
+                $dates[count($dates) - 1] = sprintf('%02d', $dates[count($dates)-1]);
             }
             return $dates[0] . ':' . $dates[1] . (count($dates) == 3 ? (':' . $dates[2]) : ':00');
 
         case 'datetime':
-            return '';
+            switch ($params['order'][$key]) {
+            case -1:
+                return (string)(int)$date == $date
+                    ? date('Y-m-d H:i:s', $date)
+                    : $date;
+            case 0:
+                list($day, $time) = explode(' ', $date, 2);
+                break;
+            case 1:
+               list($time, $day) = explode(' ', $date, 2);
+               break;
+            }
+            $date = $this->mapDate($day, 'date',
+                                   array('delimiter' => $params['day_delimiter'],
+                                         'format' => $params['day_format']),
+                                   $key);
+            $time = $this->mapDate($time, 'time',
+                                   array('delimiter' => $params['time_delimiter'],
+                                         'format' => $params['time_format']),
+                                   $key);
+            return $date . ' ' . $time;
 
         }
     }
@@ -320,8 +348,13 @@ class Horde_Data extends PEAR {
         case IMPORT_DATETIME:
         case IMPORT_DATA:
             if ($action == IMPORT_DATETIME) {
-                $delimiter = Util::getFormData('delimiter');
-                $format = Util::getFormData('format');
+                $params = array('delimiter' => Util::getFormData('delimiter'),
+                                'format' => Util::getFormData('format'),
+                                'order' => Util::getFormData('order'),
+                                'day_delimiter' => Util::getFormData('day_delimiter'),
+                                'day_format' => Util::getFormData('day_format'),
+                                'time_delimiter' => Util::getFormData('time_delimiter'),
+                                'time_format' => Util::getFormData('time_format'));
             }
             if (!isset($_SESSION['import_data']['data'])) {
                 return PEAR::raiseError(_("The uploaded data was lost since the previous step."));
@@ -337,7 +370,7 @@ class Horde_Data extends PEAR {
                             !empty($val) &&
                             isset($param['time_fields']) &&
                             isset($param['time_fields'][$mapped_key])) {
-                            $val = $this->mapDate($val, $param['time_fields'][$mapped_key], $delimiter[$key], $format[$key]);
+                            $val = $this->mapDate($val, $param['time_fields'][$mapped_key], $params, $key);
                         }
                         $data_row[$_SESSION['import_data']['map'][$key]] = $val;
                     }
