@@ -8,7 +8,7 @@ require_once 'Horde/iCalendar.php';
  * methods that vCard and iCalendar implementation can share and rely
  * on.
  *
- * $Horde: framework/Data/Data/imc.php,v 1.32.10.7 2006/01/01 21:28:13 jan Exp $
+ * $Horde: framework/Data/Data/imc.php,v 1.32.10.8 2006/05/09 23:06:09 chuck Exp $
  *
  * Copyright 1999-2006 Jan Schneider <jan@horde.org>
  *
@@ -25,8 +25,7 @@ class Horde_Data_imc extends Horde_Data {
 
     function importData($text)
     {
-        $this->_iCal = &new Horde_iCalendar();
-
+        $this->_iCal = new Horde_iCalendar();
         if (!$this->_iCal->parsevCalendar($text)) {
             return PEAR::raiseError(_("There was an error importing the iCalendar data."));
         }
@@ -46,14 +45,13 @@ class Horde_Data_imc extends Horde_Data {
      */
     function exportData($data, $method = 'REQUEST')
     {
-        global $prefs;
-
-        $this->_iCal = &new Horde_iCalendar();
-
+        $this->_iCal = new Horde_iCalendar();
         $this->_iCal->setAttribute('METHOD', $method);
+
         foreach ($data as $event) {
             $this->_iCal->addComponent($event);
         }
+
         return $this->_iCal->exportvCalendar();
     }
 
