@@ -36,7 +36,7 @@ define('DATATREE_BUILD_COUNT', 1);
  * Required values for $params:<pre>
  *   'group' -- Define each group of objects we want to build.</pre>
  *
- * $Horde: framework/DataTree/DataTree.php,v 1.151.2.16 2006/01/01 21:28:13 jan Exp $
+ * $Horde: framework/DataTree/DataTree.php,v 1.151.2.18 2006/07/13 08:58:44 jan Exp $
  *
  * Copyright 1999-2003 Stephane Huther <shuther@bigfoot.com>
  * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.org>
@@ -589,7 +589,7 @@ class DataTree {
      * @param string  $rootname   The label to use for the root element.
      *                            Defaults to DATATREE_ROOT.
      * @param integer $maxdepth   The maximum number of levels to return
-     *                            Defaults to DATATREE_ROOT, which is no limit.
+     *                            Defaults to -1, which is no limit.
      *
      * @return mixed  The tree representation of the objects, or a PEAR_Error
      *                on failure.
@@ -650,7 +650,6 @@ class DataTree {
      */
     function set($data, $charset = null)
     {
-        $cats = array();
         $cids = array();
         foreach ($data as $id => $cat) {
             if (!is_null($charset)) {
