@@ -3,7 +3,7 @@
  * The DataTree_null:: class provides a dummy implementation of the
  * DataTree:: API; no data will last beyond a single page request.
  *
- * $Horde: framework/DataTree/DataTree/null.php,v 1.15.2.5 2006/11/13 02:12:47 chuck Exp $
+ * $Horde: framework/DataTree/DataTree/null.php,v 1.15.2.4 2005/10/18 11:01:05 jan Exp $
  *
  * Copyright 1999, 2000, 2001, 2002 Stephane Huther <shuther@bigfoot.com>
  * Copyright 2001, 2002 Chuck Hagenbuch <chuck@horde.org>
@@ -295,11 +295,7 @@ class DataTree_null extends DataTree {
             return PEAR::raiseError('no criteria');
         }
 
-        $cids = array();
-        foreach (array_keys($this->_attributeCache) as $cid) {
-            $cids[$cid] = null;
-        }
-        return $cids;
+        return array_keys($this->_attributeCache);
     }
 
     /**
