@@ -6,9 +6,9 @@
  * The params array should contain the names of the fields which will be
  * summed.
  *
- * $Horde: framework/Form/Form/Action/sum_fields.php,v 1.5 2004/10/19 19:03:01 chuck Exp $
+ * $Horde: framework/Form/Form/Action/sum_fields.php,v 1.5.10.4 2006/01/01 21:28:17 jan Exp $
  *
- * Copyright 2002-2004 Matt Kynaston <matt@kynx.org>
+ * Copyright 2002-2006 Matt Kynaston <matt@kynx.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -25,13 +25,13 @@ class Horde_Form_Action_sum_fields extends Horde_Form_Action {
         Horde::addScriptFile('form_helpers.js', 'horde', true);
 
         $form_name = $form->getName();
-        $fields = "'" . join("','", $this->_params) . "'";
+        $fields = "'" . implode("','", $this->_params) . "'";
         $js = array();
-        $js[] = sprintf('document.%s.%s.disabled = true;',
+        $js[] = sprintf('document.forms[\'%s\'].elements[\'%s\'].disabled = true;',
                         $form_name,
                         $varname);
         foreach ($this->_params as $field) {
-            $js[] = sprintf("addEvent(document.%s.%s, 'onchange', \"sumFields(this.form, '%s', %s);\");",
+            $js[] = sprintf("addEvent(document.forms['%1\$s'].elements['%2\$s'], \"onchange\", \"sumFields(document.forms['%1\$s'], '%3\$s', %4\$s);\");",
                             $form_name,
                             $field,
                             $varname,
