@@ -4,15 +4,14 @@
  * the value of one Horde_Form variable as the variable the action is
  * attached to is updated.
  *
- * $Horde: framework/Form/Form/Action/updatefield.php,v 1.5.12.1 2005/01/03 12:19:00 jan Exp $
+ * $Horde: framework/Form/Form/Action/updatefield.php,v 1.5.12.4 2006/01/01 21:28:17 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.5.12.1 $
  * @package Horde_Form
  */
 class Horde_Form_Action_updatefield extends Horde_Form_Action {
@@ -55,7 +54,7 @@ function updateField<?php echo $this->id() ?>()
 {
     var target = document.getElementById('<?php echo $this->getTarget() ?>');
     if (target) {
-        target.value = <?php echo implode(' + ', $args) ?>;
+        target.value = <?php echo implode(' + ', str_replace("\n", "\\n", $args)) ?>;
     }
 }<?php
         $this->_printJavaScriptEnd();
