@@ -3,7 +3,7 @@
  * The Horde_Form_Renderer class provides HTML and other renderings of
  * forms for the Horde_Form:: package.
  *
- * $Horde: framework/Form/Form/Renderer.php,v 1.185.4.14 2006/03/07 19:48:41 chuck Exp $
+ * $Horde: framework/Form/Form/Renderer.php,v 1.185.4.15 2006/04/15 18:05:04 chuck Exp $
  *
  * Copyright 2001-2006 Robert E. Coyle <robertecoyle@hotmail.com>
  *
@@ -138,7 +138,7 @@ class Horde_Form_Renderer {
         $open_section = $form->getOpenSection();
 
         /* Add the javascript for the toggling the sections. */
-        Horde::addScriptFile('form_sections.js', 'horde');
+        Horde::addScriptFile('form_sections.js', 'horde', true);
         echo '<script type="text/javascript">' . "\n";
         printf('var sections_%1$s = new Horde_Form_Sections(\'%1$s\', \'%2$s\');',
                $form->getName(),
