@@ -5,15 +5,14 @@
  * Provides a set of graph backends and methods for creating graphs as
  * HTML tables, SVG images, etc.
  *
- * $Horde: framework/Graph/Graph.php,v 1.27.10.1 2005/01/03 12:19:00 jan Exp $
+ * $Horde: framework/Graph/Graph.php,v 1.27.10.7 2006/01/01 21:28:18 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.27.10.1 $
  * @since   Horde 3.0
  * @package Horde_Graph
  */
@@ -21,8 +20,9 @@ class Horde_Graph {
 
     /**
      * The Horde_Image instance that we are drawing the graph to.
-     * @protected
-     * @var object Horde_Image $img
+     *
+     * @access protected
+     * @var Horde_Image
      */
     var $img;
 
@@ -159,7 +159,7 @@ class Horde_Graph {
     /**
      * Process all of the data sets and set graph properties.
      */
-    function initialize()
+    function initialize($minY = false, $stepLabelsY = false)
     {
         // Load a Horde_Image canvas to draw on.
         require_once 'Horde/Image.php';
@@ -190,15 +190,23 @@ class Horde_Graph {
             $ydata = array_merge($ydata, $data);
         }
 
+        $this->_maxX = count($this->_data['x']);
+        list($this->_minY, $this->_maxY) = $this->_findRange($ydata);
+        if ($minY !== false) {
+            $this->_minY = $minY;
+        }
+
+        $this->_diffY = $this->_maxY - $this->_minY;
+
         // Calculate the number of Y gridlines (and thus, labels) to
         // show. Try to make sure we don't end up with too dense a
         // grid, but also make sure that we have a few grid lines to
         // break up small datasets.
-        $this->_gridY = max(min($this->_gridY, floor($this->_graphHeight / 30)), floor($this->_graphHeight / 60));
-
-        $this->_maxX = count($this->_data['x']);
-        list($this->_minY, $this->_maxY) = $this->_findRange($ydata);
-        $this->_diffY = $this->_maxY - $this->_minY;
+        if ($stepLabelsY === false) {
+            $this->_gridY = max(min($this->_gridY, floor($this->_graphHeight / 30)), floor($this->_graphHeight / 60));
+        } else {
+            $this->_gridY = floor(($this->_maxY - $this->_minY) / $stepLabelsY);
+        }
 
         if (($this->_maxY - $this->_minY) == 0) {
             require_once 'PEAR.php';
@@ -206,7 +214,12 @@ class Horde_Graph {
         }
 
         // Format text for labeling the Y axis.
-        $deltaLabelsY = ($this->_maxY - $this->_minY) / ($this->_gridY);
+        if ($stepLabelsY === false) {
+            $deltaLabelsY = ($this->_maxY - $this->_minY) / ($this->_gridY);
+        } else {
+            $deltaLabelsY = $stepLabelsY;
+        }
+
         for ($i = 0; $i <= $this->_gridY; $i++) {
             $text = $this->_minY + ($deltaLabelsY * $i);
             $this->_labelsY[$i] = number_format($text, 2);
@@ -222,21 +235,25 @@ class Horde_Graph {
             $denominator = 1;
         }
         $this->_factorX = $this->_graphWidth / $denominator;
-        $this->_factorY = $this->_graphHeight / $this->_maxY;
+        $this->_factorY = $this->_graphHeight / $this->_diffY;
 
         $denominator = $this->_gridX - 1 + 2 * $this->_offsetGridX;
         if ($denominator == 0) {
             $denominator = 1;
         }
         $this->_deltaTicksX = ($this->_graphWidth / $denominator) / $this->_factorX;
-        $this->_deltaTicksY = ($this->_graphHeight / $this->_gridY) / $this->_factorY;
+        if ($stepLabelsY === false) {
+            $this->_deltaTicksY = ($this->_graphHeight / $this->_gridY) / $this->_factorY;
+        } else {
+            $this->_deltaTicksY = $stepLabelsY;
+        }
 
         return true;
     }
 
-    function draw($display = true)
+    function draw($display = true, $minY = false, $deltaLabelsY = false)
     {
-        $result = $this->initialize();
+        $result = $this->initialize($minY, $deltaLabelsY);
         if (is_a($result, 'PEAR_Error')) {
             return $result;
         }
@@ -254,7 +271,7 @@ class Horde_Graph {
             $this->drawLabelsY();
 
             for ($i = 0; $i < $plots; $i++) {
-                $this->_plots[$i]->draw();
+                $this->_plots[$i]->draw($this->_minY);
             }
         } elseif ($charts) {
             $this->drawTitle();
@@ -297,8 +314,8 @@ class Horde_Graph {
      */
     function drawGridY()
     {
-        for ($i = 0; $i < $this->_gridY; $i++) {
-            $y = $this->translateY($this->_deltaTicksY * $i);
+        for ($i = 0; $i <= $this->_gridY; $i++) {
+            $y = $this->translateY($this->_minY + $this->_deltaTicksY * $i);
             $this->img->dashedLine($this->_graphLeft, $y, $this->_graphRight, $y, 'gray');
         }
     }
@@ -351,7 +368,7 @@ class Horde_Graph {
         }
 
         foreach ($this->_labelsY as $i => $label) {
-            $y = $this->translateY($i * $this->_deltaTicksY);
+            $y = $this->translateY($this->_minY + $i * $this->_deltaTicksY);
             $this->img->text($label, $this->_graphLeft - (strlen($label) * 7), $y - 5, $this->_axisFont);
             $this->img->line($this->_graphLeft - 2, $y, $this->_graphLeft + 2, $y);
         }
@@ -390,7 +407,7 @@ class Horde_Graph {
     function translateY($y)
     {
         if ($y) {
-            return $this->_graphBottom - ($y * $this->_factorY);
+            return $this->_graphBottom - (($y - $this->_minY) * $this->_factorY);
         } else {
             return $this->_graphBottom;
         }
@@ -407,15 +424,16 @@ class Horde_Graph {
      * If $resolution is 2, then maximum value becomes 8650.
      * If $resolution is 3, then maximum value becomes 8645.
      *
-     * @param array   $data        The Dataset to find the range for.
-     * @param integer $min         (optional) Minimum value to start at. The lowest number
+     * @param array  $data         The Dataset to find the range for.
+     * @param integer $min         Minimum value to start at. The lowest number
      *                             in the dataset is used if it's lower.
-     * @param integer $max         (optional) Maximum value to start at. The highest number
-     *                             in the dataset is used if it's higher.
-     * @param integer $resolution  (optional) The resolution to use for the range.
+     * @param integer $max         Maximum value to start at. The highest
+     *                             number in the dataset is used if it's
+     *                             higher.
+     * @param integer $resolution  The resolution to use for the range.
      *
      * @return array  The minimum and maximum values for the range.
-     * @private
+     * @access private
      */
     function _findRange($data, $min = 0, $max = 0, $resolution = 0)
     {
