@@ -2,15 +2,14 @@
 /**
  * Line graph implementation for the Horde_Graph package.
  *
- * $Horde: framework/Graph/Graph/Plot/line.php,v 1.4.12.1 2005/01/03 12:19:00 jan Exp $
+ * $Horde: framework/Graph/Graph/Plot/line.php,v 1.4.12.4 2006/01/01 21:28:18 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.4.12.1 $
  * @since   Horde 3.0
  * @package Horde_Graph
  */
@@ -31,7 +30,7 @@ class Horde_Graph_Plot_line {
         }
     }
 
-    function draw()
+    function draw($minY = false)
     {
         $data = $this->_graph->_data['y'][$this->_dataset];
 
@@ -39,9 +38,20 @@ class Horde_Graph_Plot_line {
         $verts = array();
         for ($i = 0; $i < $count; $i++) {
             $x = $i;
-            $y = $data[$i];
-            $this->_graph->translate($x, $y);
-            $verts[] = array('x' => $x, 'y' => $y);
+            if ($minY !== false && $data[$i] < $minY) {
+                if (count($verts) == 1) {
+                    $this->_graph->img->circle($verts[0]['x'], $verts[0]['y'], $this->_width, $this->_color, $this->_color);
+                }
+                else {
+                    $this->_graph->img->polyline($verts, $this->_color, $this->_width);
+                }
+                $verts = array();
+            }
+            else {
+                $y = $data[$i];
+                $this->_graph->translate($x, $y);
+                $verts[] = array('x' => $x, 'y' => $y);
+            }
         }
 
         $this->_graph->img->polyline($verts, $this->_color, $this->_width);
