@@ -4,9 +4,9 @@
  * addition of adding support for hook functions to define if a user
  * is in a group.
  *
- * $Horde: framework/Group/Group/hooks.php,v 1.7.2.1 2005/01/03 12:19:01 jan Exp $
+ * $Horde: framework/Group/Group/hooks.php,v 1.7.2.10 2006/01/01 21:28:19 jan Exp $
  *
- * Copyright 2003-2005 Jason Rust <jrust@rustyparts.com>
+ * Copyright 2003-2006 Jason Rust <jrust@rustyparts.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -29,21 +29,27 @@ class Group_hooks extends Group {
     /**
      * Get a list of every group that $user is in.
      *
-     * @param string $user  The user to get groups for.
+     * @param string  $user          The user to get groups for.
+     * @param boolean $parentGroups  Also return the parents of any groups?
      *
      * @return array  An array of all groups the user is in.
      */
-    function getGroupMemberships($user)
+    function getGroupMemberships($user, $parentGroups = false)
     {
-        $memberships = parent::getGroupMemberships($user);
-        $funcs = get_defined_functions();
-        foreach ($funcs['user'] as $funcName) {
-            if (strpos($funcName, '_group_hook_') === 0) {
-                $groupName = substr($funcName, 12);
-                if (!in_array($groupName, $memberships) &&
-                    $this->exists($groupName) &&
-                    call_user_func($funcName, $user)) {
-                    $memberships[] = $groupName;
+        $memberships = parent::getGroupMemberships($user, $parentGroups);
+        $groups = $this->listGroups();
+        foreach ($groups as $gid => $group) {
+            if ($this->hasHook($group) &&
+                call_user_func($this->_getGroupHookName($group), $user)) {
+                $memberships += array($gid => $group);
+            }
+            if ($parentGroups) {
+                $parents = $this->getGroupParentList($gid);
+                foreach ($parents as $pid => $parent) {
+                    if ($this->hasHook($parent) &&
+                        call_user_func($this->_getGroupHookName($group), $user)) {
+                        $memberships += array($pid => $parent);
+                    }
                 }
             }
         }
@@ -54,16 +60,16 @@ class Group_hooks extends Group {
     /**
      * Say if a user is a member of a group or not.
      *
-     * @param          string  $user       The name of the user.
-     * @param          string  $group      The name of the group.
-     * @param optional boolean $subgroups  Return true if the user is in any subgroups
-     *                                     of $group, also.
+     * @param string  $user       The name of the user.
+     * @param integer $gid        The ID of the group.
+     * @param boolean $subgroups  Return true if the user is in any subgroups
+     *                            of $group, also.
      *
-     * @access public
      * @return boolean
      */
-    function userIsInGroup($user, $group, $subgroups = false)
+    function userIsInGroup($user, $gid, $subgroups = true)
     {
+        $group = $this->getGroupName($gid);
         if ($this->hasHook($group)) {
             if (call_user_func($this->_getGroupHookName($group), $user)) {
                 $inGroup = true;
@@ -74,7 +80,7 @@ class Group_hooks extends Group {
             $inGroup = false;
         }
 
-        if ($inGroup || parent::userIsInGroup($user, $group, $subgroups)) {
+        if ($inGroup || parent::userIsInGroup($user, $gid, $subgroups)) {
             return true;
         } else {
             return false;
@@ -86,7 +92,6 @@ class Group_hooks extends Group {
      *
      * @param string $name  The group name.
      *
-     * @access public
      * @return boolean  True if the group has a hook, false otherwise
      */
     function hasHook($name)
@@ -99,7 +104,6 @@ class Group_hooks extends Group {
      *
      * @param string $name  The group name.
      *
-     * @access public
      * @return string  The function name for the hook for this group
      */
     function _getGroupHookName($name)
