@@ -1,23 +1,26 @@
 <?php
 
-/** @constant HELP_SOURCE_RAW Raw help in the string. */
+/**
+ * Raw help in the string.
+ */
 define('HELP_SOURCE_RAW', 0);
 
-/** @constant HELP_SOURCE_FILE Help text is in a file. */
+/**
+ * Help text is in a file.
+ */
 define('HELP_SOURCE_FILE', 1);
 
 /**
  * The Help:: class provides an interface to the online help subsystem.
  *
- * $Horde: framework/Horde/Horde/Help.php,v 1.68.8.1 2005/01/03 12:19:02 jan Exp $
+ * $Horde: framework/Horde/Horde/Help.php,v 1.68.8.18 2006/03/02 05:27:35 slusarz Exp $
  *
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.68.8.1 $
  * @since   Horde 1.3
  * @package Horde_Framework
  */
@@ -26,77 +29,77 @@ class Help {
     /**
      * Handle for the XML parser object.
      *
-     * @var object $_parser
+     * @var resource
      */
     var $_parser = 0;
 
     /**
      * String buffer to hold the XML help source.
      *
-     * @var string $_buffer
+     * @var string
      */
     var $_buffer = '';
 
     /**
      * String containing the ID of the requested help entry.
      *
-     * @var string $_reqEntry
+     * @var string
      */
     var $_reqEntry = '';
 
     /**
      * String containing the ID of the current help entry.
      *
-     * @var string $_curEntry
+     * @var string
      */
     var $_curEntry = '';
 
     /**
      * String containing the formatted output.
      *
-     * @var string $_output
+     * @var string
      */
     var $_output = '';
 
     /**
      * Boolean indicating whether we're inside a <help> block.
      *
-     * @var boolean $_inHelp
+     * @var boolean
      */
     var $_inHelp = false;
 
     /**
      * Boolean indicating whether we're inside the requested block.
      *
-     * @var boolean $_inBlock
+     * @var boolean
      */
     var $_inBlock = false;
 
     /**
      * Boolean indicating whether we're inside a <title> block.
      *
-     * @var boolean $_inTitle
+     * @var boolean
      */
     var $_inTitle = false;
 
     /**
      * Hash containing an index of all of the help entries.
      *
-     * @var array $_entries
+     * @var array
      */
     var $_entries = array();
 
     /**
      * String containing the charset of the XML data source.
      *
-     * @var string $_charset
+     * @var string
      */
     var $_charset = 'iso-8859-1';
 
     /**
      * Hash of user-defined function handlers for the XML elements.
      *
-     * @var array $_handlers
+     * @var array
      */
     var $_handlers = array(
         'help'     =>  '_helpHandler',
@@ -109,6 +112,7 @@ class Help {
         'href'     =>  '_hrefHandler',
         'b'        =>  '_bHandler',
         'i'        =>  '_iHandler',
+        'pre'      =>  '_preHandler',
         'tip'      =>  '_tipHandler',
         'warn'     =>  '_warnHandler'
     );
@@ -116,12 +120,10 @@ class Help {
     /**
      * Constructor
      *
-     * @access public
-     *
-     * @param integer $source       The source of the XML help data, based
-     *                              on the HELP_SOURCE_* constants.
-     * @param optional string $arg  Source-dependent argument for this Help
-     *                              instance.
+     * @param integer $source  The source of the XML help data, based on the
+     *                         HELP_SOURCE_* constants.
+     * @param string $arg      Source-dependent argument for this Help
+     *                         instance.
      */
     function Help($source, $arg = null)
     {
@@ -131,7 +133,7 @@ class Help {
             Horde::fatal(PEAR::raiseError('The XML functions are not available. Rebuild PHP with --with-xml.'), __FILE__, __LINE__, false);
         }
 
-        $this->_charset = isset($nls['charsets'][$language]) ? $nls['charsets'][$language] : $nls['defaults']['charset'];
+        $this->_charset = isset($nls['charsets'][$language]) ? $nls['charsets'][$language] : 'ISO-8859-1';
 
         /* Populate $this->_buffer based on $source. */
         switch ($source) {
@@ -140,12 +142,12 @@ class Help {
             break;
 
         case HELP_SOURCE_FILE:
-            if (!(@file_exists($arg[0]) && ($fp = @fopen($arg[0], 'r')) && ($fs = @filesize($arg[0])) ||
-                 @file_exists($arg[1]) && ($fp = @fopen($arg[1], 'r')) && ($fs = @filesize($arg[1])))) {
-                $this->_buffer = '';
+            if (@file_exists($arg[0]) && @filesize($arg[0])) {
+                $this->_buffer = file_get_contents($arg[0]);
+            } elseif (@file_exists($arg[1]) && @filesize($arg[1])) {
+                $this->_buffer = file_get_contents($arg[1]);
             } else {
-                $this->_buffer = fread($fp, $fs);
-                fclose($fp);
+                $this->_buffer = '';
             }
             break;
 
@@ -159,8 +161,6 @@ class Help {
      * Generates the HTML link that will pop up a help window for the
      * requested topic.
      *
-     * @access public
-     *
      * @param string $module  The name of the current Horde module.
      * @param string $topic   The help topic to be displayed.
      *
@@ -175,24 +175,20 @@ class Help {
         }
 
         if ($browser->hasFeature('javascript')) {
-            Horde::addScriptFile('open_help_win.js', 'horde');
-            $html = Horde::link('#', _("Help"), '', '', "open_help_win('$module', '$topic'); return false;");
-        } else {
-            $url = Horde::url($registry->get('webroot', 'horde') . '/services/help/', true);
-            $url = Util::addParameter($url, 'module', $module);
-            $url = Util::addParameter($url, 'topic', $topic);
-            $html = Horde::link($url, '', '', '_hordehelpwin');
+            Horde::addScriptFile('popup.js', 'horde');
         }
-        $html .= Horde::img('help.png', _("Help"), 'width="16" height="16" align="middle"', $registry->getImageDir('horde')) . '</a>';
 
-        return $html;
+        $url = Horde::url($registry->get('webroot', 'horde') . '/services/help/', true);
+        $url = Util::addParameter($url, array('module' => $module,
+                                              'topic' => $topic));
+        $html = Horde::link($url, _("Help"), '', 'hordehelpwin', 'popup(this.href); return false;');
+
+        return $html . Horde::img('help.png', _("Help"), 'width="16" height="16"', $registry->getImageDir('horde')) . '</a>';
     }
 
     /**
      * Cleans up the Help class resources.
      *
-     * @access public
-     *
      * @return boolean  Returns true on success, false on failure.
      */
     function cleanup()
@@ -204,8 +200,6 @@ class Help {
     /**
      * Looks up the requested entry in the XML help buffer.
      *
-     * @access public
-     *
      * @param string $entry  String containing the entry ID.
      */
     function lookup($entry)
@@ -221,8 +215,6 @@ class Help {
     /**
      * Returns a hash of all of the topics in this help buffer.
      *
-     * @access public
-     *
      * @return array  Hash of all of the topics in this buffer.
      */
     function topics()
@@ -237,8 +229,6 @@ class Help {
 
     /**
      * Display the contents of the formatted output buffer.
-     *
-     * @access public
      */
     function display()
     {
@@ -308,7 +298,7 @@ class Help {
      */
     function _defaultHandler($parser, $data)
     {
-        $data = String::convertCharset($data, $this->_charset);
+        $data = String::convertCharset($data, version_compare(zend_version(), '2', '<') ? $this->_charset : 'UTF-8');
         if ($this->_inTitle) {
             $this->_entries[$this->_curEntry] .= $data;
         }
@@ -322,9 +312,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes (Not used).
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes (Not used).
      */
     function _helpHandler($startTag, $attrs = array())
     {
@@ -337,9 +327,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _entryHandler($startTag, $attrs = array())
     {
@@ -358,9 +348,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes (Not used).
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes (Not used).
      */
     function _titleHandler($startTag, $attrs = array())
     {
@@ -375,9 +365,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes (Not used).
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param  array $attrs      Additional element attributes (Not used).
      */
     function _headingHandler($startTag, $attrs = array())
     {
@@ -391,9 +381,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes (Not used).
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes (Not used).
      */
     function _paraHandler($startTag, $attrs = array())
     {
@@ -408,9 +398,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _refHandler($startTag, $attrs = array())
     {
@@ -433,9 +423,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _erefHandler($startTag, $attrs = array())
     {
@@ -454,9 +444,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _hrefHandler($startTag, $attrs = array())
     {
@@ -472,34 +462,50 @@ class Help {
     }
 
     /**
-     * XML element handler for the <b> tag.
+     * XML element handler for the &lt;b&gt; tag.
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes (Not used).
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes (Not used).
      */
     function _bHandler($startTag, $attrs = array())
     {
         if ($this->_inHelp && $this->_inBlock) {
-            $this->_output .= $startTag ? '<b>' : '</b>';
+            $this->_output .= $startTag ? '<strong>' : '</strong>';
         }
     }
 
     /**
-     * XML element handler for the <i> tag.
+     * XML element handler for the &lt;i&gt; tag.
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _iHandler($startTag, $attrs = array())
     {
         if ($this->_inHelp && $this->_inBlock) {
-            $this->_output .= $startTag ? '<i>' : '</i>';
+            $this->_output .= $startTag ? '<em>' : '</em>';
+        }
+    }
+
+    /**
+     * XML element handler for the &lt;pre&gt; tag.
+     *
+     * @access private
+     *
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
+     */
+    function _preHandler($startTag, $attrs = array())
+    {
+        if ($this->_inHelp && $this->_inBlock) {
+            $this->_output .= $startTag ? '<pre>' : '</pre>';
         }
     }
 
@@ -508,9 +514,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _tipHandler($startTag, $attrs = array())
     {
@@ -524,9 +530,9 @@ class Help {
      *
      * @access private
      *
-     * @param boolean $startTag      Boolean indicating whether this instance
-     *                               is a start tag.
-     * @param optional array $attrs  Additional element attributes.
+     * @param boolean $startTag  Boolean indicating whether this instance is a
+     *                           start tag.
+     * @param array $attrs       Additional element attributes.
      */
     function _warnHandler($startTag, $attrs = array())
     {
