@@ -7,7 +7,7 @@
  * This library allows more complex searches to be created (e.g. OR searches,
  * searching specific headers).
  *
- * $Horde: framework/IMAP/IMAP/Search.php,v 1.29.10.23 2006/02/01 09:13:33 jan Exp $
+ * $Horde: framework/IMAP/IMAP/Search.php,v 1.29.10.25 2006/06/06 15:44:27 slusarz Exp $
  *
  * Copyright 2003-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
@@ -98,7 +98,7 @@ class IMAP_Search {
      * by imap_search()).
      *
      * @param IMAP_Search_Query $query  The search query.
-     * @param resource &$imap           An IMAP resource stream.
+     * @param resource $imap            An IMAP resource stream.
      * @param string $mbox              The name of the mailbox to search. For
      *                                  POP3, this should be empty.
      *
@@ -106,7 +106,7 @@ class IMAP_Search {
      *                current mailbox.
      *                Returns PEAR_Error on error.
      */
-    function searchMailbox($query, &$imap, $mbox)
+    function searchMailbox($query, $imap, $mbox)
     {
         /* Check for IMAP extension. */
         if (!Util::extensionExists('imap')) {
@@ -115,7 +115,9 @@ class IMAP_Search {
 
         /* Open to the correct mailbox. */
         if (!$this->_params['pop3']) {
-            @imap_reopen($imap, $mbox, OP_READONLY);
+            if (!@imap_reopen($imap, $mbox, OP_READONLY)) {
+                return array();
+            }
         }
 
         /* Clear the search flag. */
@@ -128,7 +130,7 @@ class IMAP_Search {
      * Searches the mailbox and sorts the results.
      *
      * @param IMAP_Search_Query $query  The search query.
-     * @param resource &$imap           An IMAP resource stream.
+     * @param resource $imap            An IMAP resource stream.
      * @param string $mbox              The name of the mailbox to search.
      * @param integer $sortby           The criteria to sort by (see
      *                                  imap_sort()).
@@ -138,7 +140,7 @@ class IMAP_Search {
      *                current mailbox and sorted.
      *                Returns PEAR_Error on error.
      */
-    function searchSortMailbox($query, &$imap, $mbox, $sortby, $sortdir = 0)
+    function searchSortMailbox($query, $imap, $mbox, $sortby, $sortdir = 0)
     {
         $indices = $this->searchMailbox($query, $imap, $mbox);
         if (is_a($indices, 'PEAR_Error')) {
@@ -155,7 +157,7 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _imapSearch(&$imap, $criteria)
+    function _imapSearch($imap, $criteria)
     {
         if (!empty($this->_params['charset'])) {
             if (empty($this->_params['no_imap_charset']) &&
@@ -174,7 +176,7 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _searchMailbox($query, &$imap, $mbox)
+    function _searchMailbox($query, $imap, $mbox)
     {
         $indices = array();
 
@@ -246,7 +248,7 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _doAndOrSearch($query, &$imap, $mbox, $mode, $indices,
+    function _doAndOrSearch($query, $imap, $mbox, $mode, $indices,
                             $base = false)
     {
         if (empty($query)) {
@@ -291,14 +293,14 @@ class IMAP_Search {
      *
      * @access private
      *
-     * @param stdClass $imap_query  rch query.
+     * @param stdClass $imap_query  Search query.
      * @param string $flags         Any additional flags.
-     * @param resource &$imap       An IMAP resource stream.
+     * @param resource $imap        An IMAP resource stream.
      * @param string $mbox          The name of the search mailbox.
      *
      * @return array  The list of indices that match.
      */
-    function _searchPHP($imap_query, $flags, &$imap, $mbox)
+    function _searchPHP($imap_query, $flags, $imap, $mbox)
     {
         $indices = array();
 
