@@ -56,7 +56,7 @@ define('IMAPTREE_BASE_ELT', null);
  * functions to iterate through this tree and query information about
  * individual mailboxes/folders.
  *
- * $Horde: framework/IMAP/IMAP/Tree.php,v 1.48.2.41 2006/02/27 00:04:01 slusarz Exp $
+ * $Horde: framework/IMAP/IMAP/Tree.php,v 1.48.2.43 2006/05/12 16:29:29 slusarz Exp $
  *
  * Copyright 2000-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2000-2006 Jon Parise <jon@horde.org>
@@ -756,6 +756,10 @@ class IMAP_Tree {
      */
     function insert($id)
     {
+        if ($this->_mode == IMAPTREE_MODE_NEWS) {
+            return false;
+        }
+
         if (is_array($id)) {
             if (!$this->_nonimapelt) {
                 /* We want to add from the BASE of the tree up for efficiency
@@ -766,55 +770,35 @@ class IMAP_Tree {
             $id = array($id);
         }
 
-        $success = true;
+        $adds = array();
+
         foreach ($id as $val) {
-            $currsuccess = $this->_insert($val, 1);
-            if (!$currsuccess) {
-                $success = false;
+            $ns_info = $this->_getNamespace($val);
+            if (is_null($ns_info) || $this->_nonimapelt) {
+                $adds[] = $val;
+            } else {
+                /* Break apart the name via the delimiter and go step by step
+                 * through the name to make sure all subfolders exist in the
+                 * tree. */
+                $parts = explode($ns_info['delimiter'], $val);
+                $parts[0] = $this->_convertName($parts[0]);
+                for ($i = 0; $i < count($parts); $i++) {
+                    $adds[] = implode($ns_info['delimiter'], array_slice($parts, 0, $i + 1));
+                }
             }
         }
 
-        return $success;
-    }
+        foreach (array_unique($adds) as $id) {
+            if (isset($this->_tree[$id])) {
+                continue;
+            }
 
-    /**
-     * Insert a folder/mailbox into the tree.
-     *
-     * @access private
-     *
-     * @param string $id    The name of the folder to add (must be present on
-     *                      the mail server).
-     * @param integer $pos  Current delimiter position.
-     *
-     * @return boolean  True on success, false on error.
-     */
-    function _insert($id, $pos)
-    {
-        $this->_changed = true;
+            $this->_changed = true;
 
-        $ns_info = $this->_getNamespace($id);
-
-        /* Break apart the name via the delimiter and go step by step through
-         * the name to make sure all subfolders exist in the tree. */
-        if (is_null($ns_info)) {
-            $begin = $id;
-            $more = false;
-        } else {
-            $parts = explode($ns_info['delimiter'], $id);
-            $parts[0] = $this->_convertName($parts[0]);
-            $begin = implode($ns_info['delimiter'], array_slice($parts, 0, $pos));
-            $more = (count($parts) > $pos);
-        }
-
-        $iscontainer = (isset($this->_tree[$begin]) && $this->isContainer($this->_tree[$begin])) ? $this->_tree[$begin] : false;
-
-        if (($this->_mode != IMAPTREE_MODE_NEWS) &&
-            (!isset($this->_tree[$begin]) || $iscontainer) &&
-            (is_null($ns_info) || (($begin . $ns_info['delimiter']) != $ns_info['name']))) {
             if ($this->_nonimapelt) {
-                $elt = $this->_getNonIMAPElt($begin);
+                $elt = $this->_getNonIMAPElt($id);
             } else {
-                $ob = $this->_getList($begin);
+                $ob = $this->_getList($id);
                 $elt = $this->_makeMailboxTreeElt(reset($ob));
                 if (!$this->isSubscribed($elt)) {
                     $tmp = @imap_lsub($this->_getStream(), $this->_server, $elt['v']);
@@ -836,25 +820,16 @@ class IMAP_Tree {
                 }
 
                 /* Add to subscribed/unsubscribed list. */
-                if ($this->isSubscribed($elt) && !is_null($this->_subscribed)) {
+                if ($this->isSubscribed($elt) &&
+                    !is_null($this->_subscribed)) {
                     $this->_subscribed[$elt['v']] = 1;
                 } elseif (!$this->isSubscribed($elt) &&
                           !is_null($this->_unsubscribed)) {
                     $this->_unsubscribed[$elt['v']] = 1;
                 }
-
-                /* If this element was a container, maintain the old expanded
-                 * value. */
-                if ($iscontainer) {
-                    $this->_setOpen($this->_tree[$elt['v']], $this->isOpen($iscontainer));
-                }
             }
         }
 
-        if ($more) {
-            return $this->_insert($id, ++$pos);
-        }
-
         return true;
     }
 
@@ -871,11 +846,11 @@ class IMAP_Tree {
     function _insertElt($elt)
     {
         /* Don't include the parent directories that UW passes back in
-           %/% lists.
-           TODO: Remove dotfiles filter in next major release. */
+           %/% lists. */
         if (strlen($elt['l']) &&
             (!isset($this->_tree[$elt['v']]) ||
              $this->isContainer($this->_tree[$elt['v']])) &&
+            /* TODO: Remove dotfiles filter in next major release. */
             ($this->_dotfiles || ($elt['l'][0] != '.'))) {
             /* Set the parent array to the value in $elt['p']. */
             if (empty($this->_parent[$elt['p']])) {
@@ -1031,7 +1006,7 @@ class IMAP_Tree {
 
                 /* Do not delete from tree if there are child elements -
                  * instead, convert to a container element. */
-                if ($this->hasChildren($elt)) {
+                if (!$this->_showunsub && $this->hasChildren($elt)) {
                     $this->_setContainer($elt, true);
                 }
 
@@ -1718,7 +1693,9 @@ class IMAP_Tree {
     {
         $status = array();
 
-        $sts = @imap_status($this->_getStream(), $this->_server . $name, SA_MESSAGES | SA_UNSEEN | SA_RECENT);
+        require_once 'Horde/IMAP/Cache.php';
+        $imap_cache = &IMAP_Cache::singleton();
+        $sts = $imap_cache->getStatus($this->_getStream(), $this->_server . $name);
         if (!empty($sts)) {
             $status['messages'] = $sts->messages;
             $status['unseen'] = isset($sts->unseen) ? $sts->unseen : 0;
