@@ -4,7 +4,7 @@
  * methods take care of any site-specific restrictions configured in prefs.php
  * and conf.php.
  *
- * $Horde: framework/Identity/Identity.php,v 1.50.10.11 2006/01/20 01:30:05 jan Exp $
+ * $Horde: framework/Prefs/Identity.php,v 1.1.2.2 2006/06/28 20:52:53 jan Exp $
  *
  * Copyright 2001-2006 Jan Schneider <jan@horde.org>
  *
@@ -64,7 +64,8 @@ class Identity {
     function Identity($user = null)
     {
         $this->_user = $user;
-        if (is_null($user) || $user == Auth::getAuth()) {
+        if ((is_null($user) || $user == Auth::getAuth()) &&
+            isset($GLOBALS['prefs'])) {
             $this->_prefs = &$GLOBALS['prefs'];
         } else {
             $this->_prefs = &Prefs::singleton($GLOBALS['conf']['prefs']['driver'],
@@ -72,7 +73,6 @@ class Identity {
                                               $user, '', null, false);
             $this->_prefs->retrieve();
         }
-        $this->_default = $this->_prefs->getValue('default_identity');
 
         if (!($this->_identities = @unserialize($this->_prefs->getValue('identities', false)))) {
             /* Convert identities from the old format. */
@@ -80,6 +80,8 @@ class Identity {
         } elseif (is_array($this->_identities)) {
             $this->_identities = $this->_prefs->convertFromDriver($this->_identities, NLS::getCharset());
         }
+
+        $this->setDefault($this->_prefs->getValue('default_identity'));
     }
 
     /**
