@@ -5,17 +5,16 @@ require_once 'Horde/Image.php';
 /**
  * This class implements the Horde_Image:: API for ImageMagick.
  *
- * $Horde: framework/Image/Image/im.php,v 1.34.10.3 2005/03/17 18:10:13 jan Exp $
+ * $Horde: framework/Image/Image/im.php,v 1.34.10.11 2006/01/01 21:28:22 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2003-2005 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2003-2006 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 1.34.10.3 $
  * @since   Horde 3.0
  * @package Horde_Image
  */
@@ -23,7 +22,8 @@ class Horde_Image_im extends Horde_Image {
 
     /**
      * Capabilites of this driver.
-     * @var array $_capabilities
+     *
+     * @var array
      */
     var $_capabilities = array('resize',
                                'crop',
@@ -36,36 +36,40 @@ class Horde_Image_im extends Horde_Image {
                          );
 
     /**
-     * What kind of images should ImageMagick generate? Defaults to
-     * 'png'.
-     * @var string $_type
+     * What kind of images should ImageMagick generate? Defaults to 'png'.
+     *
+     * @var string
      */
     var $_type = 'png';
 
     /**
      * Operations to be performed.
-     * @var array $_operations
+     *
+     * @var array
      */
     var $_operations = array();
 
     /**
-     * Current stroke color; cached so we don't issue more -stroke
-     * commands than necessary.
-     * @var string $_strokeColor
+     * Current stroke color; cached so we don't issue more -stroke commands
+     * than necessary.
+     *
+     * @var string
      */
     var $_strokeColor = null;
 
     /**
      * Current stroke width; cached so we don't issue more -strokewidth
      * commands than necessary.
-     * @var string $_strokeWidth
+     *
+     * @var string
      */
     var $_strokeWidth = null;
 
     /**
-     * Current fill color; cached so we don't issue more -fill
-     * commands than necessary.
-     * @var string $_fillColor
+     * Current fill color; cached so we don't issue more -fill commands than
+     * necessary.
+     *
+     * @var string
      */
     var $_fillColor = null;
 
@@ -103,9 +107,9 @@ class Horde_Image_im extends Horde_Image {
     /**
      * Returns the raw data for this image.
      *
-     * @param bool $convert  If true, the image data will be returned in the
-     *                       target format, independently from any image
-     *                       operations.
+     * @param boolean $convert  If true, the image data will be returned in the
+     *                          target format, independently from any image
+     *                          operations.
      *
      * @return string  The raw image data.
      */
@@ -253,11 +257,11 @@ class Horde_Image_im extends Horde_Image {
     /**
      * Draw a circle.
      *
-     * @param integer $x      The x coordinate of the centre.
-     * @param integer $y      The y coordinate of the centre.
-     * @param integer $r      The radius of the circle.
-     * @param string  $color  The line color of the circle.
-     * @param string  $fill   (optional) The color to fill the circle.
+     * @param integer $x     The x coordinate of the centre.
+     * @param integer $y     The y coordinate of the centre.
+     * @param integer $r     The radius of the circle.
+     * @param string $color  The line color of the circle.
+     * @param string $fill   The color to fill the circle.
      */
     function circle($x, $y, $r, $color, $fill = 'none')
     {
@@ -271,10 +275,10 @@ class Horde_Image_im extends Horde_Image {
     /**
      * Draw a polygon based on a set of vertices.
      *
-     * @param array   $vertices  An array of x and y labeled arrays
-     *                           (eg. $vertices[0]['x'], $vertices[0]['y'], ...).
-     * @param string  $color     The color you want to draw the polygon with.
-     * @param string  $fill      (optional) The color to fill the polygon.
+     * @param array $vertices  An array of x and y labeled arrays
+     *                         (eg. $vertices[0]['x'], $vertices[0]['y'], ...).
+     * @param string $color    The color you want to draw the polygon with.
+     * @param string $fill     The color to fill the polygon.
      */
     function polygon($verts, $color, $fill = 'none')
     {
@@ -295,8 +299,8 @@ class Horde_Image_im extends Horde_Image {
      * @param integer $y       The top y-coordinate of the rectangle.
      * @param integer $width   The width of the rectangle.
      * @param integer $height  The height of the rectangle.
-     * @param string  $color   The line color of the rectangle.
-     * @param string  $fill    (optional) The color to fill the rectangle.
+     * @param string $color    The line color of the rectangle.
+     * @param string $fill     The color to fill the rectangle.
      */
     function rectangle($x, $y, $width, $height, $color, $fill = 'none')
     {
@@ -336,8 +340,8 @@ class Horde_Image_im extends Horde_Image {
      * @param integer $y0     The y coordinate of the start.
      * @param integer $x1     The x coordinate of the end.
      * @param integer $y1     The y coordinate of the end.
-     * @param string  $color  (optional) The line color.
-     * @param string  $width  (optional) The width of the line.
+     * @param string $color   The line color.
+     * @param string $width   The width of the line.
      */
     function line($x0, $y0, $x1, $y1, $color = 'black', $width = 1)
     {
@@ -346,14 +350,33 @@ class Horde_Image_im extends Horde_Image {
         $this->_operations[] = "-draw \"line $x0,$y0 $x1,$y1\"";
     }
 
+    /**
+     * Draw a dashed line.
+     *
+     * @param integer $x0           The x co-ordinate of the start.
+     * @param integer $y0           The y co-ordinate of the start.
+     * @param integer $x1           The x co-ordinate of the end.
+     * @param integer $y1           The y co-ordinate of the end.
+     * @param string $color         The line color.
+     * @param string $width         The width of the line.
+     * @param integer $dash_length  The length of a dash on the dashed line
+     * @param integer $dash_space   The length of a space in the dashed line
+     */
+    function dashedLine($x0, $y0, $x1, $y1, $color = 'black', $width = 1, $dash_length = 2, $dash_space = 2)
+    {
+        $this->setStrokeColor($color);
+        $this->setStrokeWidth($width);
+        $this->_operations[] = "-draw \"line $x0,$y0 $x1,$y1\"";
+    }
+
     /**
      * Draw a polyline (a non-closed, non-filled polygon) based on a
      * set of vertices.
      *
-     * @param array   $vertices  An array of x and y labeled arrays
-     *                           (eg. $vertices[0]['x'], $vertices[0]['y'], ...).
-     * @param string  $color     The color you want to draw the line with.
-     * @param string  $width     (optional) The width of the line.
+     * @param array $vertices  An array of x and y labeled arrays
+     *                         (eg. $vertices[0]['x'], $vertices[0]['y'], ...).
+     * @param string $color    The color you want to draw the line with.
+     * @param string $width    The width of the line.
      */
     function polyline($verts, $color, $width = 1)
     {
@@ -386,6 +409,9 @@ class Horde_Image_im extends Horde_Image {
 
         // Split up arcs greater than 180 degrees into two pieces.
         $mid = round(($start + $end) / 2);
+        $x = round($x);
+        $y = round($y);
+        $r = round($r);
         if ($mid > 90) {
             $this->_operations[] = "-draw \"ellipse $x,$y $r,$r $start,$mid\"";
             $this->_operations[] = "-draw \"ellipse $x,$y $r,$r $mid,$end\"";
