@@ -1,7 +1,6 @@
 <?php
 
 require_once dirname(__FILE__) . '/Message.php';
-require_once HORDE_BASE . '/config/mime_drivers.php';
 
 /**
  * The name of the URL parameter that holds the MIME_Contents cache
@@ -29,7 +28,7 @@ define('MIME_CONTENTS_DISPLAY_TYPE_BOTH', 2);
  * The MIME_Contents:: class contains functions related to handling the output
  * of MIME content.
  *
- * $Horde: framework/MIME/MIME/Contents.php,v 1.129.4.33 2006/03/08 16:40:39 slusarz Exp $
+ * $Horde: framework/MIME/MIME/Contents.php,v 1.129.4.35 2006/05/05 03:30:22 slusarz Exp $
  *
  * Copyright 2002-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
@@ -594,6 +593,7 @@ class MIME_Contents {
                 $default_charset = String::upper(NLS::getCharset());
                 if ($charset_upper != $default_charset) {
                     $mime_part->setContents(String::convertCharset($mime_part->getContents(), $charset, $default_charset));
+                    $mime_part->setCharset($default_charset);
                     if ($default_charset != 'UTF-8') {
                         $status = array(
                             sprintf(_("This message was written in a character set (%s) other than your own."), htmlspecialchars($charset)),
