@@ -3,33 +3,47 @@
 require_once 'Horde/String.php';
 require_once dirname(__FILE__) . '/../MIME.php';
 
-/** @constant MIME_PART_EOL The character(s) used internally for EOLs. */
+/**
+ * The character(s) used internally for EOLs.
+ */
 define('MIME_PART_EOL', "\n");
 
-/** @constant MIME_PART_RFC_EOL The character string designated by RFCs 822/2045 to designate EOLs in MIME messages. */
+/**
+ * The character string designated by RFCs 822/2045 to designate EOLs in MIME
+ * messages.
+ */
 define('MIME_PART_RFC_EOL', "\r\n");
 
 /* Default MIME parameters. */
-/** @constant MIME_DEFAULT_CHARSET The default MIME character set. */
+
+/**
+ * The default MIME character set.
+ */
 define('MIME_DEFAULT_CHARSET', 'us-ascii');
 
-/** @constant MIME_DEFAULT_DESCRIPTION The default MIME description. */
+/**
+ * The default MIME description.
+ */
 define('MIME_DEFAULT_DESCRIPTION', _("unnamed"));
 
-/** @constant MIME_DEFAULT_DISPOSITION The default MIME disposition. */
+/**
+ * The default MIME disposition.
+ */
 define('MIME_DEFAULT_DISPOSITION', 'inline');
 
-/** @constant MIME_DEFAULT_ENCODING The default MIME encoding. */
+/**
+ * The default MIME encoding.
+ */
 define('MIME_DEFAULT_ENCODING', '7bit');
 
 /**
  * The MIME_Part:: class provides a wrapper around MIME parts and methods
  * for dealing with them.
  *
- * $Horde: framework/MIME/MIME/Part.php,v 1.177.4.3 2005/02/22 07:45:50 slusarz Exp $
+ * $Horde: framework/MIME/MIME/Part.php,v 1.177.4.20 2006/03/09 21:59:31 chuck Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -45,7 +59,7 @@ class MIME_Part {
      * The type (ex.: text) of this part.
      * Per RFC 2045, the default is 'application'.
      *
-     * @var string $_type
+     * @var string
      */
     var $_type = 'application';
 
@@ -53,91 +67,91 @@ class MIME_Part {
      * The subtype (ex.: plain) of this part.
      * Per RFC 2045, the default is 'octet-stream'.
      *
-     * @var string $_subtype
+     * @var string
      */
     var $_subtype = 'octet-stream';
 
     /**
      * The body of the part.
      *
-     * @var string $_contents
+     * @var string
      */
     var $_contents = '';
 
     /**
      * The desired transfer encoding of this part.
      *
-     * @var string $_transferEncoding
+     * @var string
      */
     var $_transferEncoding = MIME_DEFAULT_ENCODING;
 
     /**
      * The current transfer encoding of the contents of this part.
      *
-     * @var string $_currentEncoding
+     * @var string
      */
     var $_currentEncoding = null;
 
     /**
      * Should the message be encoded via 7-bit?
      *
-     * @var boolean $_encode7bit
+     * @var boolean
      */
     var $_encode7bit = true;
 
     /**
      * The description of this part.
      *
-     * @var string $_description
+     * @var string
      */
     var $_description = '';
 
     /**
      * The disposition of this part (inline or attachment).
      *
-     * @var string $_disposition
+     * @var string
      */
     var $_disposition = MIME_DEFAULT_DISPOSITION;
 
     /**
      * The disposition parameters of this part.
      *
-     * @var array $_dispositionParameters
+     * @var array
      */
     var $_dispositionParameters = array();
 
     /**
      * The content type parameters of this part.
      *
-     * @var array $_contentTypeParameters
+     * @var array
      */
     var $_contentTypeParameters = array();
 
     /**
      * The subparts of this part.
      *
-     * @var array $_parts
+     * @var array
      */
     var $_parts = array();
 
     /**
      * Information/Statistics on the subpart.
      *
-     * @var array $_information
+     * @var array
      */
     var $_information = array();
 
     /**
      * The list of CIDs for this part.
      *
-     * @var array $_cids
+     * @var array
      */
     var $_cids = array();
 
     /**
      * The MIME ID of this part.
      *
-     * @var string $_mimeid
+     * @var string
      */
     var $_mimeid = null;
 
@@ -150,57 +164,53 @@ class MIME_Part {
      * It is not crucial here since the PHP/PEAR mailing functions will handle
      * the EOL details.
      *
-     * @var string $_eol
+     * @var string
      */
     var $_eol = MIME_PART_EOL;
 
     /**
      * Internal class flags.
      *
-     * @var array $_flags
+     * @var array
      */
     var $_flags = array();
 
     /**
      * Part -> ID mapping cache.
      *
-     * @var array $_idmap
+     * @var array
      */
     var $_idmap = array();
 
     /**
      * Unique MIME_Part boundary string.
      *
-     * @var string $_boundary
+     * @var string
      */
     var $_boundary = null;
 
     /**
      * Default value for this Part's size.
      *
-     * @var integer $_bytes
+     * @var integer
      */
     var $_bytes = 0;
 
     /**
      * The content-ID for this part.
      *
-     * @var string $_contentid
+     * @var string
      */
     var $_contentid = null;
 
     /**
      * MIME_Part constructor.
      *
-     * @access public
-     *
-     * @param optional string $mimetype     The content type of the part.
-     * @param optional string $contents     The body of the part.
-     * @param optional string $charset      The character set of the part.
-     * @param optional string $disposition  The content disposition of the
-     *                                      part.
-     * @param optional string $encoding     The content encoding of the
-     *                                      contents.
+     * @param string $mimetype     The content type of the part.
+     * @param string $contents     The body of the part.
+     * @param string $charset      The character set of the part.
+     * @param string $disposition  The content disposition of the part.
+     * @param string $encoding     The content encoding of the contents.
      */
     function MIME_Part($mimetype = null, $contents = null,
                        $charset = MIME_DEFAULT_CHARSET, $disposition = null,
@@ -227,8 +237,6 @@ class MIME_Part {
     /**
      * Set the content-disposition of this part.
      *
-     * @access public
-     *
      * @param string $disposition  The content-disposition to set (inline or
      *                             attachment).
      */
@@ -244,8 +252,6 @@ class MIME_Part {
     /**
      * Get the content-disposition of this part.
      *
-     * @access public
-     *
      * @return string  The part's content-disposition.
      */
     function getDisposition()
@@ -256,8 +262,6 @@ class MIME_Part {
     /**
      * Set the name of this part.
      *
-     * @access public
-     *
      * @param string $name The name to set.
      */
     function setName($name)
@@ -268,12 +272,10 @@ class MIME_Part {
     /**
      * Get the name of this part.
      *
-     * @access public
-     *
-     * @param optional boolean $decode   MIME decode description?
-     * @param optional boolean $default  If the name parameter doesn't exist,
-     *                                   should we use the default name from
-     *                                   the description parameter?
+     * @param boolean $decode   MIME decode description?
+     * @param boolean $default  If the name parameter doesn't exist, should we
+     *                          use the default name from the description
+     *                          parameter?
      *
      * @return string  The name of the part.
      */
@@ -295,10 +297,8 @@ class MIME_Part {
     /**
      * Set the body contents of this part.
      *
-     * @access public
-     *
-     * @param string $contents           The part body.
-     * @param optional string $encoding  The current encoding of the contents.
+     * @param string $contents  The part body.
+     * @param string $encoding  The current encoding of the contents.
      */
     function setContents($contents, $encoding = null)
     {
@@ -310,13 +310,11 @@ class MIME_Part {
     /**
      * Add to the body contents of this part.
      *
-     * @access public
-     *
-     * @param string $contents           The contents to append to the current
-     *                                   part body.
-     * @param optional string $encoding  The current encoding of the contents.
-     *                                   If not specified, will try to auto
-     *                                   determine the encoding.
+     * @param string $contents  The contents to append to the current part
+     *                          body.
+     * @param string $encoding  The current encoding of the contents. If not
+     *                          specified, will try to auto determine the
+     *                          encoding.
      */
     function appendContents($contents, $encoding = null)
     {
@@ -325,8 +323,6 @@ class MIME_Part {
 
     /**
      * Clears the body contents of this part.
-     *
-     * @access public
      */
     function clearContents()
     {
@@ -338,8 +334,6 @@ class MIME_Part {
     /**
      * Return the body of the part.
      *
-     * @access public
-     *
      * @return string  The raw body of the part.
      */
     function getContents()
@@ -351,8 +345,6 @@ class MIME_Part {
      * Returns the contents in strict RFC 822 & 2045 output - namely, all
      * newlines end with the canonical <CR><LF> sequence.
      *
-     * @access public
-     *
      * @return string  The entire MIME part.
      */
     function getCanonicalContents()
@@ -363,8 +355,6 @@ class MIME_Part {
     /**
      * Transfer encode the contents (to the transfer encoding identified via
      * getTransferEncoding()) and set as the part's new contents.
-     *
-     * @access public
      */
     function transferEncodeContents()
     {
@@ -376,8 +366,6 @@ class MIME_Part {
 
     /**
      * Transfer decode the contents and set them as the new contents.
-     *
-     * @access public
      */
     function transferDecodeContents()
     {
@@ -397,8 +385,6 @@ class MIME_Part {
     /**
      * Set the mimetype of this part.
      *
-     * @access public
-     *
      * @param string $mimetype  The mimetype to set (ex.: text/plain).
      */
     function setType($mimetype)
@@ -434,11 +420,8 @@ class MIME_Part {
      /**
       * Get the full MIME Content-Type of this part.
       *
-      * @access public
-      *
-      * @param optional boolean $charset  Append character set information to
-      *                                   the end of the content type if this
-      *                                   is a text/* part.
+      * @param boolean $charset  Append character set information to the end of
+      *                          the content type if this is a text/* part.
       *
       * @return string  The mimetype of this part
       *                 (ex.: text/plain; charset=us-ascii).
@@ -461,8 +444,6 @@ class MIME_Part {
      * default type should be used instead (See RFC 2046).  This method
      * returns the default subtype for a particular primary MIME Type.
      *
-     * @access public
-     *
      * @return string  The default mimetype of this part (ex.: text/plain).
      */
     function getDefaultType()
@@ -486,8 +467,6 @@ class MIME_Part {
     /**
      * Get the primary type of this part.
      *
-     * @access public
-     *
      * @return string  The primary MIME type of this part.
      */
     function getPrimaryType()
@@ -498,8 +477,6 @@ class MIME_Part {
     /**
      * Get the subtype of this part.
      *
-     * @access public
-     *
      * @return string  The MIME subtype of this part.
      */
     function getSubType()
@@ -510,9 +487,7 @@ class MIME_Part {
     /**
      * Set the character set of this part.
      *
-     * @access public
-     *
-     * @param optional string $charset  The character set of this part.
+     * @param string $charset  The character set of this part.
      */
     function setCharset($charset)
     {
@@ -520,31 +495,22 @@ class MIME_Part {
     }
 
     /**
-     * Get the character set of this part. This function only will return
-     * data if this is a text/* part.
-     *
-     * @access public
+     * Get the character set to use for of this part.  Returns a charset for
+     * all types (not just 'text/*') since we use this charset to determine
+     * how to encode text in MIME headers.
      *
      * @return string  The character set of this part.  Returns null if there
      *                 is no character set.
      */
     function getCharset()
     {
-        /* If this is not a text/* part, character set isn't pertinent. */
-        if ($this->getPrimaryType() != 'text') {
-            return null;
-        }
-
         $charset = $this->getContentTypeParameter('charset');
-
         return (empty($charset)) ? null : $charset;
     }
 
     /**
      * Set the description of this part.
      *
-     * @access public
-     *
      * @param string $description  The description of this part.
      */
     function setDescription($description)
@@ -555,12 +521,10 @@ class MIME_Part {
     /**
      * Get the description of this part.
      *
-     * @access public
-     *
-     * @param optional boolean $decode   MIME decode description?
-     * @param optional boolean $default  If the name parameter doesn't exist,
-     *                                   should we use the default name from
-     *                                   the description parameter?
+     * @param boolean $decode   MIME decode description?
+     * @param boolean $default  If the name parameter doesn't exist, should we
+     *                          use the default name from the description
+     *                          parameter?
      *
      * @return string  The description of this part.
      */
@@ -585,8 +549,6 @@ class MIME_Part {
     /**
      * Set the transfer encoding to use for this part.
      *
-     * @access public
-     *
      * @param string $encoding  The transfer encoding to use.
      */
     function setTransferEncoding($encoding)
@@ -605,11 +567,9 @@ class MIME_Part {
     /**
      * Add a MIME subpart.
      *
-     * @access public
-     *
-     * @param object MIME_Part $mime_part  Add a MIME_Part subpart to the
-     *                                     current MIME_Part.
-     * @param optional string $index       The index of the added MIME_Part.
+     * @param MIME_Part $mime_part  Add a MIME_Part subpart to the current
+     *                              MIME_Part.
+     * @param string $index         The index of the added MIME_Part.
      */
     function addPart($mime_part, $index = null)
     {
@@ -642,8 +602,6 @@ class MIME_Part {
     /**
      * Get a list of all MIME subparts.
      *
-     * @access public
-     *
      * @return array  An array of the MIME_Part subparts.
      */
     function getParts()
@@ -654,36 +612,49 @@ class MIME_Part {
     /**
      * Retrieve a specific MIME part.
      *
-     * @access public
-     *
      * @param string $id  The MIME_Part ID string.
      *
-     * @return object MIME_Part  The MIME_Part requested.  Returns false if
-     *                           the part doesn't exist.
+     * @return MIME_Part  The MIME_Part requested, or false if the part
+     *                    doesn't exist.
      */
     function getPart($id)
     {
-        $orig = null;
         $mimeid = $this->getMIMEId();
 
+        /* This will convert '#.0' to simply '#', which is how the part is
+         * internally stored. */
+        $search_id = $id;
+        if (($str = strrchr($id, '.')) &&
+            ($str == '.0')) {
+            $search_id = substr($search_id, 0, -2);
+        }
+
         /* Return this part if:
            1) There is only one part (e.g. the MIME ID is 0, or the
               MIME ID is 1 and there are no subparts.
            2) $id matches this parts MIME ID. */
-        if (($id == 0) ||
-            (($id == 1) && !count($this->_parts)) ||
-            (!empty($mimeid) && ($id == $mimeid))) {
-            return $this;
+        if (($search_id == 0) ||
+            (($search_id == 1) && !count($this->_parts)) ||
+            (!empty($mimeid) && ($search_id == $mimeid))) {
+            $part = $this;
+        } else {
+            $part = $this->_partFind($id, $this->_parts);
         }
 
-        return $this->_partFind($id, $this->_parts);
+        if ($part &&
+            ($search_id != $id) &&
+            ($part->getType() == 'message/rfc822')) {
+            $ret_part = Util::cloneObject($part);
+            $ret_part->_parts = array();
+            return $ret_part;
+        }
+
+        return $part;
     }
 
     /**
      * Remove a MIME_Part subpart.
      *
-     * @access public
-     *
      * @param string $id  The MIME Part to delete.
      */
     function removePart($id)
@@ -697,10 +668,8 @@ class MIME_Part {
     /**
      * Alter a current MIME subpart.
      *
-     * @access public
-     *
-     * @param string $id                   The MIME Part ID to alter.
-     * @param object MIME_Part $mime_part  The MIME Part to store.
+     * @param string $id            The MIME Part ID to alter.
+     * @param MIME_Part $mime_part  The MIME Part to store.
      */
     function alterPart($id, $mime_part)
     {
@@ -715,11 +684,11 @@ class MIME_Part {
      *
      * @access private
      *
-     * @param string $id                  The MIME_Part ID string.
-     * @param array &$parts               A list of MIME_Part objects.
-     * @param optional boolean $retarray  Return a pointer to the array that
-     *                                    stores (would store) the part
-     *                                    rather than the part itself?
+     * @param string $id         The MIME_Part ID string.
+     * @param array &$parts      A list of MIME_Part objects.
+     * @param boolean $retarray  Return a pointer to the array that stores
+     *                           (would store) the part rather than the part
+     *                           itself?
      */
     function &_partFind($id, &$parts, $retarray = false)
     {
@@ -744,7 +713,8 @@ class MIME_Part {
         if (isset($this->_idmap[$id])) {
             return $this->_idmap[$id];
         } else {
-            return false;
+            $part = false;
+            return $part;
         }
     }
 
@@ -769,8 +739,6 @@ class MIME_Part {
     /**
      * Add information about the MIME_Part.
      *
-     * @access public
-     *
      * @param string $label  The information label.
      * @param mixed $data    The information to store.
      */
@@ -782,8 +750,6 @@ class MIME_Part {
     /**
      * Retrieve information about the MIME_Part.
      *
-     * @access public
-     *
      * @param string $label  The information label.
      *
      * @return mixed  The information requested.
@@ -797,8 +763,6 @@ class MIME_Part {
     /**
      * Add a disposition parameter to this part.
      *
-     * @access public
-     *
      * @param string $label  The disposition parameter label.
      * @param string $data   The disposition parameter data.
      */
@@ -810,8 +774,6 @@ class MIME_Part {
     /**
      * Get a disposition parameter from this part.
      *
-     * @access public
-     *
      * @param string $label  The disposition parameter label.
      *
      * @return string  The data requested.
@@ -825,8 +787,6 @@ class MIME_Part {
     /**
      * Get all parameters from the Content-Disposition header.
      *
-     * @access public
-     *
      * @return array  An array of all the parameters
      *                Returns the empty array if no parameters set.
      */
@@ -838,8 +798,6 @@ class MIME_Part {
     /**
      * Add a content type parameter to this part.
      *
-     * @access public
-     *
      * @param string $label  The disposition parameter label.
      * @param string $data   The disposition parameter data.
      */
@@ -851,8 +809,6 @@ class MIME_Part {
     /**
      * Clears a content type parameter from this part.
      *
-     * @access public
-     *
      * @param string $label  The disposition parameter label.
      * @param string $data   The disposition parameter data.
      */
@@ -864,8 +820,6 @@ class MIME_Part {
     /**
      * Get a content type parameter from this part.
      *
-     * @access public
-     *
      * @param string $label  The content type parameter label.
      *
      * @return string  The data requested.
@@ -879,8 +833,6 @@ class MIME_Part {
     /**
      * Get all parameters from the Content-Type header.
      *
-     * @access public
-     *
      * @return array  An array of all the parameters
      *                Returns the empty array if no parameters set.
      */
@@ -892,8 +844,6 @@ class MIME_Part {
     /**
      * Sets a new string to use for EOLs.
      *
-     * @access public
-     *
      * @param string $eol  The string to use for EOLs.
      */
     function setEOL($eol)
@@ -904,8 +854,6 @@ class MIME_Part {
     /**
      * Get the string to use for EOLs.
      *
-     * @access public
-     *
      * @return string  The string to use for EOLs.
      */
     function getEOL()
@@ -916,10 +864,7 @@ class MIME_Part {
     /**
      * Add the appropriate MIME headers for this part to an existing array.
      *
-     * @access public
-     *
-     * @param optional array $headers  An array of any other headers for the
-     *                                 part.
+     * @param array $headers  An array of any other headers for the part.
      *
      * @return array  The headers, with the MIME headers added.
      */
@@ -940,7 +885,7 @@ class MIME_Part {
             if ($key == 'charset') {
                 continue;
             }
-            $ctype .= '; ' . $key . '="' . MIME::encode($value, $charset) . '"';
+            $ctype .= '; ' . $key . '="' . str_replace('"', '\"', MIME::encode($value, $charset)) . '"';
         }
         $headers['Content-Type'] = MIME::wrapHeaders('Content-Type', $ctype, $eol);
 
@@ -991,9 +936,7 @@ class MIME_Part {
     /**
      * Return the entire part in MIME format. Includes headers on request.
      *
-     * @access public
-     *
-     * @param optional boolean $headers  Include the MIME headers?
+     * @param boolean $headers  Include the MIME headers?
      *
      * @return string  The MIME string.
      */
@@ -1050,9 +993,7 @@ class MIME_Part {
      * Returns the encoded part in strict RFC 822 & 2045 output - namely, all
      * newlines end with the canonical <CR><LF> sequence.
      *
-     * @access public
-     *
-     * @param optional boolean $headers  Include the MIME headers?
+     * @param boolean $headers  Include the MIME headers?
      *
      * @return string  The entire MIME part.
      */
@@ -1066,8 +1007,6 @@ class MIME_Part {
      * Should we make sure the message is encoded via 7-bit (e.g. to adhere
      * to mail delivery standards such as RFC 2821)?
      *
-     * @access public
-     *
      * @param boolean $use7bit  Use 7-bit encoding?
      */
     function strict7bit($use7bit)
@@ -1079,8 +1018,6 @@ class MIME_Part {
      * Get the transfer encoding for the part based on the user requested
      * transfer encoding and the current contents of the part.
      *
-     * @access public
-     *
      * @return string  The transfer-encoding of this part.
      */
     function getTransferEncoding()
@@ -1102,44 +1039,43 @@ class MIME_Part {
                base64 or q-p, switch it to 8bit instead.
                RFC 2046 [5.2.2, 5.2.3, 5.2.4] - All other message/* messages
                only allow 7bit encodings. */
-            if ($this->getSubType() == 'rfc822') {
-                $encoding = '8bit';
-            } else {
-                $encoding = '7bit';
-            }
+            $encoding = ($this->getSubType() == 'rfc822') ? '8bit' : '7bit';
             break;
 
         case 'text':
             if (MIME::is8bit($text)) {
-                if ($this->_encode7bit) {
-                    $encoding = 'quoted-printable';
-                } else {
-                    $encoding = '8bit';
-                }
+                $encoding = ($this->_encode7bit) ? 'quoted-printable' : '8bit';
+            } elseif (preg_match("/(?:\n|^)[^\n]{999,}(?:\n|$)/", $text)) {
+                /* If the text is longer than 998 characters between
+                 * linebreaks, use quoted-printable encoding to ensure the
+                 * text will not be chopped (i.e. by sendmail if being sent
+                 * as mail text). */
+                $encoding = 'quoted-printable';
             }
             break;
 
         default:
-            /* By default, if there is 8bit data, we MUST either 8bit or
-               base64 encode contents. */
             if (MIME::is8bit($text)) {
-                if ($this->_encode7bit) {
-                    $encoding = 'base64';
-                } else {
-                    $encoding = '8bit';
-                }
+                $encoding = ($this->_encode7bit) ? 'base64' : '8bit';
             }
             break;
         }
 
+        /* Need to do one last check for binary data if encoding is 7bit or
+         * 8bit.  If the message contains a NULL character at all, the message
+         * MUST be in binary format. RFC 2046 [2.7, 2.8, 2.9]. Q-P and base64
+         * can handle binary data fine so no need to switch those encodings. */
+        if ((($encoding == '8bit') || ($encoding == '7bit')) &&
+            preg_match('/\x00/', $text)) {
+            $encoding = ($this->_encode7bit) ? 'base64' : 'binary';
+        }
+
         return $encoding;
     }
 
     /**
      * Retrieves the current encoding of the contents in the object.
      *
-     * @access public
-     *
      * @return string  The current encoding.
      */
     function getCurrentEncoding()
@@ -1150,8 +1086,6 @@ class MIME_Part {
     /**
      * Encodes the contents with the part's transfer encoding.
      *
-     * @access public
-     *
      * @return string  The encoded text.
      */
     function transferEncode()
@@ -1195,8 +1129,6 @@ class MIME_Part {
     /**
      * Decodes the contents of the part to either a 7bit or 8bit encoding.
      *
-     * @access public
-     *
      * @return string  The decoded text.
      *                 Returns the empty string if there is no text to decode.
      */
@@ -1228,6 +1160,13 @@ class MIME_Part {
         case 'uuencode':
         case 'x-uuencode':
         case 'x-uue':
+            if (function_exists('convert_uudecode')) {
+                $message = convert_uuencode($this->_contents);
+            } else {
+                require_once 'Mail/mimeDecode.php';
+                $files = &Mail_mimeDecode::uudecode($this->_contents);
+                $message = $files[0]['filedata'];
+            }
             require_once 'Mail/mimeDecode.php';
             $files = &Mail_mimeDecode::uudecode($this->_contents);
             $message = $files[0]['filedata'];
@@ -1256,8 +1195,6 @@ class MIME_Part {
      * The boundary content-type parameter must be set for this function to
      * work correctly.
      *
-     * @access public
-     *
      * @return boolean  True if the contents were successfully split.
      *                  False if any error occurred.
      */
@@ -1302,11 +1239,9 @@ class MIME_Part {
      * Replace newlines in this part's contents with those specified by either
      * the given newline sequence or the part's current EOL setting.
      *
-     * @access public
-     *
-     * @param string $text          The text to replace.
-     * @param optional string $eol  The EOL sequence to use. If not present,
-     *                              uses the part's current EOL setting.
+     * @param string $text  The text to replace.
+     * @param string $eol   The EOL sequence to use. If not present, uses the
+     *                      part's current EOL setting.
      *
      * @return string  The text with the newlines replaced by the desired
      *                 newline sequence.
@@ -1325,8 +1260,6 @@ class MIME_Part {
      * since a user defined 'boundary' Content-Type parameter will override
      * this value.
      *
-     * @access public
-     *
      * @return string  The unique boundary string.
      */
     function getUniqueID()
@@ -1337,8 +1270,6 @@ class MIME_Part {
     /**
      * Determine the size of a MIME_Part and its child members.
      *
-     * @access public
-     *
      * @return integer  Size of the MIME_Part, in bytes.
      */
     function getBytes()
@@ -1374,8 +1305,6 @@ class MIME_Part {
      * object from IMAP header information without loading the data of the
      * part).
      *
-     * @access public
-     *
      * @param integer $bytes  The size of this part in bytes.
      */
     function setBytes($bytes)
@@ -1386,8 +1315,6 @@ class MIME_Part {
     /**
      * Output the size of this MIME_Part in KB.
      *
-     * @access public
-     *
      * @return string  Size of the MIME_Part, in string format.
      */
     function getSize()
@@ -1404,8 +1331,6 @@ class MIME_Part {
     /**
      * Add to the list of CIDs for this part.
      *
-     * @access public
-     *
      * @param array $cids  A list of MIME IDs of the part.
      *                     Key - MIME ID
      *                     Value - CID for the part
@@ -1418,8 +1343,6 @@ class MIME_Part {
     /**
      * Returns the list of CIDs for this part.
      *
-     * @access public
-     *
      * @return array  The list of CIDs for this part.
      */
     function getCIDList()
@@ -1431,10 +1354,8 @@ class MIME_Part {
     /**
      * Sets the Content-ID header for this part.
      *
-     * @access public
-     *
-     * @param optional string $cid  Use this CID (if not already set).  Else,
-     *                              generate a random CID.
+     * @param string $cid  Use this CID (if not already set).  Else, generate a
+     *                     random CID.
      */
     function setContentID($cid = null)
     {
@@ -1445,9 +1366,17 @@ class MIME_Part {
     }
 
     /**
-     * Alter the MIME ID of this part.
+     * Returns the Content-ID for this part.
      *
-     * @access public
+     * @return string  The Content-ID for this part.
+     */
+    function getContentID()
+    {
+        return $this->_contentid;
+    }
+
+    /**
+     * Alter the MIME ID of this part.
      *
      * @param string $mimeid  The MIME ID.
      */
@@ -1459,8 +1388,6 @@ class MIME_Part {
     /**
      * Returns the MIME ID of this part.
      *
-     * @access public
-     *
      * @return string  The MIME ID.
      */
     function getMIMEId()
@@ -1473,8 +1400,6 @@ class MIME_Part {
      * e.g., if the base part has MIME ID of 2, and you want the first
      * subpart of the base part, the relative MIME ID is 2.1.
      *
-     * @access public
-     *
      * @param string $id  The relative part ID.
      *
      * @return string  The relative MIME ID.
@@ -1488,8 +1413,6 @@ class MIME_Part {
     /**
      * Returns a mapping of all MIME IDs to their content-types.
      *
-     * @access public
-     *
      * @return array  KEY: MIME ID, VALUE: Content type
      */
     function contentTypeMap()
