@@ -6,7 +6,7 @@ require_once dirname(__FILE__) . '/source.php';
  * The MIME_Viewer_css class renders CSS source as HTML with an effort
  * to remove potentially malicious code.
  *
- * $Horde: framework/MIME/MIME/Viewer/css.php,v 1.1.10.7 2006/01/01 21:28:24 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/css.php,v 1.1.10.8 2006/06/01 03:08:53 chuck Exp $
  *
  * Copyright 2004-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -35,7 +35,7 @@ class MIME_Viewer_css extends MIME_Viewer_source {
         $css = trim($css);
 
         // Educated Guess at whether we are inline or not.
-        if (headers_sent()) {
+        if (headers_sent() || ob_get_length()) {
             return $this->lineNumber($css);
         } else {
             return Util::bufferOutput('require', $GLOBALS['registry']->get('templates', 'horde') . '/common-header.inc') .
