@@ -3,7 +3,7 @@
  * The MIME_Viewer_html class renders out HTML text with an effort to
  * remove potentially malicious code.
  *
- * $Horde: framework/MIME/MIME/Viewer/html.php,v 1.14.4.19 2006/02/16 16:44:14 chuck Exp $
+ * $Horde: framework/MIME/MIME/Viewer/html.php,v 1.14.4.20 2006/06/07 13:34:16 jan Exp $
  *
  * Copyright 1999-2006 Anil Madhavapeddy <anil@recoil.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -99,7 +99,7 @@ class MIME_Viewer_html extends MIME_Viewer {
             for ($i = 0; $i < $links; $i++) {
                 $m[1][$i] = strtolower(urldecode($m[1][$i]));
                 $m[2][$i] = strtolower(preg_replace('/^(http|https|ftp):\/\//', '', strip_tags($m[2][$i])));
-                if (preg_match('/^[.-_\da-z]+\.[a-z]{2,}/i', $m[2][$i]) &&
+                if (preg_match('/^[-._\da-z]+\.[a-z]{2,}/i', $m[2][$i]) &&
                     strpos($m[1][$i], $m[2][$i]) !== 0 &&
                     strpos($m[2][$i], $m[1][$i]) !== 0) {
                     /* Don't consider the link a phishing link if the domain
