@@ -2,47 +2,29 @@
 /**
  * The MIME_Viewer_images class allows images to be displayed.
  *
- * $Horde: framework/MIME/MIME/Viewer/images.php,v 1.18.8.1 2005/01/03 12:19:06 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/images.php,v 1.18.8.9 2006/01/01 21:28:25 jan Exp $
  *
- * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.18.8.1 $
  * @since   Horde 2.2
  * @package Horde_MIME_Viewer
  */
 class MIME_Viewer_images extends MIME_Viewer {
 
-    /**
-     * Render out the currently set contents.
-     * The $mime_part class variable has the information to render
-     * out, encapsulated in a MIME_Part object.
-     */
-    function render()
-    {
-        global $browser;
-
-        if ($browser->isViewable($this->getType())) {
-            return $this->mime_part->getContents();
-        }
-    }
-
     /**
      * Return the content-type.
      *
-     * @access public
-     *
      * @return string  The content-type of the output.
      */
     function getType()
     {
-        global $browser;
-
         $type = $this->mime_part->getType();
-        if ($browser->isBrowser('mozilla') && ($type == 'image/pjpeg')) {
+        if ($GLOBALS['browser']->isBrowser('mozilla') &&
+            ($type == 'image/pjpeg')) {
             /* image/jpeg and image/pjpeg *appear* to be the same
              * entity, but Mozilla don't seem to want to accept the
              * latter.  For our purposes, we will treat them the
@@ -74,7 +56,7 @@ class MIME_Viewer_images extends MIME_Viewer {
 <html>
 <head>
 <title>$title</title>
-<style type="text/css"><!-- body { overflow:hidden; margin:0px; padding:0px; } --></style>
+<style type="text/css"><!-- body { margin:0px; padding:0px; } --></style>
 EOD;
 
         /* Only use javascript if we are using a DOM capable browser. */
@@ -82,37 +64,30 @@ EOD;
             /* Translate '&amp' entities to '&' for JS URL links. */
             $url = str_replace('&amp;', '&', $url);
 
+            /* Mozilla and IE determine window dimensions in different ways. */
+            if ($browser->isBrowser('msie')) {
+                $iWidth_code = 'document.body.clientWidth;';
+                $iHeight_code = 'document.body.clientHeight;';
+            } else {
+                $iWidth_code = 'window.innerWidth;';
+                $iHeight_code = 'window.innerHeight;';
+            }
+
             /* Javascript display. */
             $loading = _("Loading...");
             $str .= <<<EOD
-<script language="javascript" type="text/javascript">
+<script type="text/javascript">
 function resizeWindow() {
     window.moveTo(0, 0);
-    var img = new Image();
-    img.onload = function() { sizeImgWin(img); };
-    img.src = "$url";
-}
-
-function sizeImgWin(img) {
-    var new_w = img.width;
-    var new_h = img.height;
-    var old_w = window.innerWidth || window.document.body.offsetWidth;
-    var old_h = window.innerHeight || window.document.body.offsetHeight;
-
-    if (!new_w) { new_w = old_w; }
-    if (!new_h) { new_h = old_h; }
-
-    new_w -= old_w;
-    new_h -= old_h;
-
-    window.resizeBy(new_w, new_h);
     document.getElementById('splash').style.display = 'none';
-    var pic = document.getElementById('disp_image');
-    pic.src = img.src;
-    pic.style.display = 'block';
+    document.getElementById('disp_image').style.display = 'block';
+    var iWidth = document.images[0].width - $iWidth_code
+    var iHeight = document.images[0].height - $iHeight_code
+    window.resizeBy(iWidth, iHeight);
+    self.focus(); 
 }
 </script></head>
-<body onload="resizeWindow();"><span id="splash" style="color:gray;font-family:sans-serif;padding:2px;">$loading</span><img id="disp_image" style="display:none;" /></body></html>
+<body onload="resizeWindow();"><span id="splash" style="color:gray;font-family:sans-serif;padding:2px;">$loading</span><img id="disp_image" style="display:none;" src="$url" /></body></html>
 EOD;
         } else {
             /* Non-javascript display. */
