@@ -3,15 +3,14 @@
  * The MIME_Viewer_msword class renders out Microsoft Word
  * documents in HTML format by using the wvWare package.
  *
- * $Horde: framework/MIME/MIME/Viewer/msword.php,v 1.25.10.2 2005/01/16 14:24:47 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/msword.php,v 1.25.10.8 2006/01/01 21:28:25 jan Exp $
  *
- * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2006 Anil Madhavapeddy <anil@recoil.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.25.10.2 $
  * @since   Horde 1.3
  * @package Horde_MIME_Viewer
  */
@@ -20,9 +19,7 @@ class MIME_Viewer_msword extends MIME_Viewer {
     /**
      * Render out the current data using wvWare.
      *
-     * @access public
-     *
-     * @param optional array $params  Any parameters the Viewer may need.
+     * @param array $params  Any parameters the Viewer may need.
      *
      * @return string  The rendered contents.
      */
@@ -46,7 +43,7 @@ class MIME_Viewer_msword extends MIME_Viewer {
         } else {
             $version = exec($mime_drivers['horde']['msword']['location'] . ' --version');
             if (version_compare($version, '0.7.0') >= 0) {
-                $args = " --targetdir=$tmp_dir $tmp_word $tmp_file";
+                $args = " --charset=" . NLS::getCharset() . " --targetdir=$tmp_dir $tmp_word $tmp_file";
             } else {
                 $args = " $tmp_word $tmp_output";
             }
@@ -67,16 +64,14 @@ class MIME_Viewer_msword extends MIME_Viewer {
             $data .= $rc;
         }
         fclose($fh);
-        
+
         return $data;
     }
 
     /**
      * Return the MIME content type of the rendered content.
      *
-     * @access public
-     *
-     * @return string  The content type of the output. 
+     * @return string  The content type of the output.
      */
     function getType()
     {
