@@ -6,7 +6,7 @@ require_once dirname(__FILE__) . '/source.php';
  * The MIME_Viewer_php class renders out syntax-highlighted PHP code
  * in HTML format.
  *
- * $Horde: framework/MIME/MIME/Viewer/php.php,v 1.22.10.7 2006/01/01 21:28:25 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/php.php,v 1.22.10.8 2006/06/01 03:08:53 chuck Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -32,7 +32,7 @@ class MIME_Viewer_php extends MIME_Viewer_source {
                                     highlight_string($this->mime_part->getContents(), true)));
 
         // Educated Guess at whether we are inline or not.
-        if (headers_sent()) {
+        if (headers_sent() || ob_get_length()) {
             return $this->lineNumber($results);
         } else {
             return Util::bufferOutput('require', $GLOBALS['registry']->get('templates', 'horde') . '/common-header.inc') .
