@@ -13,7 +13,7 @@ define('HORDE_MENU_MASK_ALL',     15);
  * The Menu:: class provides standardized methods for creating menus in
  * Horde applications.
  *
- * $Horde: framework/Horde/Horde/Menu.php,v 1.35.2.10 2006/01/01 21:28:20 jan Exp $
+ * $Horde: framework/Horde/Horde/Menu.php,v 1.35.2.11 2006/07/20 04:31:27 slusarz Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -172,7 +172,7 @@ class Menu {
         /* Add help link. */
         require_once 'Horde/Help.php';
         if ($this->_mask & HORDE_MENU_MASK_HELP && $help_link = Horde::getServiceLink('help', $app)) {
-            $this->add($help_link, _("_Help"), 'help_index.png', $graphics, 'help', 'popup(this.href); return false;');
+            $this->add($help_link, _("Help"), 'help_index.png', $graphics, 'help', 'popup(this.href); return false;');
         }
 
         /* Login/Logout. */
