@@ -3,15 +3,14 @@
  * Horde_Mobile_Renderer:: framework for mobile device markup
  * renderers.
  *
- * $Horde: framework/Mobile/Mobile/Renderer.php,v 1.15.10.1 2005/01/03 12:19:07 jan Exp $
+ * $Horde: framework/Mobile/Mobile/Renderer.php,v 1.15.10.8 2006/01/01 21:28:26 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.15.10.1 $
  * @since   Horde 3.0
  * @package Horde_Mobile
  */
@@ -43,7 +42,7 @@ class Horde_Mobile_Renderer extends Horde_Mobile {
      * appropriate rendering function in the renderer; if there isn't
      * one, we ignore this element.
      *
-     * @param object Horde_Mobile_element $element  The element to render.
+     * @param Horde_Mobile_element $element  The element to render.
      */
     function renderElement(&$element)
     {
@@ -97,17 +96,14 @@ class Horde_Mobile_Renderer extends Horde_Mobile {
      * Attempts to return a concrete Horde_Mobile_Renderer instance
      * based on $type.
      *
-     * @access public
+     * @param string $type      The kind of markup (html, hdml, wml) we want to
+     *                          generate.
+     * @param Browser $browser  The Browser object to use.
+     * @param array $params     A hash containing any options for the renderer.
      *
-     * @param string $type             The kind of markup (html, hdml, wml)
-     *                                 we want to generate.
-     * @param optional object Browser  The Browser object to use.
-     * @param optional array $params   A hash containing any
-     *                                 options for the renderer.
-     *
-     * @return object Horde_Mobile_Renderer   The newly created concrete
-     *                                        Horde_Mobile_Renderer instance, or
-     *                                        a PEAR_Error object on an error.
+     * @return Horde_Mobile_Renderer  The newly created concrete
+     *                                Horde_Mobile_Renderer instance, or a
+     *                                PEAR_Error object on an error.
      */
     function &factory($type, $browser = null, $params = array())
     {
@@ -118,12 +114,15 @@ class Horde_Mobile_Renderer extends Horde_Mobile {
         } else {
             @include_once 'Horde/Mobile/Renderer/' . $type . '.php';
         }
+
         $class = 'Horde_Mobile_Renderer_' . $type;
         if (class_exists($class)) {
-            return $ret = &new $class($browser, $params);
+            $renderer = &new $class($browser, $params);
         } else {
-            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
+            $renderer = PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
+
+        return $renderer;
     }
 
     /**
@@ -131,28 +130,21 @@ class Horde_Mobile_Renderer extends Horde_Mobile {
      * based on $type. It will only create a new instance if no
      * renderer with the same parameters currently exists.
      *
-     * @access public
+     * @param string $type      The kind of markup (html, hdml, wml) we want to
+     *                          generate.
+     * @param Browser $browser  The Browser object to use.
+     * @param array $params     A hash containing any options for the renderer.
      *
-     * @param string $type             The kind of markup (html, hdml, wml)
-     *                                 we want to generate.
-     * @param optional object Browser  The Browser object to use.
-     * @param optional array $params   A hash containing any
-     *                                 options for the renderer.
-     *
-     * @return object Horde_Mobile_Renderer   The newly created concrete
-     *                                        Horde_Mobile_Renderer instance, or
-     *                                        a PEAR_Error object on an error.
+     * @return Horde_Mobile_Renderer  The newly created concrete
+     *                                Horde_Mobile_Renderer instance, or a
+     *                                PEAR_Error object on an error.
      */
     function &singleton($type, $browser = null, $params = array())
     {
-        static $instances;
+        static $instances = array();
 
-        if (!isset($instances)) {
-            $instances = array();
-        }
-
-        $signature = serialize(array($type, $browser, $params));
-        if (!array_key_exists($signature, $instances)) {
+        $signature = md5(serialize(array($type, $browser, $params)));
+        if (!isset($instances[$signature])) {
             $instances[$signature] = &Horde_Mobile_Renderer::factory($type, $browser, $params);
         }
 
