@@ -4,9 +4,9 @@
  * raising and showing messages of different types and to different
  * listeners.
  *
- * $Horde: framework/Notification/Notification.php,v 1.46.2.1 2005/01/03 12:19:09 jan Exp $
+ * $Horde: framework/Notification/Notification.php,v 1.46.2.11 2006/01/18 15:19:01 jan Exp $
  *
- * Copyright 2001-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -20,14 +20,14 @@ class Notification {
     /**
      * Hash containing all attached listener objects.
      *
-     * @var array $_listeners
+     * @var array
      */
     var $_listeners = array();
 
     /**
      * The name of the session variable where we store the messages.
      *
-     * @var string $_stack
+     * @var string
      */
     var $_stack = 'hordeMessageStacks';
 
@@ -40,7 +40,7 @@ class Notification {
      *
      * @param string $stack  The name of the message stack to use.
      *
-     * @return object Notification  The Horde Notification instance.
+     * @return Notification  The Horde Notification instance.
      */
     function &singleton($stack = 'hordeMessageStacks')
     {
@@ -75,31 +75,28 @@ class Notification {
      * Registers a listener with the notification object and includes
      * the necessary library file dynamically.
      *
-     * @param string $driver          The name of the listener to attach.
-     *                                These names must be unique; further
-     *                                listeners with the same name will be
-     *                                ignored.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters
-     *                                a listener driver might need.
-     * @param optional string $class  The class name from which the driver
-     *                                was instantiated if not the default
-     *                                one. If given you have to include the
-     *                                library file containing this class
-     *                                yourself.
-     *                                This is useful if you want the
-     *                                listener driver to be overriden by an
-     *                                application's implementation.
+     * @param string $driver  The name of the listener to attach. These names
+     *                        must be unique; further listeners with the same
+     *                        name will be ignored.
+     * @param array $params   A hash containing any additional configuration or
+     *                        connection parameters a listener driver might
+     *                        need.
+     * @param string $class   The class name from which the driver was
+     *                        instantiated if not the default one. If given
+     *                        you have to include the library file containing
+     *                        this class yourself. This is useful if you want
+     *                        the listener driver to be overriden by an
+     *                        application's implementation.
      */
     function &attach($listener, $params = array(), $class = null)
     {
         $listener = basename($listener);
         if (!empty($this->_listeners[$listener])) {
-            return false;
+            return $this->_listeners[$listener];
         }
 
         if (is_null($class)) {
-            require_once dirname(__FILE__) . '/Notification/Listener/' . $listener . '.php';
+            @require_once dirname(__FILE__) . '/Notification/Listener/' . $listener . '.php';
             $class = 'Notification_Listener_' . $listener;
         }
         if (class_exists($class)) {
@@ -109,16 +106,14 @@ class Notification {
             }
             return $this->_listeners[$listener];
         } else {
-            Horde::fatal(PEAR::raiseError(sprintf('Notification listener %s not found.', $listener)), __FILE__, __LINE__);
+            return PEAR::raiseError(sprintf('Notification listener %s not found.', $listener));
         }
     }
 
     /**
      * Remove a listener from the notification list.
      *
-     * @access public
-     *
-     * @param string $listner          The name of the listener to detach.
+     * @param string $listner  The name of the listener to detach.
      */
     function detach($listener)
     {
@@ -140,16 +135,14 @@ class Notification {
      * application defines its own Notification_Listener subclass that
      * handles additional codes.
      *
-     * @access public
-     *
-     * @param mixed $event      Notification_Event object or message string.
-     * @param optional integer $type  The type of message: 'horde.error',
-     *                                'horde.warning', 'horde.success', or
-     *                                'horde.message'.
-     * @param optional array $flags   Array of optional flags that will be
-     *                                passed to the registered listeners.
+     * @param mixed $event   Notification_Event object or message string.
+     * @param integer $type  The type of message: 'horde.error',
+     *                       'horde.warning', 'horde.success', or
+     *                       'horde.message'.
+     * @param array $flags   Array of optional flags that will be passed to the
+     *                       registered listeners.
      */
-    function push($event, $type = 'horde.message', $flags = array())
+    function push($event, $type = null, $flags = array())
     {
         if (!is_a($event, 'Notification_Event') &&
             !is_a($event, 'PEAR_Error')) {
@@ -159,8 +152,14 @@ class Notification {
             $event = &new Notification_Event($event);
         }
         if (is_a($event, 'PEAR_Error')) {
+            if (!isset($type)) {
+                $type = 'horde.error';
+            }
             Horde::logMessage($event, __FILE__, __LINE__, PEAR_LOG_DEBUG);
         }
+        if (!isset($type)) {
+            $type = 'horde.message';
+        }
 
         foreach ($this->_listeners as $listener) {
             if ($listener->handles($type)) {
@@ -177,10 +176,8 @@ class Notification {
      * Passes the message stack to all listeners and asks them to
      * handle their messages.
      *
-     * @access public
-     *
-     * @param optional array $options  An array containing display options
-     *                                 for the listeners.
+     * @param array $options  An array containing display options for the
+     *                        listeners.
      */
     function notify($options = array())
     {
@@ -199,13 +196,9 @@ class Notification {
      *
      * @author David Ulevitch <davidu@everydns.net>
      *
-     * @access public
-     *
-     * @param optional string $my_listener  The name of the listener.
+     * @param string $my_listener  The name of the listener.
      *
      * @return integer  The number of messages in the stack.
-     *
-     * @since Horde 2.2
      */
     function count($my_listener = null)
     {
