@@ -21,7 +21,7 @@ define('PERMS_ALL', PERMS_SHOW | PERMS_READ | PERMS_EDIT | PERMS_DELETE);
 /**
  * The Perms:: class provides the Horde permissions system.
  *
- * $Horde: framework/Perms/Perms.php,v 1.80.10.8 2006/01/01 21:28:31 jan Exp $
+ * $Horde: framework/Perms/Perms.php,v 1.80.10.9 2006/05/05 04:08:59 selsky Exp $
  *
  * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2004-2006 Jan Schneider <jan@horde.org>
@@ -119,7 +119,8 @@ class Perms {
         /* If there are several components to the name, explode and
          * get the last one, otherwise just return the name. */
         if (strpos($name, ':') !== false) {
-            return array_pop(explode(':', $name));
+            $tmp = explode(':', $name);
+            return array_pop($tmp);
         } else {
             return $name;
         }
