@@ -6,7 +6,7 @@ require_once 'Horde/DataTree.php';
  * The Perms_datatree:: class provides a DataTree driver for the Horde
  * permissions system.
  *
- * $Horde: framework/Perms/Perms/datatree.php,v 1.6.2.10 2006/01/08 17:50:46 chuck Exp $
+ * $Horde: framework/Perms/Perms/datatree.php,v 1.6.2.12 2006/07/20 18:50:05 chuck Exp $
  *
  * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2004-2006 Jan Schneider <jan@horde.org>
@@ -137,7 +137,11 @@ class Perms_datatree extends Perms {
      */
     function &getPermissionById($cid)
     {
-        $object = $this->_datatree->getObjectById($cid, 'DataTreeObject_Permission');
+        if ($cid == DATATREE_ROOT) {
+            $object = &$this->newPermission(DATATREE_ROOT);
+        } else {
+            $object = &$this->_datatree->getObjectById($cid, 'DataTreeObject_Permission');
+        }
         return $object;
     }
 
@@ -650,12 +654,11 @@ class DataTreeObject_Permission extends DataTreeObject {
      */
     function removeUserPermission($user, $permission, $update = true)
     {
-        if (empty($user)) {
+        if (empty($user) || !isset($this->data['users'][$user])) {
             return;
         }
 
-        if ($this->get('type') == 'matrix' &&
-            isset($this->data['users'][$user])) {
+        if ($this->get('type') == 'matrix') {
             $this->data['users'][$user] &= ~$permission;
             if (empty($this->data['users'][$user])) {
                 unset($this->data['users'][$user]);
@@ -679,8 +682,11 @@ class DataTreeObject_Permission extends DataTreeObject {
      */
     function removeGuestPermission($permission, $update = true)
     {
-        if ($this->get('type') == 'matrix' &&
-            isset($this->data['guest'])) {
+        if (!isset($this->data['guest'])) {
+            return;
+        }
+
+        if ($this->get('type') == 'matrix') {
             $this->data['guest'] &= ~$permission;
             if ($update) {
                 $this->save();
@@ -703,8 +709,11 @@ class DataTreeObject_Permission extends DataTreeObject {
      */
     function removeCreatorPermission($permission, $update = true)
     {
-        if ($this->get('type') == 'matrix' &&
-            isset($this->data['creator'])) {
+        if (!isset($this->data['creator'])) {
+            return;
+        }
+
+        if ($this->get('type') == 'matrix') {
             $this->data['creator'] &= ~$permission;
             if ($update) {
                 $this->save();
@@ -727,8 +736,11 @@ class DataTreeObject_Permission extends DataTreeObject {
      */
     function removeDefaultPermission($permission, $update = true)
     {
-        if ($this->get('type') == 'matrix' &&
-            isset($this->data['default'])) {
+        if (!isset($this->data['default'])) {
+            return;
+        }
+
+        if ($this->get('type') == 'matrix') {
             $this->data['default'] &= ~$permission;
             if ($update) {
                 $this->save();
@@ -753,12 +765,11 @@ class DataTreeObject_Permission extends DataTreeObject {
      */
     function removeGroupPermission($groupId, $permission, $update = true)
     {
-        if (empty($groupId)) {
+        if (empty($groupId) || !isset($this->data['groups'][$groupId])) {
             return;
         }
 
-        if ($this->get('type') == 'matrix' &&
-            isset($this->data['groups'][$groupId])) {
+        if ($this->get('type') == 'matrix') {
             $this->data['groups'][$groupId] &= ~$permission;
             if (empty($this->data['groups'][$groupId])) {
                 unset($this->data['groups'][$groupId]);
