@@ -1,7 +1,5 @@
 <?php
 
-// Preference constants (bitmasks)
-
 /**
  * Preference is administratively locked.
  */
@@ -22,8 +20,6 @@ define('_PREF_DIRTY', 4);
  */
 define('_PREF_DEFAULT', 8);
 
-require_once 'Horde/String.php';
-
 /**
  * The Prefs:: class provides a common abstracted interface into the
  * various preferences storage mediums.  It also includes all of the
@@ -52,7 +48,7 @@ require_once 'Horde/String.php';
  *     'help'   => *Name of the entry in the XML help file*
  * );
  *
- * $Horde: framework/Prefs/Prefs.php,v 1.137.10.20 2006/02/28 06:06:46 slusarz Exp $
+ * $Horde: framework/Prefs/Prefs.php,v 1.137.10.27 2006/07/03 17:38:11 chuck Exp $
  *
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
@@ -161,10 +157,7 @@ class Prefs {
             /* Place each preference in the cache according to its
              * scope. */
             foreach ($prefs as $name => $pref) {
-                $scope = $this->getScope($name);
-                if (isset($_SESSION['prefs_cache'][$scope])) {
-                    $_SESSION['prefs_cache'][$scope][$name] = $pref;
-                }
+                $_SESSION['prefs_cache'][$this->getScope($name)][$name] = $pref;
             }
         }
     }
@@ -537,9 +530,7 @@ class Prefs {
     }
 
     /**
-     * This method should be overridden by a subclass
-     * implementation. It's here to retain code integrity in the case
-     * that no subclass is loaded ($driver == 'none').
+     * Retrieves the default preferences.
      */
     function retrieve()
     {
@@ -551,15 +542,11 @@ class Prefs {
     }
 
     /**
-     * This is an abstract method that should be overridden by a
-     * subclass implementation. It's here to retain code integrity in
-     * the case that no subclass is loaded ($driver == 'none').
-     *
-     * This function will be run at the end of every request as a
-     * shutdown function (registered by the Prefs:: constructor).  All
-     * prefs with the dirty bit set will be saved to the storage
-     * backend at this time; thus, there is no need to manually call
-     * $prefs->store() every time a preference is changed.
+     * This function will be run at the end of every request as a shutdown
+     * function (registered by the Prefs:: constructor).  All prefs with the
+     * dirty bit set will be saved to the storage backend at this time; thus,
+     * there is no need to manually call $prefs->store() every time a
+     * preference is changed.
      *
      * @abstract
      */
@@ -713,7 +700,7 @@ class Prefs {
         }
 
         global $registry;
-        include $registry->get('fileroot', 'horde') . '/config/hooks.php';
+        include_once $registry->get('fileroot', 'horde') . '/config/hooks.php';
         foreach ($this->_hooks as $pref) {
             if ($this->isLocked($pref) ||
                 !$this->getValue($pref) ||
@@ -752,8 +739,7 @@ class Prefs {
             $driver = $driver[1];
         }
 
-        /* Attempt to register (cache) the $prefs hash in session
-         * storage. */
+        /* Attempt to register (cache) the $prefs hash in session storage. */
         if ($caching) {
             if (!isset($_SESSION['prefs_cache'])) {
                 $_SESSION['prefs_cache'] = array();
@@ -762,18 +748,16 @@ class Prefs {
 
         $driver = basename($driver);
         if (empty($driver) || $driver == 'none') {
-            $prefs = &new Prefs();
-            $prefs->_scope = $scope;
-            return $prefs;
+            $driver = 'session';
         }
 
         if (is_null($params)) {
             $params = Horde::getDriverConfig('prefs', $driver);
         }
 
-        /* If $params['user_hook'] is defined, use it to retrieve the
-           value to use for the username ($this->_user). Otherwise,
-           just use the value passed in the $user parameter. */
+        /* If $params['user_hook'] is defined, use it to retrieve the value to
+         * use for the username ($this->_user). Otherwise, just use the value
+         * passed in the $user parameter. */
         if (!empty($params['user_hook']) &&
             function_exists($params['user_hook'])) {
             $user = call_user_func($params['user_hook'], $user);
@@ -781,10 +765,10 @@ class Prefs {
 
         if (!empty($app)) {
             require_once $GLOBALS['registry']->get('fileroot', $app) . '/lib/Prefs/' . $driver . '.php';
-        } elseif (@file_exists(dirname(__FILE__) . '/Prefs/' . $driver . '.php')) {
+        } elseif (file_exists(dirname(__FILE__) . '/Prefs/' . $driver . '.php')) {
             require_once dirname(__FILE__) . '/Prefs/' . $driver . '.php';
         } else {
-            @include_once 'Horde/Prefs/' . $driver . '.php';
+            include_once 'Horde/Prefs/' . $driver . '.php';
         }
 
         $class = 'Prefs_' . $driver;
