@@ -3,15 +3,14 @@
  * Class for handling a list of categories stored in a user's
  * preferences.
  *
- * $Horde: framework/Prefs/Prefs/CategoryManager.php,v 1.11.10.1 2005/01/03 12:19:11 jan Exp $
+ * $Horde: framework/Prefs/Prefs/CategoryManager.php,v 1.11.10.5 2006/01/01 21:28:32 jan Exp $
  *
- * Copyright 2004-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2004-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.11.10.1 $
  * @since   Horde 3.0
  * @package Horde_Prefs
  */
@@ -43,28 +42,27 @@ class Prefs_CategoryManager {
 
         $categories = Prefs_CategoryManager::get();
         if (!in_array($current, $categories) && !empty($current)) {
-            $html .= '<option value="*new*' . htmlspecialchars($current) . '">' . sprintf(_("Use Current: %s"), htmlspecialchars($current)) . '</option>';
-            $html .= '<option value="">----</option>';
+            $html .= '<option value="*new*' . htmlspecialchars($current) . '">' . sprintf(_("Use Current: %s"), htmlspecialchars($current)) . '</option>' .
+                '<option value="">----</option>';
         }
 
         if (!$prefs->isLocked('categories')) {
-            $html .= '<option value="*new*">' . _("New Category") . "</option>\n";
-            $html .= '<option value="">----</option>';
+            $html .= '<option value="*new*">' . _("New Category") . "</option>\n" .
+                '<option value="">----</option>';
         }
 
         // Always add an Unfiled option.
-        $html .= '<option value=""';
-        $html .= empty($current) ? ' selected="selected">' : '>';
-        $html .= htmlspecialchars(_("Unfiled")) . '</option>';
+        $html .= '<option value=""' .
+            (empty($current) ? ' selected="selected">' : '>') .
+            htmlspecialchars(_("Unfiled")) . '</option>';
 
         foreach ($categories as $name) {
-            $html .= '<option value="' . htmlspecialchars($name) . '"';
-            $html .= ($name == $current) ? ' selected="selected">' : '>';
-            $html .= htmlspecialchars($name) . '</option>';
+            $html .= '<option value="' . htmlspecialchars($name) . '"' .
+                ($name === $current ? ' selected="selected">' : '>') .
+                htmlspecialchars($name) . '</option>';
         }
-        $html .= '</select>';
 
-        return $html;
+        return $html . '</select>';
     }
 
     function getJavaScript($formname, $elementname)
@@ -74,7 +72,7 @@ class Prefs_CategoryManager {
 
         return <<<JAVASCRIPT
 
-<script language="JavaScript" type="text/javascript">
+<script type="text/javascript">
 <!--
 function checkCategory()
 {
@@ -197,7 +195,7 @@ JAVASCRIPT;
         $colors = Prefs_CategoryManager::colors();
         $fgcolors = array();
         foreach ($colors as $name => $color) {
-            $fgcolors[$name] = Horde_Image::brightness($color) < 128 ? '#f6f6f6' : 'black';
+            $fgcolors[$name] = Horde_Image::brightness($color) < 128 ? '#f6f6f6' : '#000';
         }
 
         return $fgcolors;
