@@ -1,4 +1,10 @@
 <?php
+
+/**
+ * Horde_String class.
+ */
+require_once 'Horde/String.php';
+
 /**
  * Preferences storage implementation for PHP's LDAP extention.
  *
@@ -41,7 +47,7 @@
  * </pre>
  *
  *
- * $Horde: framework/Prefs/Prefs/ldap.php,v 1.85.10.18 2006/02/28 05:59:19 slusarz Exp $
+ * $Horde: framework/Prefs/Prefs/ldap.php,v 1.85.10.20 2006/06/21 20:07:55 jan Exp $
  *
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
@@ -166,6 +172,21 @@ class Prefs_ldap extends Prefs {
             }
         }
 
+        /* If necessary, bind to the LDAP server as the user with search
+         * permissions. */
+        if (!empty($this->_params['searchdn'])) {
+            $bind = @ldap_bind($conn, $this->_params['searchdn'],
+                               $this->_params['searchpass']);
+            if (!$bind) {
+                return PEAR::raiseError(sprintf('Bind to server %s:%d with DN %s failed: [%d] %s',
+                                                $this->_params['hostspec'],
+                                                $this->_params['port'],
+                                                $this->_params['searchdn'],
+                                                ldap_errno($this->_connection),
+                                                ldap_error($this->_connection)));
+            }
+	}
+
         /* Register our callback function to handle referrals. */
         if (function_exists('ldap_set_rebind_proc') &&
             !ldap_set_rebind_proc($conn, array($this, '_rebindProc'))) {
