@@ -11,7 +11,7 @@ define('HORDE_SESSION_READONLY', 2);
  * between Horde applications and keeping track of application
  * configuration information.
  *
- * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.20 2006/02/12 22:47:15 mrubinsk Exp $
+ * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.22 2006/05/04 22:35:26 jan Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -162,9 +162,6 @@ class Registry {
             } else {
                 $this->_usecache = true;
             }
-            /* Call any function triggers which may have been set in the
-             * session. */
-            Horde::sessionCallbacks();
         }
 
         /* Initialize the localization routines and variables. */
@@ -943,7 +940,7 @@ class Registry {
         /* If there is no logged in user, return an empty Prefs::
          * object with just default preferences. */
         if (!Auth::getAuth()) {
-            $prefs = &Prefs::factory('none', $app, '', '', null, false);
+            $prefs = &Prefs::factory('session', $app, '', '', null, false);
             $prefs->retrieve();
             $this->_prefsCache[$app] = &$prefs;
             $GLOBALS['prefs'] = &$this->_prefsCache[$app];
