@@ -2,15 +2,14 @@
 /**
  * This class provides attributes methods for any existing SQL class.
  *
- * $Horde: framework/SQL/SQL/Attributes.php,v 1.14.10.1 2005/01/03 12:19:12 jan Exp $
+ * $Horde: framework/SQL/SQL/Attributes.php,v 1.14.10.9 2006/01/01 21:28:33 jan Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.14.10.1 $
  * @since   Horde 2.2
  * @package Horde_SQL
  */
@@ -18,7 +17,8 @@ class Horde_SQL_Attributes {
 
     /**
      * The PEAR::DB object to run queries with.
-     * @var object DB $_db
+     *
+     * @var DB
      */
     var $_db;
 
@@ -27,22 +27,24 @@ class Horde_SQL_Attributes {
      *   id_column       - The primary id column to use in joins.
      *   primary_table   - The main table name.
      *   attribute_table - The table that the attributes are stored in.
-     * @var array $_params
+     *
+     * @var array
      */
     var $_params = array();
 
     /**
-     * The number of copies of the attributes table that we need to
-     * join on in the current query.
-     * @var integer $_table_count
+     * The number of copies of the attributes table that we need to join on in
+     * the current query.
+     *
+     * @var integer
      */
     var $_table_count = 1;
 
     /**
      * Constructor.
      *
-     * @param object DB $dbh     A PEAR::DB object.
-     * @param array     $params  The id column, table names, etc.
+     * @param DB $dbh        A PEAR::DB object.
+     * @param array $params  The id column, table names, etc.
      */
     function Horde_SQL_Attributes($dbh, $params)
     {
@@ -152,27 +154,28 @@ class Horde_SQL_Attributes {
     }
 
     /**
-     * Given a new attribute set and an id, insert each into the
-     * DB. If anything fails in here, rollback the transaction, return
-     * the relevant error and bail out.
+     * Given a new attribute set and an id, insert each into the DB. If
+     * anything fails in here, rollback the transaction, return the relevant
+     * error and bail out.
      *
-     * @params int $id            The id of the record for which attributes
-     *                            are being inserted.
-     * @params array $attributes  An hash containing the attributes.
+     * @param integer $id        The id of the record for which attributes are
+     *                           being inserted.
+     * @param array $attributes  An hash containing the attributes.
      */
     function insertAttributes($id, $attributes)
     {
         foreach ($attributes as $attr) {
-            $query = sprintf('INSERT INTO %s (%s, attribute_name, attribute_key, attribute_value) VALUES (%s, %s, %s, %s)',
-                             $this->_params['attribute_table'],
-                             $this->_params['id_column'],
-                             (int)$id,
-                             $this->_db->quote($attr['name']),
-                             $this->_db->quote($attr['key']),
-                             $this->_db->quote($attr['value']));
+            $query = 'INSERT INTO ' . $this->_params['attribute_table'] .
+                     ' (' . $this->_params['id_column'] . ', attribute_name,' .
+                     ' attribute_key, attribute_value) VALUES (?, ?, ?, ?)';
+            $values = array((int)$id,
+                            $attr['name'],
+                            $attr['key'],
+                            $attr['value']);
 
             Horde::logMessage('SQL Query by Horde_SQL_Attributes::insertAttributes(): ' . $query, __FILE__, __LINE__, PEAR_LOG_DEBUG);
-            $result = $this->_db->query($query);
+
+            $result = $this->_db->query($query, $values);
             if (is_a($result, 'PEAR_Error')) {
                 $this->_db->rollback();
                 $this->_db->autoCommit(true);
@@ -189,8 +192,8 @@ class Horde_SQL_Attributes {
      * Given an id, delete all attributes for that id from the
      * attributes table.
      *
-     * @params int $id  The id of the record for which attributes are being
-     *                  deleted.
+     * @param integer $id  The id of the record for which attributes are being
+     *                     deleted.
      */
     function deleteAttributes($id)
     {
@@ -210,12 +213,12 @@ class Horde_SQL_Attributes {
     }
 
     /**
-     * Given an id, update all attributes for that id in the
-     * attributes table with the new attributes.
+     * Given an id, update all attributes for that id in the attributes table
+     * with the new attributes.
      *
-     * @params int $id            The id of the record for which attributes
-     *                            are being deleted.
-     * @params array $attributes  An hash containing the attributes.
+     * @param integer $id        The id of the record for which attributes are
+     *                           being deleted.
+     * @param array $attributes  An hash containing the attributes.
      */
     function updateAttributes($id, $attributes)
     {
@@ -233,10 +236,9 @@ class Horde_SQL_Attributes {
     /**
      * Build a piece of an attribute query.
      *
-     * @param string $glue      The glue to join the criteria (OR/AND).
-     * @param array  $criteria  The array of criteria.
-     * @param bool $join        Should we join on a clean attributes table?
-     *                          Defaults to false.
+     * @param string $glue     The glue to join the criteria (OR/AND).
+     * @param array $criteria  The array of criteria.
+     * @param boolean $join    Should we join on a clean attributes table?
      *
      * @return string  An SQL fragment.
      */
@@ -289,8 +291,7 @@ class Horde_SQL_Attributes {
      * Get an alias to an attributes table, incrementing it if
      * necessary.
      *
-     * @param optional bool $increment  Increment the alias count? Defaults to
-     *                                  false.
+     * @param boolean $increment  Increment the alias count? Defaults to false.
      */
     function _getAlias($increment = false)
     {
@@ -316,7 +317,7 @@ class Horde_SQL_Attributes {
      * This method must be invoked as: $var =
      * &Horde_SQL_Attributes::singleton()
      *
-     * @param object $dbh    An object pointing to a SQL database handle.
+     * @param DB $dbh        An object pointing to a SQL database handle.
      *
      * @param array $params  Parameters for the attributes table, consisting
      *                       of the following keys:
