@@ -21,45 +21,17 @@ define('SERIALIZE_UTF7', 14);
 define('SERIALIZE_UTF7_BASIC', 15);
 
 
-/* Specific default values */
-/* BZIP */
-/** Define the block size (1-9). */
-define('SERIALIZE_BZIP_BLOCK', 9);
-
-/** Work factor - not used. */
-define('SERIALIZE_BZIP_FACTOR', 30);
-
-/** Try to minimize memory use. */
-define('SERIALIZE_BZIP_SMALLMEM', false);
-
-/* Gzip */
-/** Level of compression - deflate (1-9). */
-define('SERIALIZE_GZ_DEFLATE_LEVEL', 9);
-
-/** Max length of the uncompressed string (in bytes). */
-define('SERIALIZE_GZ_DEFLATE_LENGTH', 2048);
-
-/** Level of compression - compress (1-9). */
-define('SERIALIZE_GZ_COMPRESS_LEVEL', 9);
-
-/** Max length of the uncompressed string. */
-define('SERIALIZE_GZ_COMPRESS_LENGTH', 2048);
-
-/** Level of compression - Encode (1-9). */
-define('SERIALIZE_GZ_ENCOD_LEVEL', 9);
-
 /**
  * The Serialize:: class provides various methods of encapsulating data.
  *
- * $Horde: framework/Serialize/Serialize.php,v 1.25.10.1 2005/01/03 12:19:13 jan Exp $
+ * $Horde: framework/Serialize/Serialize.php,v 1.25.10.9 2006/01/01 21:28:34 jan Exp $
  *
- * Copyright 2001-2005 Stephane Huther <shuther@bigfoot.com>
+ * Copyright 2001-2006 Stephane Huther <shuther@bigfoot.com>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Stephane Huther <shuther@bigfoot.com>
- * @version $Revision: 1.25.10.1 $
  * @since   Horde 2.0
  * @package Horde_Serialize
  */
@@ -67,18 +39,16 @@ class Horde_Serialize {
 
     /**
      * Serialize a value.
+     *
      * See the list of constants at the top of the file for the serializing
      * techniques that can be used.
      *
-     * @access public
-     *
-     * @param mixed $data             The data to be serialized.
-     * @param optional mixed $mode    The mode of serialization. Can be
-     *                                either a single mode or array of modes.
-     *                                If array, will be serialized in the
-     *                                order provided.
-     * @param optional mixed $params  Any additional parameters the
-     *                                serialization method requires.
+     * @param mixed $data    The data to be serialized.
+     * @param mixed $mode    The mode of serialization. Can be either a single
+     *                       mode or array of modes.  If array, will be
+     *                       serialized in the order provided.
+     * @param mixed $params  Any additional parameters the serialization method
+     *                       requires.
      *
      * @return string  The serialized data.
      *                 Returns PEAR_Error on error.
@@ -119,8 +89,8 @@ class Horde_Serialize {
      *                                either a single mode or array of modes.
      *                                If array, will be serialized in the
      *                                order provided.
-     * @param optional mixed $params  Any additional parameters the
-     *                                serialization method requires.
+     * @param mixed $params  Any additional parameters the serialization method
+     *                       requires.
      */
     function _serialize(&$data, $mode, $params = null)
     {
@@ -129,7 +99,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_BZIP:
-            $data = bzcompress($data, SERIALIZE_BZIP_BLOCK, SERIALIZE_BZIP_FACTOR);
+            $data = bzcompress($data, 9, 30);
             break;
 
         case SERIALIZE_WDDX:
@@ -149,7 +119,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_GZ_DEFLATE:
-            $data = gzdeflate($data, SERIALIZE_GZ_DEFLATE_LEVEL);
+            $data = gzdeflate($data, 9);
             break;
 
         case SERIALIZE_BASIC:
@@ -157,7 +127,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_GZ_COMPRESS:
-            $data = gzcompress($data, SERIALIZE_GZ_COMPRESS_LEVEL);
+            $data = gzcompress($data, 9);
             break;
 
         case SERIALIZE_BASE64:
@@ -165,7 +135,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_GZ_ENCOD:
-            $data = gzencode($data, SERIALIZE_GZ_ENCOD_LEVEL);
+            $data = gzencode($data, 9);
             break;
 
         case SERIALIZE_RAW:
@@ -178,7 +148,6 @@ class Horde_Serialize {
 
         case SERIALIZE_SQLXML:
             require_once 'DB.php';
-            require_once 'XML/sql2xml.php';
             $sql2xml = &new xml_sql2xml();
             $data = $sql2xml->getXML($data);
             break;
@@ -197,18 +166,16 @@ class Horde_Serialize {
 
     /**
      * Unserialize a value.
+     *
      * See the list of constants at the top of the file for the serializing
      * techniques that can be used.
      *
-     * @access public
-     *
      * @param mixed $data             The data to be unserialized.
-     * @param optional mixed $mode    The mode of unserialization. Can be
-     *                                either a single mode or array of modes.
-     *                                If array, will be unserialized in the
-     *                                order provided.
-     * @param optional mixed $params  Any additional parameters the
-     *                                unserialization method requires.
+     * @param mixed $mode    The mode of unserialization.  Can be either a
+     *                       single mode or array of modes.  If array, will be
+     *                       unserialized in the order provided.
+     * @param mixed $params  Any additional parameters the unserialization
+     *                       method requires.
      *
      * @return string  The unserialized data.
      *                 Returns PEAR_Error on error.
@@ -244,13 +211,12 @@ class Horde_Serialize {
      *
      * @access private
      *
-     * @param mixed &$data            The data to be unserialized.
-     * @param mixed $mode             The mode of unserialization. Can be
-     *                                either a single mode or array of modes.
-     *                                If array, will be unserialized in the
-     *                                order provided.
-     * @param optional mixed $params  Any additional parameters the
-     *                                unserialization method requires.
+     * @param mixed &$data   The data to be unserialized.
+     * @param mixed $mode    The mode of unserialization. Can be either a
+     *                       single mode or array of modes.  If array, will be
+     *                       unserialized in the order provided.
+     * @param mixed $params  Any additional parameters the unserialization
+     *                       method requires.
      */
     function _unserialize(&$data, $mode, $params = null)
     {
@@ -272,7 +238,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_BZIP:
-            $data = bzdecompress($data, SERIALIZE_BZIP_SMALLMEM);
+            $data = bzdecompress($data, false);
             break;
 
         case SERIALIZE_IMAPUTF7:
@@ -284,7 +250,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_GZ_DEFLATE:
-            $data = gzinflate($data, SERIALIZE_GZ_DEFLATE_LENGTH);
+            $data = gzinflate($data);
             break;
 
         case SERIALIZE_BASE64:
@@ -292,7 +258,7 @@ class Horde_Serialize {
             break;
 
         case SERIALIZE_GZ_COMPRESS:
-            $data = gzuncompress($data, SERIALIZE_GZ_COMPRESS_LENGTH);
+            $data = gzuncompress($data);
             break;
 
         case SERIALIZE_UTF7:
@@ -310,8 +276,6 @@ class Horde_Serialize {
     /**
      * Check whether or not a serialization method is supported.
      *
-     * @access public
-     *
      * @param integer $mode  The serialization method.
      *
      * @return boolean  True if supported, false if not.
@@ -335,10 +299,12 @@ class Horde_Serialize {
         case SERIALIZE_GZ_ENCOD:
             return Util::extensionExists('zlib');
 
+        case SERIALIZE_SQLXML:
+            return @include_once 'XML/sql2xml.php';
+
         case SERIALIZE_NONE:
         case SERIALIZE_BASIC:
         case SERIALIZE_BASE64:
-        case SERIALIZE_SQLXML:
         case SERIALIZE_RAW:
         case SERIALIZE_URL:
         case SERIALIZE_UTF7:
