@@ -3,7 +3,7 @@
  * SessionHandler:: defines an API for implementing custom session
  * handlers for PHP.
  *
- * $Horde: framework/SessionHandler/SessionHandler.php,v 1.13.10.8 2006/03/10 00:14:42 jan Exp $
+ * $Horde: framework/SessionHandler/SessionHandler.php,v 1.13.10.11 2006/07/14 08:54:59 jan Exp $
  *
  * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
  *
@@ -53,23 +53,26 @@ class SessionHandler {
         }
 
         $driver = basename($driver);
-
-        if (is_null($params)) {
-            require_once 'Horde.php';
-            $params = Horde::getDriverConfig('sessionhandler', $driver);
-        }
-
-        if (!empty($app)) {
-            require_once $GLOBALS['registry']->get('fileroot', $app) . '/lib/SessionHandler/' . $driver . '.php';
-        } elseif (@file_exists(dirname(__FILE__) . '/SessionHandler/' . $driver . '.php')) {
-            require_once dirname(__FILE__) . '/SessionHandler/' . $driver . '.php';
-        } else {
-            @include_once 'Horde/SessionHandler/' . $driver . '.php';
+        if ($driver == 'memcached') {
+            // Trap for old driver name.
+            $driver = 'memcache';
         }
 
         $class = 'SessionHandler_' . $driver;
+        if (!class_exists($class)) {
+            if (!empty($app)) {
+                include_once $GLOBALS['registry']->get('fileroot', $app) . '/lib/SessionHandler/' . $driver . '.php';
+            } else {
+                include_once 'Horde/SessionHandler/' . $driver . '.php';
+            }
+        }
+
         if (class_exists($class)) {
-            $handler = &new $class($params);
+            if (is_null($params)) {
+                include_once 'Horde.php';
+                $params = Horde::getDriverConfig('sessionhandler', $driver);
+            }
+            $handler = new $class($params);
         } else {
             $handler = PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
@@ -206,21 +209,19 @@ class SessionHandler {
             return false;
         }
 
-        $vars = preg_split('/([a-z,A-Z]+)\|/', $session_data, -1,
-                           PREG_SPLIT_NO_EMPTY | PREG_SPLIT_DELIM_CAPTURE);
-
-        $auth = array_search('auth', $vars);
-        if (empty($auth)) {
-            return false;
-        }
-
-        $data = unserialize($vars[$auth + 1]);
-        if (empty($data)) {
-            return false;
-        }
-
-        if (!empty($data['authenticated'])) {
-            return $return_data ? $data : true;
+        while ($session_data) {
+            $vars = explode('|', $session_data, 2);
+            $data = unserialize($vars[1]);
+            if ($vars[0] == '__auth') {
+                if (empty($data)) {
+                    return false;
+                }
+                if (!empty($data['authenticated'])) {
+                    return $return_data ? $data : true;
+                }
+                return false;
+            }
+            $session_data = substr($session_data, strlen($vars[0]) + strlen(serialize($data)) + 1);
         }
     }
 
@@ -252,11 +253,8 @@ class SessionHandler {
 
         foreach ($sessions as $id) {
             $data = $this->read($id);
-            if (is_a($data, 'PEAR_Error')) {
-                return $data;
-            }
-
-            if ($this->_isAuthenticated($data)) {
+            if (!is_a($data, 'PEAR_Error') &&
+                $this->_isAuthenticated($data)) {
                 $count++;
             }
         }
@@ -281,7 +279,7 @@ class SessionHandler {
         foreach ($sessions as $id) {
             $data = $this->read($id);
             if (is_a($data, 'PEAR_Error')) {
-                return $data;
+                continue;
             }
 
             $data = $this->_isAuthenticated($data, true);
