@@ -7,7 +7,7 @@ require_once 'Horde/DataTree.php';
  * methods take care of any site-specific restrictions configured in in the
  * application's prefs.php and conf.php files.
  *
- * $Horde: framework/Share/Share.php,v 1.111.2.16 2006/01/01 21:28:35 jan Exp $
+ * $Horde: framework/Share/Share.php,v 1.111.2.20 2006/05/04 13:25:29 jan Exp $
  *
  * Copyright 2002-2006 Joel Vandal <jvandal@infoteck.qc.ca>
  * Copyright 2002-2006 Infoteck Internet <webmaster@infoteck.qc.ca>
@@ -538,7 +538,7 @@ class Horde_Share {
                 $criteria['OR'][] = array(
                     'AND' => array(
                         array('field' => 'name', 'op' => '=', 'test' => 'perm_groups'),
-                        array('field' => 'key', 'op' => 'IN', 'test' => '(' . implode(', ', array_keys($groups)) . ')'),
+                        array('field' => 'key', 'op' => 'IN', 'test' => array_keys($groups)),
                         array('field' => 'value', 'op' => '&', 'test' => $perm)));
             }
         } else {
@@ -756,6 +756,23 @@ class DataTreeObject_Share extends DataTreeObject {
         $perm->removeUserPermission($userid, PERMS_READ, false);
         $perm->removeUserPermission($userid, PERMS_EDIT, false);
         $perm->removeUserPermission($userid, PERMS_DELETE, false);
+        return $this->setPermission($perm);
+    }
+
+    /**
+     * Removes a group from this share.
+     *
+     * @param integer $groupId  The group to remove.
+     */
+    function removeGroup($groupId)
+    {
+        /* Remove all $groupId's permissions. */
+        $perm = &$this->getPermission();
+        $perm->removeGroupPermission($groupId, PERMS_SHOW, false);
+        $perm->removeGroupPermission($groupId, PERMS_READ, false);
+        $perm->removeGroupPermission($groupId, PERMS_EDIT, false);
+        $perm->removeGroupPermission($groupId, PERMS_DELETE, false);
+        return $this->setPermission($perm);
     }
 
     /**
