@@ -3,7 +3,7 @@
  * Horde Template system. Adapted from bTemplate by Brian Lozier
  * <brian@massassi.net>.
  *
- * $Horde: framework/Template/Template.php,v 1.38.10.8 2006/01/22 19:12:26 slusarz Exp $
+ * $Horde: framework/Template/Template.php,v 1.38.10.10 2006/06/13 03:54:03 chuck Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -142,7 +142,7 @@ class Horde_Template {
             foreach ($tag as $tTag => $tVar) {
                 $this->set($tTag, $tVar, $isIf);
             }
-        } elseif (is_array($var)) {
+        } elseif (is_array($var) || is_object($var)) {
             $this->_arrays[$tag] = $var;
             if ($isIf) {
                 // Just store the same variable that we stored in
@@ -493,7 +493,7 @@ class Horde_Template {
         if (isset($key)) {
             list($tg, $k) = explode('.', $tag);
         }
-        while ($if = $this->_getStatement($t, $contents)) {
+        while (($if = $this->_getStatement($t, $contents)) !== false) {
             // Check for else statement.
             if ($else = $this->_getStatement($et, $if)) {
                 // Process the if statement.
@@ -548,11 +548,11 @@ class Horde_Template {
             $parsed = '';
             $first = true;
             foreach ($array as $key => $value) {
-                if (is_array($value)) {
+                if (is_array($value) || is_object($value)) {
                     $i = $loop;
                     if (is_numeric($key)) {
                         foreach ($value as $key2 => $value2) {
-                            if (!is_array($value2)) {
+                            if (!is_array($value2) && !is_object($value2)) {
                                 // Replace associative array tags.
                                 $aa_tag = $tag . '.' . $key2;
                                 $i = str_replace($this->_getTag($aa_tag), $value2, $i);
@@ -570,16 +570,16 @@ class Horde_Template {
                         }
                     }
                     $i = str_replace($this->_getTag($tag), $key, $i);
-                } elseif (is_string($key) && !is_array($value)) {
+                } elseif (is_string($key) && !is_array($value) && !is_object($value)) {
                     $contents = str_replace($this->_getTag($tag . '.' . $key), $value, $contents);
-                } elseif (!is_array($value)) {
+                } elseif (!is_array($value) && !is_object($value)) {
                     $i = str_replace($this->_getTag($tag . ''), $value, $loop);
                 } else {
                     $i = null;
                 }
 
                 // Parse conditions in the array.
-                if (!empty($this->_ifs[$tag][$key]) && is_array($this->_ifs[$tag][$key]) && count($this->_ifs[$tag][$key])) {
+                if (!empty($this->_ifs[$tag][$key]) && is_array($this->_ifs[$tag][$key]) && $this->_ifs[$tag][$key]) {
                     foreach ($this->_ifs[$tag][$key] as $cTag => $cValue) {
                         $i = $this->_parseIf($tag . '.' . $cTag, $i, $key);
                     }
@@ -636,7 +636,7 @@ class Horde_Template {
             // Process the cloop.
             $parsed = '';
             foreach ($array['array'] as $key => $value) {
-                if (is_numeric($key) && is_array($value)) {
+                if (is_numeric($key) && (is_array($value) || is_object($value))) {
                     // Set up the cases.
                     if (isset($value['case'])) {
                         $current_case = $value['case'];
@@ -648,7 +648,7 @@ class Horde_Template {
 
                     // Loop through each value.
                     foreach ($value as $key2 => $value2) {
-                        if (is_array($value2)) {
+                        if (is_array($value2) || is_object($value2)) {
                             $i = $this->_parseLoop($tag . '.' . $key2, $value2, $i);
                         } else {
                             $i = str_replace($this->_getTag($tag . '.' . $key2), $value2, $i);
