@@ -2,15 +2,14 @@
 /**
  * The Text:: class provides common methods for manipulating text.
  *
- * $Horde: framework/Horde/Horde/Text.php,v 1.2 2004/10/15 13:18:13 jan Exp $
+ * $Horde: framework/Horde/Horde/Text.php,v 1.2.10.5 2006/01/01 21:28:20 jan Exp $
  *
- * Copyright 1999-2004 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.2 $
  * @since   Horde 1.3
  * @package Horde_Text
  */
@@ -25,7 +24,12 @@ class Text {
      */
     function htmlSpaces($text = '')
     {
-        $text = @htmlspecialchars($text, ENT_COMPAT, NLS::getCharset());
+        static $charset;
+        if (!isset($charset)) {
+            $charset = NLS::getCharset();
+        }
+
+        $text = @htmlspecialchars($text, ENT_COMPAT, $charset);
         $text = str_replace("\t", '&nbsp; &nbsp; &nbsp; &nbsp; ', $text);
         $text = str_replace('  ', '&nbsp; ', $text);
         $text = str_replace('  ', ' &nbsp;', $text);
