@@ -12,7 +12,7 @@ define('TEXT_HTML_NOHTML_NOBREAK', 5);
 /**
  * Text_Filter:: is a parent class for defining stackable text filters.
  *
- * $Horde: framework/Text_Filter/Filter.php,v 1.15.2.7 2006/01/01 21:28:37 jan Exp $
+ * $Horde: framework/Text_Filter/Filter.php,v 1.15.2.9 2006/05/11 19:49:14 chuck Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2004-2006 Jan Schneider <jan@horde.org>
@@ -60,7 +60,7 @@ class Text_Filter {
         }
 
         foreach ($filters as $num => $filter) {
-            $filterOb = &Text_Filter::singleton($filter, $params[$num]);
+            $filterOb = Text_Filter::factory($filter, isset($params[$num]) ? $params[$num] : array());
             if (is_a($filterOb, 'PEAR_Error')) {
                 return $filterOb->getMessage();
             }
@@ -166,42 +166,4 @@ class Text_Filter {
         return $filter;
     }
 
-    /**
-     * Attempts to return a reference to a concrete Text_Filter
-     * instance based on $driver. It will only create a new instance
-     * if no Text_Filter instance with the same parameters currently
-     * exists.
-     *
-     * This should be used if multiple types of text filters (and,
-     * thus, multiple Text_Filter instances) are required.
-     *
-     * This method must be invoked as: $filter = &Text_Filter::singleton();
-     *
-     * @param mixed $driver  The type of concrete Text_Filter subclass to
-     *                       return. This is based on the filter driver
-     *                       ($driver). The code is dynamically included. If
-     *                       $driver is an array, then we will look in
-     *                       $driver[0] for the subclass implementation named
-     *                       $driver[1].php.
-     * @param array $params  A hash containing any additional configuration
-     *                       parameters a subclass might need.
-     *
-     * @return Text_Filter  The concrete Text_Filter reference, or false on an
-     *                      error.
-     */
-    function &singleton($driver, $params = array())
-    {
-        static $instances;
-        if (!isset($instances)) {
-            $instances = array();
-        }
-
-        $signature = serialize(array($driver, $params));
-        if (!isset($instances[$signature])) {
-            $instances[$signature] = &Text_Filter::factory($driver, $params);
-        }
-
-        return $instances[$signature];
-    }
-
 }
