@@ -49,9 +49,9 @@ require_once 'Horde.php';
  *         and the text is "Mail to Carlos".
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/bbcode.php,v 1.8.10.2 2005/01/11 20:44:48 chuck Exp $
+ * $Horde: framework/Text_Filter/Filter/bbcode.php,v 1.8.10.5 2006/01/01 21:28:38 jan Exp $
  *
- * Copyright 2003-2005 Carlos Pedrinaci <cpedrinaci@yahoo.es>
+ * Copyright 2003-2006 Carlos Pedrinaci <cpedrinaci@yahoo.es>
  *
  * Email validation based on Chuck Hagenbuch's
  * Mail_RFC822::isValidInetAddress.
@@ -67,7 +67,7 @@ class Text_Filter_bbcode extends Text_Filter {
     /**
      * Filter parameters.
      *
-     * @var array $_params
+     * @var array
      */
     var $_params = array('entities' => false);
 
@@ -95,9 +95,9 @@ class Text_Filter_bbcode extends Text_Filter {
     function getPatterns()
     {
     	$replace = array(
-    	    '[i]' => '<i>', '[/i]' => '</i>',
+    	    '[i]' => '<em>', '[/i]' => '</em>',
             '[u]' => '<u>', '[/u]' => '</u>',
-            '[b]' => '<b>', '[/b]' => '</b>',
+            '[b]' => '<strong>', '[/b]' => '</strong>',
             '[center]' => '<center>', '[/center]' => '</center>',
             '[quote]' => '<blockquote>', '[/quote]' => '</blockquote>',
             '[list]' => '<ul>', '[/list]' => '</ul>',
