@@ -10,10 +10,10 @@
  * class         -- CSS class of the generated <a> tag.  Defaults to none.
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/emails.php,v 1.15.10.14 2007/03/01 07:10:31 slusarz Exp $
+ * $Horde: framework/Text_Filter/Filter/emails.php,v 1.15.10.8 2006/02/17 20:05:49 chuck Exp $
  *
- * Copyright 2003-2007 Tyler Colbert <tyler-hordeml@colberts.us>
- * Copyright 2004-2007 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2006 Tyler Colbert <tyler-hordeml@colberts.us>
+ * Copyright 2004-2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -60,9 +60,9 @@ class Text_Filter_emails extends Text_Filter {
             ((?(1)\s*\]))
 
             |
-            # Version 2 Pattern 8 and 9: simple email addresses.
-            (^|\s|&lt;)([\w-+.=]+@[-A-Z0-9.]*[A-Z0-9])
-            # Pattern 10 to 12: Optional parameters
+            # Version 2 Pattern 8: simple email addresses.
+            (\b[\w-+.=]+@[-A-Z0-9.]*[A-Z0-9])
+            # Pattern 9 to 11: Optional parameters
             ((\?)([^\s"<]*[\w+#?\/&=]))?
 
             /eix
@@ -73,7 +73,7 @@ EOR;
             !$this->_params['always_mailto']) {
             /* If we have a mail/compose registry method, use it. */
             $replacement = 'Text_Filter_emails::callback(\'' . $tag .
-                '\', \'' . $class . '\', \'$1\', \'$2\', \'$3\', \'$4\', \'$6\', \'$7\', \'$8\', \'$9\', \'$10\', \'$12\')';
+                '\', \'' . $class . '\', \'$1\', \'$2\', \'$3\', \'$4\', \'$6\', \'$7\', \'$8\', \'$9\', \'$11\')';
         } else {
             /* Otherwise, generate a standard mailto: and let the
              * browser handle it. */
@@ -83,8 +83,8 @@ EOR;
                 '$1$2<$tag$class href="mailto:$3$4" title="' . sprintf(_("New Message to %s"), htmlspecialchars('$3')) .
                 '">$3$4</$tag>$7' :
 
-                '$8<$tag$class href="mailto:$9$10" title="' . sprintf(_("New Message to %s"), htmlspecialchars('$9')) .
-                '">$9$10</$tag>'
+                '<$tag$class href="mailto:$8$9" title="' . sprintf(_("New Message to %s"), htmlspecialchars('$8')) .
+                '">$8$9</$tag>'
 EOP;
         }
 
@@ -92,15 +92,14 @@ EOP;
     }
 
     function callback($tag, $class, $bracket1, $protocol, $email, $args_long,
-                      $args, $bracket2, $prefix, $email2, $args_long2, $args2)
+                      $args, $bracket2, $email2, $args_long2, $args2)
     {
         if (!empty($email2)) {
             $args = $args2;
             $email = $email2;
             $args_long = $args_long2;
         }
-
-        parse_str($args, $extra);
+        $extra = call_user_func(create_function('$a', '$p=array();foreach($a as $b){$b=explode("=",$b,2);$p[$b[0]]=@$b[1];}return $p;'), explode('&', $args));
         $url = $GLOBALS['registry']->call('mail/compose',
                                           array(array('to' => $email),
                                           $extra));
@@ -113,7 +112,7 @@ EOP;
             $onclick = '';
         }
 
-        return $bracket1 . $protocol . $prefix . '<' . $tag . $class . ' href="' .
+        return $bracket1 . $protocol . '<' . $tag . $class . ' href="' .
             $href . '" title="' . sprintf(_("New Message to %s"), htmlspecialchars($email)) . '"' .
             $onclick . '>' . htmlspecialchars($email) . $args_long . '</' . $tag . '>' . $bracket2;
     }
