@@ -6,6 +6,7 @@
  * <pre>
  * target   -- The link target.  Defaults to _blank.
  * class    -- The CSS class of the generated links.  Defaults to none.
+ * nofollow -- Whether to set the 'rel="nofollow"' attribute on links.
  * capital  -- generate uppercase <A> tags so you can know which tags you just
  *             generated.  Defaults to false.
  * callback -- An optional callback function that the URL is passed through
@@ -14,10 +15,10 @@
  *             first and only parameter.
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/linkurls.php,v 1.11.10.2 2005/01/11 20:44:48 chuck Exp $
+ * $Horde: framework/Text_Filter/Filter/linkurls.php,v 1.11.10.5 2006/01/01 21:28:38 jan Exp $
  *
- * Copyright 2003-2005 Tyler Colbert <tyler-hordeml@colberts.us>
- * Copyright 2004-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2006 Tyler Colbert <tyler-hordeml@colberts.us>
+ * Copyright 2004-2006 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -31,10 +32,11 @@ class Text_Filter_linkurls extends Text_Filter {
     /**
      * Filter parameters.
      *
-     * @var array $_params
+     * @var array
      */
     var $_params = array('target' => '_blank',
                          'class' => '',
+                         'nofollow' => false,
                          'capital' => false,
                          'callback' => null);
 
@@ -67,11 +69,12 @@ class Text_Filter_linkurls extends Text_Filter {
         if (!empty($class)) {
             $class = ' class="' . $class . '"';
         }
+        $nofollow = $this->_params['nofollow'] ? ' rel="nofollow"' : '';
 
         $url = $this->_params['callback'] ? '\' . ' . $this->_params['callback'] . '(\'$0\') . \'' : '$0';
 
         $regexp = array('|(\w+)://([^\s"<]*[\w+#?/&=])|e' =>
-                        '\'<' . $a . ' href="' . $url . '" target="_blank"' . $class . '>$0</' . $a . '>\'');
+                        '\'<' . $a . ' href="' . $url . '"' . $nofollow . ' target="_blank"' . $class . '>$0</' . $a . '>\'');
 
         return array('regexp' => $regexp);
     }
