@@ -2,7 +2,7 @@
 /**
  * Highlights simple markup as used in emails or usenet postings.
  *
- * $Horde: framework/Text_Filter/Filter/simplemarkup.php,v 1.1.10.4 2006/01/01 21:28:38 jan Exp $
+ * $Horde: framework/Text_Filter/Filter/simplemarkup.php,v 1.1.10.5 2006/07/24 15:54:54 slusarz Exp $
  *
  * Copyright 2004-2006 Jan Schneider <jan@horde.org>
  *
@@ -24,13 +24,13 @@ class Text_Filter_simplemarkup extends Text_Filter {
     {
         $regexp = array(
             // Bold.
-            '/(\s|\n)(\*[^*\s]+\*)(\s|\r|\n|<br)/i' => '\1<strong>\2</strong>\3',
+            '/(^|\s|&nbsp;|<br \/>)(\*[^*\s]+\*)(\s|&nbsp;|<br|\.)/i' => '\1<strong>\2</strong>\3',
 
             // Underline.
-            '/(\s|\n)(_[^_\s]+_)(\s|\r|\n|<br)/i' => '\1<u>\2</u>\3',
+            '/(^|\s|&nbsp;|<br \/>)(_[^_\s]+_)(\s|&nbsp;|<br|\.)/i' => '\1<u>\2</u>\3',
 
             // Italic.
-            ';(\s|\n)(/[^/\s]+/)(\s|\r|\n|<br);i' => '\1<em>\2</em>\3');
+            ';(^|\s|&nbsp\;|<br />)(/[^/\s]+/)(\s|&nbsp\;|<br|\.);i' => '\1<em>\2</em>\3');
 
         return array('regexp' => $regexp);
     }
