@@ -3,12 +3,12 @@
  * The Horde_Tree_html:: class extends the Horde_Tree class to provide
  * HTML specific rendering functions.
  *
- * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Tree/Tree/html.php,v 1.51.2.4 2005/03/15 02:30:44 chuck Exp $
+ * $Horde: framework/Tree/Tree/html.php,v 1.51.2.12 2006/01/15 16:33:29 chuck Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @package Horde_Tree
@@ -19,74 +19,138 @@ class Horde_Tree_html extends Horde_Tree {
     /**
      * Image directory location.
      *
-     * @var string $_img_dir
+     * @var string
      */
     var $_img_dir = '';
 
     /**
-     * Default tree graphics (located in $_img_dir).
+     * Default tree graphic for a line.
      *
-     * @var string $_img_line
-     * @var string $_img_blank
-     * @var string $_img_join
-     * @var string $_img_join_bottom
-     * @var string $_img_plus
-     * @var string $_img_plus_bottom
-     * @var string $_img_plus_only
-     * @var string $_img_minus
-     * @var string $_img_minus_bottom
-     * @var string $_img_minus_only
-     * @var string $_img_folder
-     * @var string $_img_folder_open
-     * @var string $_img_leaf
+     * @var string
+     */
+    var $_img_line = 'line.png';
+
+    /**
+     * Default tree graphic for a blank.
+     *
+     * @var string
+     */
+    var $_img_blank = 'blank.png';
+
+    /**
+     * Default tree graphic for a join.
+     *
+     * @var string
+     */
+    var $_img_join = 'join.png';
+
+    /**
+     * Default tree graphic for a bottom join.
+     *
+     * @var string
+     */
+    var $_img_join_bottom = 'joinbottom.png';
+
+    /**
+     * Default tree graphic for a plus.
+     *
+     * @var string
+     */
+    var $_img_plus = 'plus.png';
+
+    /**
+     * Default tree graphic for a bottom plus.
+     *
+     * @var string
+     */
+    var $_img_plus_bottom = 'plusbottom.png';
+
+    /**
+     * Default tree graphic for a plus only.
+     *
+     * @var string
+     */
+    var $_img_plus_only = 'plusonly.png';
+
+    /**
+     * Default tree graphic for a minus.
+     *
+     * @var string
+     */
+    var $_img_minus = 'minus.png';
+
+    /**
+     * Default tree graphic for a bottom minus.
+     *
+     * @var string
      */
-    var $_img_line         = 'line.png';
-    var $_img_blank        = 'blank.png';
-    var $_img_join         = 'join.png';
-    var $_img_join_bottom  = 'joinbottom.png';
-    var $_img_plus         = 'plus.png';
-    var $_img_plus_bottom  = 'plusbottom.png';
-    var $_img_plus_only    = 'plusonly.png';
-    var $_img_minus        = 'minus.png';
     var $_img_minus_bottom = 'minusbottom.png';
-    var $_img_minus_only   = 'minusonly.png';
-    var $_img_null_only    = 'nullonly.png';
-    var $_img_folder       = 'folder.png';
-    var $_img_folder_open  = 'folderopen.png';
-    var $_img_leaf         = 'leaf.png';
+
+    /**
+     * Default tree graphic for a minus only.
+     *
+     * @var string
+     */
+    var $_img_minus_only = 'minusonly.png';
+
+    /**
+     * Default tree graphic for a null only.
+     *
+     * @var string
+     */
+    var $_img_null_only = 'nullonly.png';
+
+    /**
+     * Default tree graphic for a folder.
+     *
+     * @var string
+     */
+    var $_img_folder = 'folder.png';
+
+    /**
+     * Default tree graphic for an open folder.
+     *
+     * @var string
+     */
+    var $_img_folder_open = 'folderopen.png';
+
+    /**
+     * Default tree graphic for a leaf.
+     *
+     * @var string
+     */
+    var $_img_leaf = 'leaf.png';
 
     /**
      * TODO
      *
-     * @var array $_nodes
+     * @var array
      */
     var $_nodes = array();
 
     /**
      * TODO
      *
-     * @var array $_node_pos
+     * @var array
      */
     var $_node_pos = array();
 
     /**
      * TODO
      *
-     * @var array $_dropline
+     * @var array
      */
     var $_dropline = array();
 
     /**
      * Current value of the alt tag count.
      *
-     * @var integer $_alt_count
+     * @var integer
      */
     var $_alt_count = 0;
 
     /**
      * Constructor
-     *
-     * @access public
      */
     function Horde_Tree_html($tree_name, $params)
     {
@@ -98,8 +162,6 @@ class Horde_Tree_html extends Horde_Tree {
     /**
      * Returns the tree.
      *
-     * @access public
-     *
      * @param boolean $static  If true the tree nodes can't be expanded and
      *                         collapsed and the tree gets rendered expanded.
      *
@@ -108,6 +170,8 @@ class Horde_Tree_html extends Horde_Tree {
     function getTree($static = false)
     {
         $this->_static = $static;
+        $this->_buildIndents($this->_root_nodes);
+
         $tree = $this->_buildHeader();
         foreach ($this->_root_nodes as $node_id) {
             $tree .= $this->_buildTree($node_id);
@@ -133,8 +197,6 @@ class Horde_Tree_html extends Horde_Tree {
     /**
      * Returns just the JS node definitions as a string. This is a
      * no-op for the HTML renderer.
-     *
-     * @access public
      */
     function renderNodeDefinitions()
     {
@@ -163,20 +225,22 @@ class Horde_Tree_html extends Horde_Tree {
         $html .= '>';
 
         foreach ($this->_header as $header) {
-            $html .= '<div';
+            $html .= '<div class="leftFloat';
             if (!empty($header['class'])) {
-                $html .= ' class="' . $header['class'] . '"';
+                $html .= ' ' . $header['class'];
             }
+            $html .= '"';
 
-            $style = 'float:left;';
+            $style = '';
             if (!empty($header['width'])) {
                 $style .= 'width:' . $header['width'] . ';';
             }
             if (!empty($header['align'])) {
                 $style .= 'text-align:' . $header['align'] . ';';
             }
-
-            $html .= ' style="' . $style . '"';
+            if (!empty($style)) {
+                $html .= ' style="' . $style . '"';
+            }
             $html .= '>';
             $html .= empty($header['html']) ? '&nbsp;' : $header['html'];
             $html .= '</div>';
@@ -245,22 +309,30 @@ class Horde_Tree_html extends Horde_Tree {
             $extra = $this->_nodes[$node_id]['extra'][HORDE_TREE_EXTRA_LEFT];
             $cMax = count($extra);
             for ($c = 0; $c < $cMax; $c++) {
-                $style = 'float:left;';
+                $style = '';
                 if (isset($this->_header[$column]['width'])) {
                     $style .= 'width:' . $this->_header[$column]['width'] . ';';
                 }
 
-                $line .= '<div style="' . $style . '">' . $extra[$c] . '</div>';
+                $line .= '<div class="leftFloat"';
+                if (!empty($style)) {
+                    $line .= ' style="' . $style . '"';
+                }
+                $line .= '>' . $extra[$c] . '</div>';
 
                 $column++;
             }
         }
 
-        $style = 'float:left;';
+        $style = '';
         if (isset($this->_header[$column]['width'])) {
             $style .= 'width:' . $this->_header[$column]['width'] . ';';
         }
-        $line .= '<div style="' . $style . '">';
+        $line .= '<div class="leftFloat"';
+        if (!empty($style)) {
+            $line .= ' style="' . $style . '"';
+        }
+        $line .= '>';
 
         if ($this->getOption('multiline')) {
             $line .= '<table cellspacing="0"><tr><td>';
@@ -294,12 +366,16 @@ class Horde_Tree_html extends Horde_Tree {
             $extra = $this->_nodes[$node_id]['extra'][HORDE_TREE_EXTRA_RIGHT];
             $cMax = count($extra);
             for ($c = 0; $c < $cMax; $c++) {
-                $style = 'float:left;';
+                $style = '';
                 if (isset($this->_header[$column]['width'])) {
                     $style .= 'width:' . $this->_header[$column]['width'] . ';';
                 }
 
-                $line .= '<div style="' . $style . '">' . $extra[$c] . '</div>';
+                $line .= '<div class="leftFloat"';
+                if (!empty($style)) {
+                    $line .= ' style="' . $style . '"';
+                }
+                $line .= '>' . $extra[$c] . '</div>';
 
                 $column++;
             }
@@ -373,7 +449,7 @@ class Horde_Tree_html extends Horde_Tree {
                 $alt = '+';
             }
             if (!$this->_static) {
-                $url = Util::addParameter(Horde::selfURL(), HORDE_TREE_TOGGLE . $this->_instance, $node_id);
+                $url = Util::addParameter(Horde::selfUrl(), HORDE_TREE_TOGGLE . $this->_instance, $node_id);
                 $link_start = Horde::link($url);
             }
         } elseif (($this->_nodes[$node_id]['indent'] != 0) &&
@@ -436,7 +512,7 @@ class Horde_Tree_html extends Horde_Tree {
                 $this->_dropline[$this->_nodes[$node_id]['indent']] = false;
             }
             if (!$this->_static) {
-                $url = Util::addParameter(Horde::selfURL(), HORDE_TREE_TOGGLE . $this->_instance, $node_id);
+                $url = Util::addParameter(Horde::selfUrl(), HORDE_TREE_TOGGLE . $this->_instance, $node_id);
                 $link_start = Horde::link($url);
             }
         } else {
@@ -502,14 +578,14 @@ class Horde_Tree_html extends Horde_Tree {
             }
         }
 
-        $imgtxt = '<img src="' . $img_dir . $img . '" style="vertical-align:middle" ';
+        $imgtxt = '<img src="' . $img_dir . $img . '"';
 
         /* Does the node have user defined alt text? */
         if (isset($this->_nodes[$node_id]['iconalt'])) {
-            $imgtxt .= 'alt="' . $this->_nodes[$node_id]['iconalt'] . '" ';
+            $imgtxt .= ' alt="' . htmlspecialchars($this->_nodes[$node_id]['iconalt']) . '"';
         }
 
-        return $imgtxt . '/>';
+        return $imgtxt . ' />';
     }
 
 }
