@@ -5,12 +5,12 @@ require_once dirname(__FILE__) . '/Widget.php';
 /**
  * The Horde_UI_Pager:: provides links to individual pages.
  *
- * $Horde: framework/UI/UI/Pager.php,v 1.7.10.5 2006/01/01 21:28:40 jan Exp $
+ * $Horde: framework/UI/UI/Pager.php,v 1.7.10.8 2006/06/20 09:08:26 jan Exp $
  *
  * Copyright 2004-2006 Joel Vandal <jvandal@infoteck.qc.ca>
  *
- * See the enclosed file LICENSE for license information (BSD). If you
- * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Ben Chavet <ben@chavet.net>
  * @author  Joel Vandal <jvandal@infoteck.qc.ca>
@@ -60,7 +60,7 @@ class Horde_UI_Pager extends Horde_UI_Widget {
             return '';
         }
 
-        $html = '<div class="pager" style="text-align:center">';
+        $html = '<div class="pager">';
 
         // Create the '<< Prev' link if we are not on the first page.
         $link = Util::addParameter($url, $this->_name, $current_page - 1);
@@ -70,17 +70,21 @@ class Horde_UI_Pager extends Horde_UI_Widget {
         }
 
         // Figure out the top & bottom display limits.
-        $bottom = $current_page - ($current_page % $page_limit);
+        $bottom = max(0, $current_page - ($page_limit / 2) + 1);
         $top = $bottom + $page_limit - 1;
+        if ($top - 1 > $pages) {
+            $bottom -= ($top - 1) - $pages;
+            $top = $pages + 1;
+        }
 
         // Create bottom '[x-y]' link if necessary.
         $link = $this->_addPreserved(Util::addParameter($url, $this->_name, $bottom - 1));
-        if ($bottom > 1) {
-            $html .= ' ' . Horde::link(Horde::applicationUrl($link), '', 'prevRange') . '[' . ($bottom - $page_limit + 1) . '-' . $bottom . ']</a>';
+        if ($bottom > 0) {
+            $html .= ' ' . Horde::link(Horde::applicationUrl($link), '', 'prevRange') . '[' . ($bottom == 1 ? $bottom : '1-' . $bottom) . ']</a>';
         }
 
         // Create links to individual pages between limits.
-        for ($i = $bottom; $i <= $top && $i <= $pages; $i++) {
+        for ($i = $bottom; $i <= $top && $i <= $pages; ++$i) {
             if ($i == $current_page) {
                 $html .= ' <strong>(' . ($i + 1) . ')</strong>';
             } elseif ($i >= 0 && $i <= $pages) {
@@ -91,10 +95,9 @@ class Horde_UI_Pager extends Horde_UI_Widget {
 
         // Create top '[x-y]' link if necessary.
         if ($top < $pages) {
-            $last = $top + $page_limit < $pages ? $top + $page_limit + 1 : $pages + 1;
             $link = $this->_addPreserved(Util::addParameter($url, $this->_name, $top + 1));
             $html .= ' ' . Horde::link(Horde::applicationUrl($link), '', 'nextRange') . '[' .
-                ($top + 2) . '-' . $last . ']</a></td>';
+                ($top + 2 == $pages + 1 ? $pages + 1 : ($top + 2) . '-' . ($pages + 1)) . ']</a>';
         }
 
         // Create the 'Next>>' link if we are not on the last page.
