@@ -2,7 +2,7 @@
 /**
  * The Horde_UI_VarRenderer_html:: class renders variables to HTML.
  *
- * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.26 2006/03/02 17:38:21 chuck Exp $
+ * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.28 2006/08/16 12:17:22 jan Exp $
  *
  * Copyright 2003-2006 Jason M. Felice <jfelice@cronosys.com>
  *
@@ -109,7 +109,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
     function _renderVarInput_cellphone(&$form, &$var, &$vars)
     {
         $varname = @htmlspecialchars($var->getVarName(), ENT_QUOTES, $this->_charset);
-        return sprintf('<input type="text" name="%s" id="%s" size="12" value="%s" %s%s />',
+        return sprintf('<input type="text" name="%s" id="%s" size="15" value="%s" %s%s />',
                        $varname,
                        $varname,
                        @htmlspecialchars($var->getValue($vars), ENT_QUOTES, $this->_charset),
@@ -1039,7 +1039,7 @@ EOT;
 
         if ($number && $registry->hasMethod('sms/compose')) {
             $url = $registry->link('sms/compose', array('to' => $number));
-            $html .= ' ' . Horde::link($url, _("Send SMS")) . Horde::img('swoosh.png', _("Send SMS"), '', $registry->getImageDir('swoosh')) . '</a>';
+            $html .= ' ' . Horde::link($url, _("Send SMS")) . Horde::img('mobile.png', _("Send SMS"), '', $registry->getImageDir('horde')) . '</a>';
         }
 
         return $html;
@@ -1072,11 +1072,11 @@ EOT;
                     $mapurl .= '&streetNumber=' . urlencode($lineParts[2]) . '&streetName=' . urlencode($lineParts[3]);
                 }
                 /* Look for "Suburb, State". */
-                if (preg_match('/([a-zA-Z ]*),?\s+' . $aus_state_regexp . '/', $addressLines[$i], $lineParts)) {
+                if (preg_match('/([a-zA-Z ]*),?\s+' . $aus_state_regex . '/', $addressLines[$i], $lineParts)) {
                     $mapurl .= '&suburb=' . urlencode($lineParts[1]);
                 }
                 /* Look for "State <4 digit postcode>". */
-                if (preg_match('/(' . $aus_state_regexp . ')\s+(\d{4})/', $addressLines[$i], $lineParts)) {
+                if (preg_match('/(' . $aus_state_regex . ')\s+(\d{4})/', $addressLines[$i], $lineParts)) {
                     $mapurl .= '&state=' . urlencode($lineParts[1]);
                 }
             }
