@@ -13,7 +13,7 @@ define('HORDE_ERROR_DRIVER_CONFIG', 2);
 /**
  * The Util:: class provides generally useful methods of different kinds.
  *
- * $Horde: framework/Util/Util.php,v 1.384.6.15 2006/03/28 12:31:12 jan Exp $
+ * $Horde: framework/Util/Util.php,v 1.384.6.17 2006/05/05 16:02:12 jan Exp $
  *
  * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2006 Jon Parise <jon@horde.org>
@@ -159,6 +159,11 @@ class Util {
      */
     function addParameter($url, $parameter, $value = null, $encode = true)
     {
+        static $translation_table;
+
+        if (!isset($translation_table)) {
+            $translation_table = array_flip(get_html_translation_table(HTML_ENTITIES));
+        }
         if (empty($parameter)) {
             return $url;
         }
@@ -179,7 +184,7 @@ class Util {
             $query = substr($url, $pos + 1);
             if (preg_match('/=.*?&amp;.*?=/', $query)) {
                 $arg = '&amp;';
-                $query = strtr($query, array_flip(get_html_translation_table(HTML_ENTITIES)));
+                $query = strtr($query, $translation_table);
             } elseif (preg_match('/=.*?&.*?=/', $query)) {
                 $arg = '&';
             }
@@ -223,6 +228,11 @@ class Util {
      */
     function removeParameter($url, $remove)
     {
+        static $translation_table;
+
+        if (!isset($translation_table)) {
+            $translation_table = array_flip(get_html_translation_table(HTML_ENTITIES));
+        }
         if (!is_array($remove)) {
             $remove = array($remove);
         }
@@ -239,7 +249,7 @@ class Util {
          * htmlentities-ized in the URL. */
         if (preg_match('/=.*?&amp;.*?=/', $query)) {
             $entities = true;
-            $query = strtr($query, array_flip(get_html_translation_table(HTML_ENTITIES)));
+            $query = strtr($query, $translation_table);
         }
 
         /* Get the list of parameters. */
