@@ -6,7 +6,7 @@ require_once 'Horde/Array.php';
 /**
  * Variables:: class.
  *
- * $Horde: framework/Util/Variables.php,v 1.8.10.1 2005/01/12 15:54:42 chuck Exp $
+ * $Horde: framework/Util/Variables.php,v 1.8.10.6 2006/03/28 12:31:12 jan Exp $
  *
  * @author  Robert E. Coyle <robertecoyle@hotmail.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
@@ -31,7 +31,8 @@ class Variables {
 
     function &getDefaultVariables()
     {
-        return $ret = &new Variables(Util::dispelMagicQuotes($_REQUEST));
+        $vars = &new Variables(Util::dispelMagicQuotes($_REQUEST));
+        return $vars;
     }
 
     function exists($varname)
@@ -57,7 +58,23 @@ class Variables {
 
     function set($varname, $value)
     {
-        $this->_vars[$varname] = $value;
+        $keys = array();
+        if (!Horde_Array::getArrayParts($varname, $base, $keys)) {
+            $this->_vars[$varname] = $value;
+        } else {
+            array_unshift($keys, $base);
+            $place = &$this->_vars;
+
+            while (count($keys)) {
+                $key = array_shift($keys);
+                if (!isset($place[$key])) {
+                    $place[$key] = array();
+                }
+                $place = &$place[$key];
+            }
+
+            $place = $value;
+        }
     }
 
     function merge($vars)
@@ -79,7 +96,18 @@ class Variables {
     {
         Horde_Array::getArrayParts($varname, $base, $keys);
         if (!is_null($base)) {
-            eval("unset(\$this->_vars['" . $base . "']['" . implode("']['", $keys) . "']);");
+            $ptr = &$this->_vars[$base];
+            $end = count($keys) - 1;
+            foreach ($keys as $key => $val) {
+                if (!isset($ptr[$val])) {
+                    break;
+                }
+                if ($end == $key) {
+                    array_splice($ptr, array_search($val, array_keys($ptr)), 1);
+                } else {
+                    $ptr = &$ptr[$val];
+                }
+            }
         } else {
             unset($this->_vars[$varname]);
         }
