@@ -26,7 +26,7 @@ define('VCARD_GEO_LON',      1);
 /**
  * Class representing vCard entries.
  *
- * $Horde: framework/iCalendar/iCalendar/vcard.php,v 1.3.10.7 2006/03/03 09:07:21 jan Exp $
+ * $Horde: framework/iCalendar/iCalendar/vcard.php,v 1.3.10.8 2006/05/09 23:08:22 chuck Exp $
  *
  * Copyright 2003-2006 Karsten Fourmont (karsten@horde.org)
  *
@@ -127,7 +127,7 @@ class Horde_iCalendar_vcard extends Horde_iCalendar {
 
         static $rfc822;
         if (is_null($rfc822)) {
-            $rfc822 = &new Mail_RFC822();
+            $rfc822 = new Mail_RFC822();
         }
 
         $rfc822->validateMailbox($address);
