@@ -2,9 +2,9 @@
 /**
  * Class representing vJournals.
  *
- * $Horde: framework/iCalendar/iCalendar/vjournal.php,v 1.8.10.8 2008/07/03 08:42:58 jan Exp $
+ * $Horde: framework/iCalendar/iCalendar/vjournal.php,v 1.8.10.4 2006/01/01 21:28:47 jan Exp $
  *
- * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2003-2006 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -20,6 +20,11 @@ class Horde_iCalendar_vjournal extends Horde_iCalendar {
         return 'vJournal';
     }
 
+    function parsevCalendar($data)
+    {
+        parent::parsevCalendar($data, 'VJOURNAL');
+    }
+
     function exportvCalendar()
     {
         return parent::_exportvData('VJOURNAL');
