@@ -2,16 +2,15 @@
 /**
  * The Net_IMSP_Auth_plaintext class for IMSP authentication.
  *
- * Required parameters:
- * ====================
- * 'username'       -- Username to logon to IMSP server as.
- * 'password'       -- Password for current user.
- * 'server'         -- The hostname of the IMSP server.
- * 'port'           -- The port of the IMSP server.
+ * Required parameters:<pre>
+ *   'username'  Username to logon to IMSP server as.
+ *   'password'  Password for current user.
+ *   'server'    The hostname of the IMSP server.
+ *   'port'      The port of the IMSP server.</pre>
  *
- * $Horde: framework/Net_IMSP/IMSP/Auth/plaintext.php,v 1.7.10.4 2005/03/09 18:26:56 mrubinsk Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Auth/plaintext.php,v 1.7.10.11 2006/01/01 21:28:28 jan Exp $
  *
- * Copyright 2003-2005 Michael Rubinsky <mrubinsk@horde.org>
+ * Copyright 2003-2006 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -27,6 +26,7 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
      *
      * @access private
      * @param  mixed  $params Hash of IMSP parameters.
+     *
      * @return mixed  Net_IMSP object connected to server if successful,
      *                PEAR_Error on failure.
      */
@@ -55,10 +55,10 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
                 return $result;
             }
 
-            if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
+            if (!preg_match("/^\+/",
                             $imsp->imspReceive())) {
 
-                return $imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
+                return $imsp->imspError('Did not receive expected command continuation response from IMSP server.',
                                         __FILE__, __LINE__);
             }
         }
@@ -80,9 +80,9 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
                 return $result;
             }
 
-            if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
+            if (!preg_match("/^\+/",
                             $imsp->imspReceive())) {
-                return $imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
+                return $imsp->imspError('Did not receive expected command continuation response from IMSP server.',
                                         __FILE__, __LINE__);
             }
         }
@@ -101,7 +101,7 @@ class Net_IMSP_Auth_plaintext extends Net_IMSP_Auth {
         }
 
         if ($server_response != 'OK') {
-            return $imsp->imspError(IMSP_EXIT_LOGIN_FAILED, __FILE__, __LINE__);
+            return $imsp->imspError('Login to IMSP host failed.', __FILE__, __LINE__);
         }
 
         return $imsp;
