@@ -5,15 +5,14 @@ require_once 'PEAR.php';
 /**
  * Net_SMS Class
  *
- * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
  *
- * See the enclosed file COPYING for license information (LGPL). If you did not
- * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you did
+ * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Net_SMS/SMS.php,v 1.10.10.1 2005/01/03 12:19:09 jan Exp $
+ * $Horde: framework/Net_SMS/SMS.php,v 1.10.10.10 2006/01/01 21:28:28 jan Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.10.10.1 $
  * @package Net_SMS
  */
 class Net_SMS {
@@ -21,7 +20,7 @@ class Net_SMS {
     /**
      * A hash containing any parameters for the current gateway driver.
      *
-     * @var array $_params
+     * @var array
      */
     var $_params = array();
 
@@ -30,8 +29,7 @@ class Net_SMS {
     /**
      * Constructor
      *
-     * @param optional array $params  Any parameters needed for this gateway
-     *                                driver.
+     * @param array $params  Any parameters needed for this gateway driver.
      */
     function Net_SMS($params = null)
     {
@@ -41,8 +39,6 @@ class Net_SMS {
     /**
      * Returns a list of available gateway drivers.
      *
-     * @access public
-     *
      * @return array  An array of available drivers.
      */
     function getDrivers()
@@ -73,8 +69,6 @@ class Net_SMS {
      * Returns information on a gateway, such as name and a brief description,
      * from the driver subclass getInfo() function.
      *
-     * @access public
-     *
      * @return array  An array of extra information.
      */
     function getGatewayInfo($gateway)
@@ -95,8 +89,6 @@ class Net_SMS {
      * Returns parameters for a gateway from the driver subclass getParams()
      * function.
      *
-     * @access public
-     *
      * @param string  The name of the gateway driver for which to return the
      *                parameters.
      *
@@ -119,10 +111,8 @@ class Net_SMS {
     /**
      * Returns send parameters for a gateway from the driver subclass
      * getDefaultSendParams()function. These are parameters which are available
-     * to the user during sending, such as setting a time for delivery, or
-     * type of SMS (normal text or flash), or source address, etc.
-     *
-     * @access public
+     * to the user during sending, such as setting a time for delivery, or type
+     * of SMS (normal text or flash), or source address, etc.
      *
      * @param string  The name of the gateway driver for which to return the
      *                send parameters.
@@ -147,8 +137,6 @@ class Net_SMS {
      * Query the current Gateway object to find out if it supports the given
      * capability.
      *
-     * @access public
-     *
      * @param string $capability  The capability to test for.
      *
      * @return mixed  Whether or not the capability is supported or any other
@@ -165,8 +153,6 @@ class Net_SMS {
     /**
      * Authenticates against the gateway if required.
      *
-     * @access public
-     *
      * @return mixed  True on success or PEAR Error on failure.
      */
     function authenticate()
@@ -183,13 +169,13 @@ class Net_SMS {
      * Sends a message to one or more recipients. Hands off the actual sending
      * to the gateway driver.
      *
-     * @access public
-     *
      * @param array $message  The message to be sent, which is composed of:
+     *                        <pre>
      *                          id   - A unique ID for the message;
      *                          to   - An array of recipients;
      *                          text - The text of the message;
-     *                          
+     *                        </pre>
+     *
      *
      * @return mixed  True on success or PEAR Error on failure.
      */
@@ -268,9 +254,8 @@ class Net_SMS {
      * If the current driver has a credit capability, queries the gateway for
      * a credit balance and returns the value.
      *
-     * @access public
-     *
-     * @return int  Value indicating available credit or null if not supported.
+     * @return integer  Value indicating available credit or null if not
+     *                  supported.
      */
     function getBalance()
     {
@@ -290,46 +275,45 @@ class Net_SMS {
     /**
      * Attempts to return a concrete Gateway instance based on $driver.
      *
-     * @param string $driver          The type of concrete Gateway subclass to
-     *                                return. This is based on the gateway
-     *                                driver ($driver). The code is dynamically
-     *                                included.
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters a
-     *                                subclass might need.
+     * @param string $driver  The type of concrete Gateway subclass to return.
+     *                        This is based on the gateway driver ($driver).
+     *                        The code is dynamically included.
+     * @param array $params   A hash containing any additional configuration or
+     *                        connection parameters a subclass might need.
      *
-     * @return object Net_SMS  The newly created concrete Gateway instance or
-     *                         false on an error.
+     * @return Net_SMS  The newly created concrete Gateway instance or false on
+     *                  an error.
      */
     function &factory($driver, $params = array())
     {
         include_once 'Net/SMS/' . $driver . '.php';
         $class = 'Net_SMS_' . $driver;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $sms = &new $class($params);
         } else {
-            return PEAR::raiseError(sprintf(_("Class definition of %s not found."), $driver));
+            $sms = PEAR::raiseError(sprintf(_("Class definition of %s not found."), $driver));
         }
+
+        return $sms;
     }
 
     /**
      * Attempts to return a reference to a concrete Net_SMS instance based on
-     * $driver. It wil only create a new instance if no Net_SMS instance with
-     * the same parameters currently exists.
+     * $driver.
+     *
+     * It will only create a new instance if no Net_SMS instance with the same
+     * parameters currently exists.
      *
      * This method must be invoked as: $var = &Net_SMS::singleton()
      *
-     * @param string $driver          The type of concrete Net_SMS
-     *                                subclass to return. The is based on the
-     *                                gateway driver ($driver). The code is
-     *                                dynamically included.
+     * @param string $driver  The type of concrete Net_SMS subclass to return.
+     *                        The is based on the gateway driver ($driver).
+     *                        The code is dynamically included.
      *
-     * @param optional array $params  A hash containing any additional
-     *                                configuration or connection parameters a
-     *                                subclass might need.
+     * @param array $params  A hash containing any additional configuration or
+     *                       connection parameters a subclass might need.
      *
-     * @return mixed  The created concrete Net_SMS instance, or false on
-     *                error.
+     * @return mixed  The created concrete Net_SMS instance, or false on error.
      */
     function &singleton($driver, $params = array())
     {
