@@ -1,27 +1,26 @@
 <?php
 /**
- * Net_SMS_vodafoneitaly_smtp Class implements the SMTP API for accessing
- * the Vodafone Italy SMS gateway. Use of this gateway requires an email account
+ * Net_SMS_vodafoneitaly_smtp Class implements the SMTP API for accessing the
+ * Vodafone Italy SMS gateway. Use of this gateway requires an email account
  * with Vodafone Italy (www.190.it).
  *
- * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
- * Copyright 2003-2005 Matteo Zambelli <mmzambe@hotmail.com>
+ * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2006 Matteo Zambelli <mmzambe@hotmail.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Net_SMS/SMS/vodafoneitaly_smtp.php,v 1.11.10.1 2005/01/03 12:19:09 jan Exp $
+ * $Horde: framework/Net_SMS/SMS/vodafoneitaly_smtp.php,v 1.11.10.8 2006/01/01 21:28:29 jan Exp $
  *
  * @author Marko Djukic <marko@oblo.com>
  * @author Matteo Zambelli <mmzambe@hotmail.com>
- * @version $Revision: 1.11.10.1 $
  * @package Net_SMS
  */
 class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
 
     /**
      * An array of capabilities, so that the driver can report which operations
-     * it supports and which it doesn't. Possible values are:
+     * it supports and which it doesn't. Possible values are:<pre>
      *   auth        - The gateway require authentication before sending;
      *   batch       - Batch sending is supported;
      *   multi       - Sending of messages to multiple recipients is supported;
@@ -29,8 +28,9 @@ class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
      *   credit      - Is use of the gateway based on credits;
      *   addressbook - Are gateway addressbooks supported;
      *   lists       - Gateway support for distribution lists.
+     * </pre>
      *
-     * @var array $capabilities
+     * @var array
      */
     var $capabilities = array('auth'        => false,
                               'batch'       => false,
@@ -45,35 +45,38 @@ class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
      *
      * @access private
      *
-     * @param array  $message  The array containing the message and its send
-     *                         parameters.
-     * @param string $to       The destination string.
+     * @param array $message  The array containing the message and its send
+     *                        parameters.
+     * @param string $to      The destination string.
      *
-     * @return mixed  True on success or PEAR Error on failure.
+     * @return array  An array with the success status and additional
+     *                information.
      */
     function _send(&$message, $to)
     {
         if (!@include_once 'Mail.php') {
             return PEAR::raiseError(_("Missing required PEAR package Mail."));
         }
-        $mailer = &Mail::factory('mail');
+        $mailer = Mail::factory('mail');
 
         /* Since this only works for Italian numbers, this is hardcoded. */
         if (preg_match('/^.*?<?(\+?39)?(\d{10})>?/', $to, $matches)) {
             $headers['From'] = $this->_params['user'];
             $to = $matches[2] . '@sms.vodafone.it';
             $result = $mailer->send($to, $headers, $message['text']);
-            return $result;
+            if (is_a($result, 'PEAR_Error')) {
+                return array(0, $result->getMessage());
+            } else {
+                return array(1, null);
+            }
         } else {
-            return false;
+            return array(0, _("You need to provide an Italian phone number"));
         }
     }
 
     /**
      * Identifies this gateway driver and returns a brief description.
      *
-     * @access public
-     *
      * @return array  Array of driver info.
      */
     function getInfo()
@@ -87,8 +90,6 @@ class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
     /**
      * Returns the required parameters for this gateway driver.
      *
-     * @access public
-     *
      * @return array  Array of required parameters.
      */
     function getParams()
@@ -104,8 +105,6 @@ class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
      * Returns the parameters that can be set as default for sending messages
      * using this gateway driver and displayed when sending messages.
      *
-     * @access public
-     *
      * @return array  Array of parameters that can be set as default.
      */
     function getDefaultSendParams()
@@ -118,8 +117,6 @@ class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
      * displayed when sending messages. These are filtered out using the
      * default values set up when creating the gateway.
      *
-     * @access public
-     *
      * @return array  Array of required parameters.
      * @todo  Would be nice to use a time/date setup rather than minutes from
      *        now for the delivery time. Upload field for ringtones/logos?
@@ -132,16 +129,15 @@ class Net_SMS_vodafoneitaly_smtp extends Net_SMS {
     /**
      * Returns a string representation of an error code.
      *
-     * @access public
+     * @param integer $error  The error code to look up.
+     * @param string $text    An existing error text to use to raise a
+     *                        PEAR Error.
      *
-     * @param int $error             The error code to look up.
-     * @param optional string $text  An existing error text to use to raise a
-     *                               PEAR Error.
-     *
-     * @return mixed  A textual message corrisponding to the error code or a
+     * @return mixed  A textual message corresponding to the error code or a
      *                PEAR Error if passed an existing error text.
      *
-     * @todo  Check which of these are actually required and trim down the list.
+     * @todo  Check which of these are actually required and trim down the
+     *        list.
      */
     function getError($error, $error_text = '')
     {
