@@ -20,7 +20,7 @@
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/SyncML/SyncML/Backend.php,v 1.8.2.5 2006/03/06 14:02:53 jan Exp $
+ * $Horde: framework/SyncML/SyncML/Backend.php,v 1.8.2.8 2006/07/18 12:00:56 jan Exp $
  *
  * @author  Karsten Fourmont <karsten@horde.org>
  * @package SyncML
@@ -48,6 +48,12 @@ class SyncML_Backend_Horde {
 
     var $_datatree;
 
+    /**
+     * Cache for Datatree values
+     */
+     
+    var $_cache;
+    
     function SyncML_Backend_Horde()
     {
         $driver = $GLOBALS['conf']['datatree']['driver'];
@@ -55,6 +61,7 @@ class SyncML_Backend_Horde {
         $params = array_merge($params, array('group' => 'syncml'));
 
         $this->_datatree =& DataTree::singleton($driver, $params);
+        $this->_cache = array();
     }
 
     /**
@@ -286,7 +293,7 @@ class SyncML_Backend_Horde {
         if (!is_a($suid, 'PEAR_Error')) {
             $ts = $registry->call($serverdatabase. '/getActionTimestamp', array($suid, 'add'));
             if (!$ts) {
-                $this->logMessage('SyncML: unable to find add-ts for ' . $suid . ' at ' . $ts, __FILE__, __LINE__, PEAR_LOG_ERR);
+                $this->logMessage('Unable to find add-ts for ' . $suid . ' at ' . $ts, __FILE__, __LINE__, PEAR_LOG_ERR);
             }
             $this->createUidMap($syncIdentifier, $database, $cuid, $suid, $ts);
         }
@@ -403,6 +410,7 @@ class SyncML_Backend_Horde {
                 // Object already exists: update instead.
                 $this->_datatree->updateData($info);
             }
+            $this->_cache[$info->getName()] = $info;
         }
     }
 
@@ -429,6 +437,7 @@ class SyncML_Backend_Horde {
             // Object already exists: update instead.
             $r = $this->_datatree->updateData($gid);
         }
+        $this->_cache[$gid->getName()] = $gid;
         $this->dieOnError($r, __FILE__, __LINE__);
 
         // Set $globaluid
@@ -440,6 +449,7 @@ class SyncML_Backend_Horde {
             // Object already exists: update instead.
             $r = $this->_datatree->updateData($lid);
         }
+        $this->_cache[$lid->getName()] = $lid;
         $this->dieOnError($r, __FILE__, __LINE__);
 
         // If tasks and events are handled at once, we need to store
@@ -463,6 +473,7 @@ class SyncML_Backend_Horde {
                 // Object already exists: update instead.
                 $r = $this->_datatree->updateData($gid);
             }
+            $this->_cache[$gid->getName()] = $gid;
             $this->dieOnError($r, __FILE__, __LINE__);
 
             // Set $globaluid
@@ -474,6 +485,7 @@ class SyncML_Backend_Horde {
                 // Object already exists: update instead.
                 $r = $this->_datatree->updateData($lid);
             }
+            $this->_cache[$lid->getName()] = $lid;
             $this->dieOnError($r, __FILE__, __LINE__);
         }
     }
@@ -632,6 +644,7 @@ class SyncML_Backend_Horde {
             // Object already exists: update instead.
             $r = $this->_datatree->updateData($map);
         }
+        $this->_cache[$map->getName()] = $map;
         $this->dieOnError($r, __FILE__, __LINE__);
     }
 
@@ -653,11 +666,10 @@ class SyncML_Backend_Horde {
 
     function &_getOb($name)
     {
-        static $cache = array();
-        if (!isset($cache[$name])) {
-            $cache[$name] =& $this->_datatree->getObject($name);
+        if (!isset($this->_cache[$name])) {
+            $this->_cache[$name] =& $this->_datatree->getObject($name);
         }
-        return $cache[$name];
+        return $this->_cache[$name];
     }
 
 }
