@@ -3,7 +3,7 @@
 include_once 'SyncML/Command.php';
 
 /**
- * $Horde: framework/SyncML/SyncML/Command/Put.php,v 1.12.10.5 2006/01/01 21:28:36 jan Exp $
+ * $Horde: framework/SyncML/SyncML/Command/Put.php,v 1.12.10.7 2006/05/31 17:06:36 selsky Exp $
  *
  * The SyncML_Command_Put:: class handles DevInf device information
  * sent by the client. The data is stored in a SyncML_DeviceInfo
@@ -60,6 +60,13 @@ class SyncML_Command_Put extends SyncML_Command {
         switch (count($this->_Stack)) {
         case 1:
             $_SESSION['SyncML.state']->setDeviceInfo($di);
+            if (DEBUGLOG_DEVINF) {
+                $fp = @fopen('/tmp/sync/devinf.txt', 'a');
+                if ($fp) {
+                    @fwrite($fp, var_export($di, true));
+                    @fclose($fp);
+                }
+            }
 
         case 5:
             switch ($element) {
@@ -241,7 +248,7 @@ class SyncML_Command_Put extends SyncML_Command {
         parent::endElement($uri, $element);
     }
 
-    function output($currentCmdID, &$output )
+    function output($currentCmdID, &$output)
     {
         $state = &$_SESSION['SyncML.state'];
 
