@@ -25,12 +25,12 @@ if (!function_exists('_')) {
  * The Horde_Test:: class provides functions used in the test scripts
  * used in the various applications (test.php).
  *
- * $Horde: horde/lib/Test.php,v 1.31.4.4 2005/03/05 20:21:15 chuck Exp $
+ * $Horde: horde/lib/Test.php,v 1.31.4.19 2006/03/28 12:31:13 jan Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
- * Copyright 2002-2005 Brent J. Nordquist <bjn@horde.org>
- * Copyright 2003-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
+ * Copyright 2002-2006 Brent J. Nordquist <bjn@horde.org>
+ * Copyright 2003-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -48,44 +48,32 @@ class Horde_Test {
      * Array that holds the list of Horde applications.
      * (Loaded from config/registry.php)
      *
-     * @var array $applications
+     * @var array
      */
     var $applications = array();
 
     /**
      * Cached results of getApplications().
      *
-     * @var array $_appoutput
+     * @var array
      */
     var $_appoutput = array();
 
     /**
      * The PHP version of the system.
      *
-     * @var array $_phpver
+     * @var array
      */
     var $_phpver;
 
-    /**
-     * Location of the base Horde test script.
-     *
-     * @var string $_testscript
-     */
-    var $_testscript;
-
     /**
      * Constructor.
-     *
-     * @access public
      */
     function Horde_Test()
     {
         include_once HORDE_BASE . '/config/registry.php';
         ksort($this->applications);
 
-        /* Set the location of the base test script. */
-        $this->_testscript = $_SERVER['PHP_SELF'];
-
         /* Store the PHP version information. */
         $this->_phpver = $this->splitPHPVersion(phpversion());
 
@@ -100,8 +88,6 @@ class Horde_Test {
     /**
      * Parse PHP version.
      *
-     * @access public
-     *
      * @param string $version  A PHP-style version string (X.X.X).
      *
      * @param array  The parsed string.
@@ -159,8 +145,6 @@ class Horde_Test {
     /**
      * Check the list of PHP modules.
      *
-     * @access public
-     *
      * @param array $modlist  The module list.
      * <pre>
      * KEY:   module name
@@ -225,8 +209,6 @@ class Horde_Test {
     /**
      * Checks the list of PHP settings.
      *
-     * @access public
-     *
      * @param array $modlist  The settings list.
      * <code>
      * KEY:   setting name
@@ -261,8 +243,6 @@ class Horde_Test {
     /**
      * Check the list of PEAR modules.
      *
-     * @access public
-     *
      * @param array $pear_list  The PEAR module list.
      * <pre>
      * KEY:   PEAR class name
@@ -284,7 +264,7 @@ class Horde_Test {
         ini_set('track_errors', 1);
 
         /* Print the include_path. */
-        $output .= $this->_outputLine(array("<b>PEAR Search Path (PHP's include_path)</b>", '&nbsp;<tt>' . ini_get('include_path') . '</tt>'));
+        $output .= $this->_outputLine(array("<strong>PEAR Search Path (PHP's include_path)</strong>", '&nbsp;<tt>' . ini_get('include_path') . '</tt>'));
 
         /* Check for PEAR in general. */
         {
@@ -358,8 +338,6 @@ class Horde_Test {
     /**
      * Check the list of required files
      *
-     * @access public
-     *
      * @param array $file_list  The file list.
      * <pre>
      * KEY:   file path
@@ -394,25 +372,32 @@ class Horde_Test {
     }
 
     /**
-     * Displays an error screen with a list of all configuration files
-     * that are missing, together with a description what they do and
-     * how they are created. If a file can be automatically created
-     * from the defaults, then we do that instead and don't display an
-     * error.
+     * Displays an error screen with a list of all configuration files that
+     * are missing, together with a description what they do and how they are
+     * created. If a file can be automatically created from the defaults, then
+     * we do that instead and don't display an error.
      *
      * @param string $app        The application name
      * @param string $appBase    The path to the application
-     * @param array  $files      An array with the "standard" configuration files
-     *                           that should be checked. Currently supported:
+     * @param array  $files      An array with the "standard" configuration
+     *                           files that should be checked. Currently
+     *                           supported:
      *                           - conf.php
      *                           - prefs.php
      *                           - mime_drivers.php
-     * @param array $additional  (optional) An associative array containing
-     *                           more files (as keys) and error message (as
-     *                           values) if they don't exist.
+     * @param array $additional  An associative array containing more files (as
+     *                           keys) and error message (as values) if they
+     *                           don't exist.
      */
     function configFilesMissing($app, $appBase, $files, $additional = array())
     {
+        /* Try to load a basic framework if we're testing an app other than
+         * the Horde base files. */
+        if ($app != 'Horde') {
+            $GLOBALS['registry'] = &Registry::singleton();
+            $GLOBALS['registry']->pushApp('horde', false);
+        }
+
         if (!is_array($files)) {
             $files = array($files);
         }
@@ -442,7 +427,7 @@ class Horde_Test {
                                   'scripts. You need to login as an ' .
                                   'administrator and create the file with ' .
                                   'the web frontend under "Administration => ' .
-                                  'Configuration".',
+                                  'Setup".',
                                   $app, $app, $appBase . '/config'),
             'prefs.php' => sprintf('This file controls the default preferences ' .
                                    'for %s, and also controls which preferences ' .
@@ -456,6 +441,20 @@ class Horde_Test {
             'sources.php' => sprintf('This file defines the list of available ' .
                                      'sources for %s.', $app)
         ), $additional);
+
+        /* If we know the user is an admin, give them a direct link to
+         * generate conf.php. In the future, should we try generating
+         * a basic conf.php automagically here? */
+        if (Auth::isAdmin()) {
+            $setup_url = Horde::link(Horde::url($GLOBALS['registry']->get('webroot', 'horde') .
+                                                '/admin/setup/config.php?app=' . String::lower($app))) .
+                'Configuration Web Interface' . '</a>';
+            $descriptions['conf.php'] =
+                sprintf('This is the main %s configuration file. ' .
+                        'Generate it by going to the %s.',
+                        $app, $setup_url);
+        }
+
         $title = sprintf('%s is not properly configured', $app);
         $header = sprintf('Some of %s\'s configuration files are missing or unreadable', $app);
         $footer = sprintf('Create these files from their .dist versions in %s and change them according to your needs.', $appBase . '/config');
@@ -468,6 +467,9 @@ class Horde_Test {
 HEADER;
 
         foreach ($files as $file) {
+            if (empty($descriptions[$file])) {
+                continue;
+            }
             $description = $descriptions[$file];
             echo <<< FILE
     <h3>$file</h3><p>$description</p>
@@ -486,8 +488,6 @@ FOOTER;
     /**
      * Check the list of required Horde applications.
      *
-     * @access public
-     *
      * @param array $app_list  The application list.
      * <pre>
      * KEY:   application name
@@ -531,8 +531,6 @@ FOOTER;
     /**
      * Is this a 'recent' version of PEAR?
      *
-     * @access public
-     *
      * @param boolean  True if a recent version of PEAR.
      */
     function isRecentPEAR()
@@ -547,8 +545,6 @@ FOOTER;
     /**
      * Obtain information on the PHP version.
      *
-     * @access public
-     *
      * @return object stdClass  TODO
      */
     function getPhpVersionInformation()
@@ -557,8 +553,9 @@ FOOTER;
         $url = urlencode($_SERVER['PHP_SELF']);
         $vers_check = true;
 
-        $output->phpinfo = $this->_testscript . '?mode=phpinfo&url=' . $url;
-        $output->extensions = $this->_testscript . '?mode=extensions&url=' . $url;
+        $testscript = $this->applications['horde']['webroot'] . '/test.php';
+        $output->phpinfo = $testscript . '?mode=phpinfo&url=' . $url;
+        $output->extensions = $testscript . '?mode=extensions&url=' . $url;
         $output->version = phpversion();
         $output->major = $this->_phpver['major'];
         if (isset($this->_phpver['minor'])) {
@@ -573,12 +570,12 @@ FOOTER;
         if ($output->major < '4.3') {
             $output->status = 'This version of PHP is not supported. You need to upgrade to a more recent version.';
             $vers_check = false;
-        } elseif (($output->major == '4.3') || ($output->major == '4.4')) {
+        } elseif (($output->major == '4.3') ||
+                  ($output->major == '4.4') ||
+                  ($output->major == '5.0') ||
+                  ($output->major == '5.1')) {
             $output->status = 'You are running a supported version of PHP.';
             $output->status_color = 'green';
-        } elseif ($output->major == '5.0') {
-            $output->status = 'PHP 5 is supported experimentally. You may not see any error messages, but the changed behaviour of objects in PHP 5 has unpredictable side effects.';
-            $ouput->status_color = 'orange';
         } else {
             $output->status = 'Wow, a mystical version of PHP from the future. Let <a href="mailto:dev@lists.horde.org">dev@lists.horde.org</a> know what version you have so we can fix this script.';
             $output->status_color = 'orange';
@@ -594,8 +591,6 @@ FOOTER;
     /**
      * Get the application list.
      *
-     * @access public
-     *
      * @return array  List of stdClass objects.
      *                KEY: application name
      *                ELEMENT 'version': Version of application
@@ -612,11 +607,10 @@ FOOTER;
                 ($det['status'] != 'block') &&
                 is_readable($det['fileroot'] . '/lib/version.php')) {
                 require_once $det['fileroot'] . '/lib/version.php';
-                eval('$defined = defined(\'' . strtoupper($mod) . '_VERSION\');');
-                if ($defined) {
-                    eval('$ver = ' . strtoupper($mod) . '_VERSION;');
+                $version_constant = String::upper($mod) . '_VERSION';
+                if (defined($version_constant)) {
                     $this->_appoutput[$mod] = &new stdClass;
-                    $this->_appoutput[$mod]->version = $ver;
+                    $this->_appoutput[$mod]->version = constant($version_constant);
                     if (($mod != 'horde') &&
                         @is_readable($det['fileroot'] . '/test.php')) {
                         $this->_appoutput[$mod]->test = $det['webroot'] . '/test.php';
@@ -641,11 +635,11 @@ FOOTER;
     function _status($bool, $required = true)
     {
         if ($bool) {
-            return '<font color="green"><b>Yes</b></font>';
+            return '<font color="green"><strong>Yes</strong></font>';
         } elseif ($required) {
-            return '<font color="red"><b>No</b></font>';
+            return '<font color="red"><strong>No</strong></font>';
         } else {
-            return '<font color="orange"><b>No</b></font>';
+            return '<font color="orange"><strong>No</strong></font>';
         }
     }
 
@@ -669,7 +663,7 @@ FOOTER;
         $output = '<li>' . array_shift($entry) . ': ' . array_shift($entry);
         if (!empty($entry)) {
             $msg = array_shift($entry);
-            $output .= '<br /><font color="' . (empty($entry) || !array_shift($entry) ? 'red' : 'orange') . '"><b>' . $msg . '</b></font>' . "\n";
+            $output .= '<br /><font color="' . (empty($entry) || !array_shift($entry) ? 'red' : 'orange') . '"><strong>' . $msg . '</strong></font>' . "\n";
         }
         $output .= '</li>' . "\n";
 
