@@ -8,7 +8,7 @@
  * The PHP diff code used in this package was originally written by Geoffrey
  * T. Dairiki and is used with his permission.
  *
- * $Horde: framework/Text_Diff/Diff.php,v 1.11.2.1 2005/03/22 09:54:05 jan Exp $
+ * $Horde: framework/Text_Diff/Diff.php,v 1.11.2.7 2006/02/06 00:25:52 jan Exp $
  *
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
@@ -18,7 +18,7 @@ class Text_Diff {
     /**
      * Array of changes.
      *
-     * @var array $_edits
+     * @var array
      */
     var $_edits;
 
@@ -68,7 +68,7 @@ class Text_Diff {
     function reverse()
     {
         if (version_compare(zend_version(), '2', '>')) {
-            $rev = clone($obj);
+            $rev = clone($this);
         } else {
             $rev = $this;
         }
@@ -97,9 +97,9 @@ class Text_Diff {
     /**
      * Computes the length of the Longest Common Subsequence (LCS).
      *
-     * This is mostly for diagnostic purposed.
+     * This is mostly for diagnostic purposes.
      *
-     * @return int  The length of the LCS.
+     * @return integer  The length of the LCS.
      */
     function lcs()
     {
@@ -196,7 +196,7 @@ class Text_Diff {
 }
 
 /**
- * $Horde: framework/Text_Diff/Diff.php,v 1.11.2.1 2005/03/22 09:54:05 jan Exp $
+ * $Horde: framework/Text_Diff/Diff.php,v 1.11.2.7 2006/02/06 00:25:52 jan Exp $
  *
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
@@ -252,7 +252,8 @@ class Text_MappedDiff extends Text_Diff {
  *
  * @author  Jon Parise <jon@horde.org>
  * @package Text_Diff
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Engine_xdiff {
 
@@ -307,7 +308,7 @@ class Text_Diff_Engine_xdiff {
  * More ideas are taken from:
  * http://www.ics.uci.edu/~eppstein/161/960229.html
  *
- * Some ideas (and a bit of code) are from from analyze.c, from GNU
+ * Some ideas (and a bit of code) are taken from analyze.c, of GNU
  * diffutils-2.7, which can be found at:
  * ftp://gnudist.gnu.org/pub/gnu/diffutils/diffutils-2.7.tar.gz
  *
@@ -317,7 +318,8 @@ class Text_Diff_Engine_xdiff {
  *
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
  * @package Text_Diff
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Engine_native {
 
@@ -335,7 +337,7 @@ class Text_Diff_Engine_native {
 
         // Skip leading common lines.
         for ($skip = 0; $skip < $n_from && $skip < $n_to; $skip++) {
-            if ($from_lines[$skip] != $to_lines[$skip]) {
+            if ($from_lines[$skip] !== $to_lines[$skip]) {
                 break;
             }
             $this->xchanged[$skip] = $this->ychanged[$skip] = false;
@@ -344,7 +346,7 @@ class Text_Diff_Engine_native {
         // Skip trailing common lines.
         $xi = $n_from; $yi = $n_to;
         for ($endskip = 0; --$xi > $skip && --$yi > $skip; $endskip++) {
-            if ($from_lines[$xi] != $to_lines[$yi]) {
+            if ($from_lines[$xi] !== $to_lines[$yi]) {
                 break;
             }
             $this->xchanged[$xi] = $this->ychanged[$yi] = false;
@@ -728,7 +730,8 @@ class Text_Diff_Engine_native {
 /**
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Op {
 
@@ -755,7 +758,8 @@ class Text_Diff_Op {
 /**
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Op_copy extends Text_Diff_Op {
 
@@ -770,7 +774,8 @@ class Text_Diff_Op_copy extends Text_Diff_Op {
 
     function &reverse()
     {
-        return $reverse = &new Text_Diff_Op_copy($this->final, $this->orig);
+        $reverse = &new Text_Diff_Op_copy($this->final, $this->orig);
+        return $reverse;
     }
 
 }
@@ -778,7 +783,8 @@ class Text_Diff_Op_copy extends Text_Diff_Op {
 /**
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Op_delete extends Text_Diff_Op {
 
@@ -790,7 +796,8 @@ class Text_Diff_Op_delete extends Text_Diff_Op {
 
     function &reverse()
     {
-        return $reverse = &new Text_Diff_Op_add($this->orig);
+        $reverse = &new Text_Diff_Op_add($this->orig);
+        return $reverse;
     }
 
 }
@@ -798,7 +805,8 @@ class Text_Diff_Op_delete extends Text_Diff_Op {
 /**
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Op_add extends Text_Diff_Op {
 
@@ -810,7 +818,8 @@ class Text_Diff_Op_add extends Text_Diff_Op {
 
     function &reverse()
     {
-        return $reverse = &new Text_Diff_Op_delete($this->final);
+        $reverse = &new Text_Diff_Op_delete($this->final);
+        return $reverse;
     }
 
 }
@@ -818,7 +827,8 @@ class Text_Diff_Op_add extends Text_Diff_Op {
 /**
  * @package Text_Diff
  * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
- * @access  private
+ *
+ * @access private
  */
 class Text_Diff_Op_change extends Text_Diff_Op {
 
@@ -830,7 +840,8 @@ class Text_Diff_Op_change extends Text_Diff_Op {
 
     function &reverse()
     {
-        return $reverse = &new Text_Diff_Op_change($this->final, $this->orig);
+        $reverse = &new Text_Diff_Op_change($this->final, $this->orig);
+        return $reverse;
     }
 
 }
