@@ -1,22 +1,21 @@
 <?php
 /**
  * The Text_Flowed:: class provides common methods for manipulating text
- * using the encoding described in RFC 2646 ('flowed' text).
+ * using the encoding described in RFC 3676 ('flowed' text).
  *
- * $Horde: framework/Text_Flowed/Flowed.php,v 1.14.10.3 2005/02/04 03:13:41 slusarz Exp $
+ * $Horde: framework/Text_Flowed/Flowed.php,v 1.14.10.17 2006/03/11 09:50:22 jan Exp $
  *
  * This class is based on the Text::Flowed perl module (Version 0.14) found
  * in the CPAN perl repository.  This module is released under the Perl
  * license, which is compatible with the LGPL.
  *
  * Copyright 2002-2003 Philip Mak
- * Copyright 2004-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2004-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.14.10.3 $
  * @since   Horde 3.0
  * @package Horde_Text
  */
@@ -24,10 +23,10 @@ class Text_Flowed {
 
     /**
      * The maximum length that a line is allowed to be (unless faced with
-     * with a word that is unreasonably long. This class will re-wrap a
+     * with a word that is unreasonably long). This class will re-wrap a
      * line if it exceeds this length.
      *
-     * @var integer $_maxlength
+     * @var integer
      */
     var $_maxlength = 78;
 
@@ -35,41 +34,53 @@ class Text_Flowed {
      * When this class wraps a line, the newly created lines will be split
      * at this length.
      *
-     * @var integer $_optlength
+     * @var integer
      */
     var $_optlength = 72;
 
     /**
      * The text to be formatted.
      *
-     * @var string $_text
+     * @var string
      */
-    var $_text = '';
+    var $_text;
 
     /**
      * The cached output of the formatting.
      *
-     * @var array $_output
+     * @var array
      */
     var $_output = null;
 
+    /**
+     * The character set of the text.
+     *
+     * @var string
+     */
+    var $_charset;
+
+    /**
+     * Convert text using DelSp?
+     *
+     * @var boolean
+     */
+    var $_delsp = false;
+
     /**
      * Constructor.
      *
-     * @access public
-     *
-     * @param string $text  The text to process.
+     * @param string $text     The text to process.
+     * @param string $charset  The character set of $text.
      */
-    function Text_Flowed($text)
+    function Text_Flowed($text, $charset = null)
     {
         $this->_text = $text;
+        $this->_charset = $charset;
     }
 
     /**
      * Set the maximum length of a line of text.
      *
-     * @access public
-     *
      * @param integer $max  A new value for $_maxlength.
      */
     function setMaxLength($max)
@@ -80,35 +91,41 @@ class Text_Flowed {
     /**
      * Set the optimal length of a line of text.
      *
-     * @access public
-     *
      * @param integer $max  A new value for $_optlength.
      */
     function setOptLength($opt)
     {
         $this->_optlength = $opt;
     }
-        
+
+    /**
+     * Set whether to format test using DelSp.
+     *
+     * @since Horde 3.1
+     *
+     * @param boolean $delsp  Use DelSp?
+     */
+    function setDelSp($delsp)
+    {
+        $this->_delsp = (bool) $delsp;
+    }
+
     /**
      * Reformats the input string, where the string is 'format=flowed' plain
      * text as described in RFC 2646.
      *
-     * @access public
+     * @param boolean $quote  Add level of quoting to each line?
      *
-     * @param optional boolean $quote  Add level of quoting to each line?
-     *
-     * @return string  The reformatted string.
+     * @return string  The text converted to RFC 2646 'fixed' format.
      */
     function toFixed($quote = false)
     {
-        $this->_reformat(false, $quote);
-
         $txt = '';
 
+        $this->_reformat(false, $quote);
         foreach ($this->_output as $val) {
             $txt .= $val['text'] . "\n";
         }
-
         return rtrim($txt);
     }
 
@@ -116,9 +133,7 @@ class Text_Flowed {
      * Reformats the input string, and returns the output in an array format
      * with quote level information.
      *
-     * @access public
-     *
-     * @param optional boolean $quote  Add level of quoting to each line?
+     * @param boolean $quote  Add level of quoting to each line?
      *
      * @return array  An array of arrays with the following elements:
      * <pre>
@@ -133,24 +148,21 @@ class Text_Flowed {
     }
 
     /**
-     * Convert the text to 'flowed' format.
+     * Reformats the input string, where the string is 'format=fixed' plain
+     * text as described in RFC 2646.
      *
-     * @access public
-     *
-     * @param optional boolean $quote  Add level of quoting to each line?
+     * @param boolean $quote  Add level of quoting to each line?
      *
      * @return string  The text converted to RFC 2646 'flowed' format.
      */
     function toFlowed($quote = false)
     {
-        $this->_reformat(true, $quote);
-
         $txt = '';
 
+        $this->_reformat(true, $quote);
         foreach ($this->_output as $val) {
             $txt .= $val['text'] . "\n";
         }
-
         return $txt;
     }
 
@@ -174,52 +186,52 @@ class Text_Flowed {
         $this->_output = array();
         $text = explode("\n", $this->_text);
 
+        /* Set variables used in regexps. */
+        $delsp = ($toflowed && $this->_delsp) ? 1 : 0;
+        $opt = $this->_optlength - 1 - $delsp;
+
         /* Process message line by line. */
         do {
             $line = array_shift($text);
 
             /* Per RFC 2646 [4.3], the 'Usenet Signature Convention' line
-             * (DASH DASH SP) is not considered flowed. If converting to
-             * fixed, we ignore it as it is already in fixed format. */
-            if (!$toflowed) {
-                /* We need to strip all quotes from the beginning of the
-                 * line because the signature may be in a quoted part. */
-                $temp_line = preg_replace("/^>+\s+/", '', $line);
-                if ($temp_line == '-- ') {
-                    $this->_output[] = array('text' => $line, 'level' => 0);
-                    continue;
-                }
-            }
+             * (DASH DASH SP) is not considered flowed.  Watch for this when
+             * dealing with potentially flowed lines. */
 
             /* The next three steps come from RFC 2646 [4.2]. */
             /* STEP 1: Determine quote level for line. */
             if (($num_quotes = $this->_numquotes($line))) {
-                $line = ltrim($line, '>');
-            } 
+                $line = substr($line, $num_quotes);
+            }
 
-            /* STEP 2: Remove space stuffing from line. */
-            $line = $this->_unstuff($line);
+            /* Only combine lines if we are converting to flowed or if the
+             * current line is quoted. */
+            if (!$toflowed || $num_quotes) {
+                /* STEP 2: Remove space stuffing from line. */
+                $line = $this->_unstuff($line);
 
-            /* STEP 3: Should we interpret this line as flowed?
-             * While line is flowed (not empty and there is a space
-             * at the end of the line), and there is a next line, and the
-             * next line has the same quote depth, add to the current
-             * line. A line is not flowed if it is a signature line. */
-            if ($line != '-- ') {
+                /* STEP 3: Should we interpret this line as flowed?
+                 * While line is flowed (not empty and there is a space
+                 * at the end of the line), and there is a next line, and the
+                 * next line has the same quote depth, add to the current
+                 * line. A line is not flowed if it is a signature line. */
                 while (!empty($line) &&
-                       preg_match('/ $/', $line) &&
+                       ($line != '-- ') &&
+                       ($line{strlen($line)-1} == ' ') &&
                        !empty($text) &&
                        ($this->_numquotes($text[0]) == $num_quotes)) {
-                    /* Join the next line. */
-                    $newline = array_shift($text);
-                    if ($num_quotes) {
-                        $newline = ltrim($newline, '>');
+                    /* If DelSp is yes and this is flowed input, we need to
+                     * remove the trailing space. */
+                    if (!$toflowed && $this->_delsp) {
+                        $line = substr($line, 0, -1);
                     }
-                    $line .= $this->_unstuff($newline);
+                    $line .= $this->_unstuff(substr(array_shift($text), $num_quotes));
                 }
+            }
 
-                /* Ensure line is fixed, since we already joined all flowed
-                 * lines. Remove all trailing ' ' from the line. */
+            /* Ensure line is fixed, since we already joined all flowed
+             * lines. Remove all trailing ' ' from the line. */
+            if ($line != '-- ') {
                 $line = rtrim($line);
             }
 
@@ -234,36 +246,51 @@ class Text_Flowed {
             if (empty($line)) {
                 /* Line is empty. */
                 $this->_output[] = array('text' => $quotestr, 'level' => $num_quotes);
-            } elseif (empty($this->_maxlength) || ((String::length($line) + $num_quotes) <= $this->_maxlength)) {
+            } elseif (empty($this->_maxlength) || ((String::length($line, $this->_charset) + $num_quotes) <= $this->_maxlength)) {
                 /* Line does not require rewrapping. */
                 $this->_output[] = array('text' => $quotestr . $this->_stuff($line, $num_quotes, $toflowed), 'level' => $num_quotes);
             } else {
+                $min = $num_quotes + 1;
+
                 /* Rewrap this paragraph. */
                 while ($line) {
-                    /* Set variables used in regexps. */
-                    $max = $this->_maxlength;
-                    $min = $num_quotes + 1;
-                    $opt = $this->_optlength - 1;
-
                     /* Stuff and re-quote the line. */
                     $line = $quotestr . $this->_stuff($line, $num_quotes, $toflowed);
-
-                    if (String::length($line) <= $this->_optlength) {
+                    $line_length = String::length($line, $this->_charset);
+                    if ($line_length <= $this->_optlength) {
                         /* Remaining section of line is short enough. */
                         $this->_output[] = array('text' => $line, 'level' => $num_quotes);
                         break;
-                    } elseif (preg_match('/^(.{' . $min . ',' . $opt . '}) (.*)/', $line, $m) ||
-                              preg_match('/^(.{' . $min . ',' . $max . '}) (.*)/', $line, $m) ||
-                              preg_match('/^(.{' . $min . ',})? (.*)/', $line, $m)) {
-                        /* 1. Try to find a string as long as _optlength.
+                    } elseif ($m = String::regexMatch($line, array('^(.{' . $min . ',' . $opt . '}) (.*)', '^(.{' . $min . ',' . $this->_maxlength . '}) (.*)', '^(.{' . $min . ',})? (.*)'), $this->_charset)) {
+                        /* We need to wrap text at a certain number of
+                         * *characters*, not a certain number of *bytes*;
+                         * thus the need for a multibyte capable regex.
+                         * If a multibyte regex isn't available, we are stuck
+                         * with preg_match() (the function will still work -
+                         * we will just be left with shorter rows than expected
+                         * if multibyte characters exist in the row).
+                         *
+                         * Algorithim:
+                         * 1. Try to find a string as long as _optlength.
                          * 2. Try to find a string as long as _maxlength.
                          * 3. Take the first word. */
-                        $this->_output[] = array('text' => $m[1] . ' ', 'level' => $num_quotes);
+                        if (empty($m[1])) {
+                            $m[1] = $m[2];
+                            $m[2] = '';
+                        }
+                        $this->_output[] = array('text' => $m[1] . ' ' . (($delsp) ? ' ' : ''), 'level' => $num_quotes);
                         $line = $m[2];
                     } else {
-                        /* One excessively long word left on line. */
-                        $this->_output[] = array('text' => $line, 'level' => $num_quotes);
-                        break;
+                        /* One excessively long word left on line.  Be
+                         * absolutely sure it does not exceed 998 characters
+                         * in length or else we must truncate. */
+                        if ($line_length > 998) { 
+                            $this->_output[] = array('text' => String::substr($line, 0, 998, $this->_charset), 'level' => $num_quotes);
+                            $line = String::substr($line, 998, null, $this->_charset);
+                        } else {
+                            $this->_output[] = array('text' => $line, 'level' => $num_quotes);
+                            break;
+                        }
                     }
                 }
             }
@@ -282,10 +309,9 @@ class Text_Flowed {
      */
     function _numquotes($text)
     {
-        return (preg_match('/^(>+)/', $text, $matches)) ? strlen($matches[1]) : 0;
+        return strspn($text, '>');
     }
 
-
     /**
      * Space-stuffs if it starts with ' ' or '>' or 'From ', or if
      * quote depth is non-zero (for aesthetic reasons so that there is a
@@ -295,18 +321,17 @@ class Text_Flowed {
      *
      * @param string $text        The text to stuff.
      * @param string $num_quotes  The quote-level of this line.
-     * @param boolean $toflowed   Converting to flowed format?
+     * @param boolean $toflowed   Are we converting to flowed text?
      *
      * @return string  The stuffed text.
      */
     function _stuff($text, $num_quotes, $toflowed)
     {
-        if ($num_quotes ||
-            ($toflowed && preg_match('/^(?: |>|From )/', $text))) {
+        if ($toflowed &&
+            ($num_quotes || preg_match("/^(?: |>|From |From$)/", $text))) {
             return ' ' . $text;
-        } else {
-            return $text;
         }
+        return $text;
     }
 
     /**
@@ -320,10 +345,9 @@ class Text_Flowed {
      */
     function _unstuff($text)
     {
-        if (strpos($text, ' ') === 0) {
+        if (!empty($text) && ($text{0} == ' ')) {
             $text = substr($text, 1);
         }
-
         return $text;
     }
 
