@@ -5,20 +5,23 @@ require_once dirname(__FILE__) . '/../Formatter.php';
 /**
  * The Text_reST_Formatter_html:: class is the HTML formatter.
  *
- * $Horde: framework/Text_reST/reST/Formatter/html.php,v 1.6.12.1 2005/01/03 12:19:17 jan Exp $
+ * $Horde: framework/Text_reST/reST/Formatter/html.php,v 1.6.12.5 2006/01/01 21:28:39 jan Exp $
  *
- * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
+ * Copyright 2003-2006 Jason M. Felice <jfelice@cronosys.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jason M. Felice <jfelice@cronosys.com>
- * @version $Revision: 1.6.12.1 $
  * @package Text_reST
  */
 class Text_reST_Formatter_html extends Text_reST_Formatter {
 
-    /** The current output charset. */
+    /**
+     * The current output charset.
+     *
+     * @var string
+     */
     var $_charset = null;
 
     function format(&$node, $charset = null)
@@ -41,14 +44,14 @@ class Text_reST_Formatter_html extends Text_reST_Formatter {
 
         case 'Heading':
             $level = $node->getProperty('level');
-            return '<h' . $level . '>' . $this->_children($node) . '</h' . 
+            return '<h' . $level . '>' . $this->_children($node) . '</h' .
                 $level . '>';
 
         case 'Link':
             return '<a href="' .
-                (isset($charset) ? 
+                (isset($charset) ?
                  @htmlspecialchars($node->getProperty('href'), ENT_QUOTES, $charset) :
-                 htmlspecialchars($node->getProperty('href'), ENT_QUOTES)) . 
+                 htmlspecialchars($node->getProperty('href'), ENT_QUOTES)) .
                 '">' .
                 $this->_children($node) . '</a>';
 
@@ -71,7 +74,7 @@ class Text_reST_Formatter_html extends Text_reST_Formatter {
 
             case 'strong':
                 return '<strong>' . $this->_children($node) . '</strong>';
-            
+
             case 'superscript':
                 return '<sup>' . $this->_children($node) . '</sup>';
 
@@ -86,9 +89,6 @@ class Text_reST_Formatter_html extends Text_reST_Formatter {
                 return $this->_children($node);
             }
 
-        case 'Paragraph':
-            return "<p>" . $this->_children($node) . "</p>";
-
         case 'Section':
             return $this->_children($node);
         }
