@@ -11,7 +11,7 @@ define('VFS_QUOTA_METRIC_GB', 4);
 /**
  * VFS API for abstracted file storage and access.
  *
- * $Horde: framework/VFS/VFS.php,v 1.69.4.13 2006/03/17 17:43:03 jan Exp $
+ * $Horde: framework/VFS/VFS.php,v 1.69.4.16 2006/08/07 00:30:14 chuck Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -193,6 +193,37 @@ class VFS {
         return PEAR::raiseError(_("Not supported."));
     }
 
+    /**
+     * Returns the size of a folder
+     *
+     * @since Horde 3.1
+     *
+     * @param string $path  The path to the folder.
+     * @param string $name  The name of the folder.
+     *
+     * @return integer  The size of the folder, in bytes, or PEAR_Error on
+     *                  failure.
+     */
+    function getFolderSize($path = null, $name = null)
+    {
+        $size = 0;
+        $root = ((!is_null($path)) ? $path . '/' : '') . $name;
+        $object_list = $this->listFolder($root, null, true, false, true);
+        foreach ($object_list as $key => $val) {
+            if (isset($val['subdirs'])) {
+                $size += $this->getFolderSize($root, $key);
+            } else {
+                $filesize = $this->size($root, $key);
+                if (is_a($filesize, 'PEAR_Error')) {
+                    return $filesize;
+                }
+                $size += $filesize;
+            }
+        }
+
+        return $size;
+    }
+
     /**
      * Retrieves a file from the VFS.
      *
@@ -427,7 +458,8 @@ class VFS {
     }
 
     /**
-     * Removes recursively all files and subfolders from the given folder.
+     * Recursively remove all files and subfolders from the given
+     * folder.
      *
      * @param string $path  The path of the folder to empty.
      *
@@ -457,6 +489,8 @@ class VFS {
                 return $result;
             }
         }
+
+        return true;
     }
 
     /**
@@ -652,50 +686,6 @@ class VFS {
         return strlen($string);
     }
 
-    /**
-     * Returns the size of a file.
-     *
-     * @abstract
-     * @since Horde 3.1
-     *
-     * @param string $path  The path to the file.
-     * @param string $name  The name of the file.
-     *
-     * @return integer  The size of the file, in bytes, or PEAR_Error on
-     *                  failure.
-     */
-    function getFileSize($path, $name)
-    {
-        return PEAR::raiseError(_("Not supported."));
-    }
-
-    /**
-     * Returns the size of a folder
-     *
-     * @since Horde 3.1
-     *
-     * @param string $path  The path to the folder.
-     * @param string $name  The name of the folder.
-     *
-     * @return integer  The size of the folder, in bytes, or PEAR_Error on
-     *                  failure.
-     */
-    function getFolderSize($path = null, $name = null)
-    {
-        $size = 0;
-        $root = ((!is_null($path)) ? $path . '/' : '') . $name;
-        $object_list = $this->listFolder($root, null, true, false, true);
-        foreach ($object_list as $key => $val) {
-            if (isset($val['subdirs'])) {
-                $size += $this->getFolderSize($root, $key);
-            } else {
-                $size += @$this->getFileSize($root, $key);
-            }
-        }
-
-        return $size;
-    }
-
     /**
      * Returns the size of the VFS item.
      *
@@ -764,13 +754,13 @@ class VFS {
     {
         if (empty($this->_params['vfs_quotalimit'])) {
             return PEAR::raiseError(_("No quota set."));
+        }
+
+        $usage = $this->getVFSSize();
+        if (is_a($usage, 'PEAR_Error')) {
+            return $usage;
         } else {
-            $usage = $this->getVFSSize();
-            if (is_a($usage, 'PEAR_Error')) {
-                 return $usage;
-            } else {
-                return array('usage' => $this->getVFSSize(), 'limit' => $this->_params['vfs_quotalimit']);
-            }
+            return array('usage' => $usage, 'limit' => $this->_params['vfs_quotalimit']);
         }
     }
 
@@ -858,7 +848,11 @@ class VFS {
             } else {
                 $filesize = strlen($data);
             }
-            if (($this->getVFSSize() + $filesize) > $this->_params['vfs_quotalimit']) {
+            $vfssize = $this->getVFSSize();
+            if (is_a($vfssize, 'PEAR_Error')) {
+                return $vfssize;
+            }
+            if (($vfssize + $filesize) > $this->_params['vfs_quotalimit']) {
                 return PEAR::raiseError(_("Unable to write VFS file, quota will be exceeded."));
             } elseif ($this->_vfsSize !== 0) {
                 $this->_vfsSize += $filesize;
@@ -882,9 +876,9 @@ class VFS {
     {
         if (($this->_params['vfs_quotalimit'] != -1) &&
             !empty($this->_vfsSize)) {
-            $filesize = $this->getFileSize($path, $name);
+            $filesize = $this->size($path, $name);
             if (is_a($filesize, 'PEAR_Error')) {
-                return PEAR::raiseError(_("Unable to read VFS file (getFileSize() failed)."));
+                return PEAR::raiseError(_("Unable to read VFS file (size() failed)."));
             }
             $this->_vfsSize -= $filesize;
         }
