@@ -5,9 +5,9 @@ require_once 'PEAR.php';
 /**
  * VFS API for abstracted creation of ISO (CD-ROM) filesystems.
  *
- * $Horde: framework/VFS_ISOWriter/ISOWriter.php,v 1.1.8.4 2005/07/03 05:52:03 selsky Exp $
+ * $Horde: framework/VFS_ISOWriter/ISOWriter.php,v 1.1.8.7 2006/01/01 21:28:43 jan Exp $
  *
- * Copyright 2004-2005 Cronosys, LLC <http://www.cronosys.com/>
+ * Copyright 2004-2006 Cronosys, LLC <http://www.cronosys.com/>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -98,8 +98,9 @@ class VFS_ISOWriter {
          * support it. */
         require_once dirname(__FILE__) . '/ISOWriter/mkisofs.php';
         if (VFS_ISOWriter_mkisofs::strategyAvailable()) {
-            return $ret = &new VFS_ISOWriter_mkisofs($sourceVfs, $targetVfs,
-                                                     $params);
+            $isowriter = &new VFS_ISOWriter_mkisofs($sourceVfs, $targetVfs,
+                                                    $params);
+            return $isowriter;
         }
 
         return PEAR::raiseError(_("No available strategy for making ISO images."));
