@@ -3,15 +3,14 @@
 /**
  * Encapsulate strategies for ability to write output to real file.
  *
- * $Horde: framework/VFS_ISOWriter/ISOWriter/RealOutputStrategy.php,v 1.1.8.1 2005/01/03 12:19:21 jan Exp $
+ * $Horde: framework/VFS_ISOWriter/ISOWriter/RealOutputStrategy.php,v 1.1.8.7 2006/01/01 21:28:43 jan Exp $
  *
- * Copyright 2004-2005 Cronosys, LLC <http://www.cronosys.com/>
+ * Copyright 2004-2006 Cronosys, LLC <http://www.cronosys.com/>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jason M. Felice <jfelice@cronosys.com>
- * @version $Revision: 1.1.8.1 $
  * @package VFS_ISO
  * @since   Horde 3.0
  */
@@ -20,14 +19,14 @@ class VFS_ISOWriter_RealOutputStrategy {
     /**
      * The VFS to which we will write the file.
      *
-     * @var object $_targetVfs
+     * @var VFS
      */
     var $_targetVfs;
 
     /**
      * Where to store the file in the VFS.
      *
-     * @var string $_targetFile
+     * @var string
      */
     var $_targetFile;
 
@@ -52,7 +51,7 @@ class VFS_ISOWriter_RealOutputStrategy {
      * @param string $targetFile        The path and filename of the target
      *                                  file within the VFS.
      * @return object   A concrete output strategy object or PEAR_Error on
-     *                  failure. 
+     *                  failure.
      */
     function &factory(&$targetVfs, $targetFile)
     {
@@ -66,11 +65,12 @@ class VFS_ISOWriter_RealOutputStrategy {
                       '.php';
         $class = 'VFS_ISOWriter_RealOutputStrategy_' . $method;
         if (!class_exists($class)) {
-            return PEAR::raiseError(sprintf(_("Could not load strategy '%s'."),
+            return PEAR::raiseError(sprintf(_("Could not load strategy \"%s\"."),
                                             $method));
         }
 
-        return $ret = &new $class($targetVfs, $targetFile);
+        $strategy = &new $class($targetVfs, $targetFile);
+        return $strategy;
     }
 
     /**
