@@ -9,7 +9,7 @@
  * 'apache', or 'www-data') MUST have read/write permission to the
  * directory you specify as the 'vfsroot'.
  *
- * $Horde: framework/VFS/VFS/file.php,v 1.63.4.18 2006/03/24 16:41:48 slusarz Exp $
+ * $Horde: framework/VFS/VFS/file.php,v 1.63.4.21 2006/05/31 04:50:02 slusarz Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -17,7 +17,6 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch
- * @since   Horde 2.2
  * @package VFS
  */
 class VFS_file extends VFS {
@@ -61,7 +60,11 @@ class VFS_file extends VFS {
      */
     function size($path, $name)
     {
-        return filesize($this->_getNativePath($path, $name));
+        $size = @filesize($this->_getNativePath($path, $name));
+        if ($size === false) {
+            return PEAR::raiseError(sprintf(_("Unable to check file size of \"%s/%s\"."), $path, $name));
+        }
+        return $size;
     }
 
     /**
@@ -198,8 +201,8 @@ class VFS_file extends VFS {
     function move($path, $name, $dest)
     {
         $orig = $this->_getNativePath($path, $name);
-        if (preg_match('|^' . preg_quote($orig) . '[$/]|', $dest)) {
-            return PEAR::raiseError(_("Can not move file(s) - destination is within source."));
+        if (preg_match('|^' . preg_quote($orig) . '/?$|', $dest)) {
+            return PEAR::raiseError(_("Cannot move file(s) - destination is within source."));
         }
 
         $fileCheck = $this->listFolder($dest, false);
@@ -228,8 +231,8 @@ class VFS_file extends VFS {
     function copy($path, $name, $dest)
     {
         $orig = $this->_getNativePath($path, $name);
-        if (preg_match('|^' . preg_quote($orig) . '[$/]|', $dest)) {
-            return PEAR::raiseError(_("Can not copy file(s) - source and destination are the same."));
+        if (preg_match('|^' . preg_quote($orig) . '/?$|', $dest)) {
+            return PEAR::raiseError(_("Cannot copy file(s) - source and destination are the same."));
         }
 
         $fileCheck = $this->listFolder($dest, false);
@@ -689,24 +692,4 @@ class VFS_file extends VFS {
         }
     }
 
-    /**
-     * Returns the size of a file.
-     *
-     * @since Horde 3.1
-     *
-     * @param string $path  The path to the file.
-     * @param string $name  The name of the file.
-     *
-     * @return integer  The size of the file, in bytes, or PEAR_Error on
-     *                  failure.
-     */
-    function getFileSize($path, $name)
-    {
-        $size = @filesize($this->_getNativePath($path, $name));
-        if ($size === false) {
-            return PEAR::raiseError(sprintf(_("Unable to check file size of \"%s/%s\"."), $path, $name));
-        }
-        return $size;
-    }
-
 }
