@@ -23,7 +23,7 @@
  *      'timeout'        If defined, use this value as the timeout for the
  *                       server.</pre>
  *
- * $Horde: framework/VFS/VFS/ftp.php,v 1.75.4.18 2006/03/24 16:41:49 slusarz Exp $
+ * $Horde: framework/VFS/VFS/ftp.php,v 1.75.4.21 2006/05/31 04:50:02 slusarz Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2002-2006 Michael Varghese <mike.varghese@ascellatech.com>
@@ -33,7 +33,6 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Michael Varghese <mike.varghese@ascellatech.com>
- * @since   Horde 2.2
  * @package VFS
  */
 class VFS_ftp extends VFS {
@@ -76,6 +75,31 @@ class VFS_ftp extends VFS {
      */
     var $_gids = array();
 
+    /**
+     * Returns the size of a file.
+     *
+     * @access public
+     *
+     * @param string $path  The path of the file.
+     * @param string $name  The filename.
+     *
+     * @return integer  The size of the file in bytes or PEAR_Error on
+     *                  failure.
+     */
+    function size($path, $name)
+    {
+        $conn = $this->_connect();
+        if (is_a($conn, 'PEAR_Error')) {
+            return $conn;
+        }
+
+        if (($size = @ftp_size($this->_stream, $this->_getPath($path, $name))) === false) {
+            return PEAR::raiseError(sprintf(_("Unable to check file size of \"%s\"."), $this->_getPath($path, $name)));
+        }
+
+        return $size;
+    }
+
     /**
      * Retrieves a file from the VFS.
      *
@@ -215,31 +239,6 @@ class VFS_ftp extends VFS {
         return true;
     }
 
-    /**
-     * Returns the size of a file.
-     *
-     * @access public
-     *
-     * @param string $path  The path of the file.
-     * @param string $name  The filename.
-     *
-     * @return integer  The size of the file in bytes or PEAR_Error on
-     *                  failure.
-     */
-    function getFileSize($path, $name)
-    {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
-        }
-
-        if (($size = @ftp_size($this->_stream, $this->_getPath($path, $name))) === false) {
-            return PEAR::raiseError(sprintf(_("Unable to check file size of \"%s\"."), $this->_getPath($path, $name)));
-        }
-
-        return $size;
-    }
-
     /**
      * Checks if a given item is a folder.
      *
@@ -672,8 +671,8 @@ class VFS_ftp extends VFS {
     function copy($path, $name, $dest)
     {
         $orig = $this->_getPath($path, $name);
-        if (preg_match('|^' . preg_quote($orig) . '[$/]|', $dest)) {
-            return PEAR::raiseError(_("Can not copy file(s) - source and destination are the same."));
+        if (preg_match('|^' . preg_quote($orig) . '/?$|', $dest)) {
+            return PEAR::raiseError(_("Cannot copy file(s) - source and destination are the same."));
         }
 
         $conn = $this->_connect();
@@ -748,8 +747,8 @@ class VFS_ftp extends VFS {
     function move($path, $name, $dest)
     {
         $orig = $this->_getPath($path, $name);
-        if (preg_match('|^' . preg_quote($orig) . '[$/]|', $dest)) {
-            return PEAR::raiseError(_("Can not move file(s) - destination is within source."));
+        if (preg_match('|^' . preg_quote($orig) . '/?$|', $dest)) {
+            return PEAR::raiseError(_("Cannot move file(s) - destination is within source."));
         }
 
         $conn = $this->_connect();
