@@ -46,7 +46,7 @@ define('VFS_FOLDER', 2);
  *    mssql.textsize = 0 ; zero to pass through
  * </pre>
  *
- * $Horde: framework/VFS/VFS/sql.php,v 1.85.4.24 2006/03/12 18:48:26 jan Exp $
+ * $Horde: framework/VFS/VFS/sql.php,v 1.85.4.26 2006/05/31 04:50:02 slusarz Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -54,7 +54,6 @@ define('VFS_FOLDER', 2);
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @since   Horde 2.2
  * @package VFS
  */
 class VFS_sql extends VFS {
@@ -81,9 +80,53 @@ class VFS_sql extends VFS {
             return $conn;
         }
 
-        return strlen($this->_readBlob($this->_params['table'], 'vfs_data',
-                                       array('vfs_path' => $this->_convertPath($path),
-                                             'vfs_name' => $name)));
+        $length_op = $this->_getFileSizeOp();
+        $sql = sprintf(
+            'SELECT %s(vfs_data) FROM %s WHERE vfs_path = ? AND vfs_name = ?',
+            $length_op,
+            $this->_params['table']
+        );
+        $values = array($this->_convertPath($path), $name);
+        $this->log($sql, PEAR_LOG_DEBUG);
+        $size = $this->_db->getOne($sql, $values);
+
+        if (is_null($size)) {
+            return PEAR::raiseError(sprintf(_("Unable to check file size of \"%s/%s\"."), $path, $name));
+        }
+
+        return $size;
+    }
+
+    /**
+     * Returns the size of a file.
+     *
+     * @access public
+     *
+     * @param string $path  The path of the file.
+     * @param string $name  The filename.
+     *
+     * @return integer  The size of the folder in bytes or PEAR_Error on
+     *                  failure.
+     */
+    function getFolderSize($path = null, $name = null)
+    {
+        $conn = $this->_connect();
+        if (is_a($conn, 'PEAR_Error')) {
+            return $conn;
+        }
+
+        $where = (is_null($path)) ? null : sprintf('WHERE vfs_path = %s', ((!strlen($path)) ? '""' : $this->_db->quote($this->_convertPath($path))));
+        $length_op = $this->_getFileSizeOp();
+        $sql = sprintf(
+            'SELECT SUM(%s(vfs_data)) FROM %s %s',
+            $length_op,
+            $this->_params['table'],
+            $where
+        );
+        $this->log($sql, PEAR_LOG_DEBUG);
+        $size = $this->_db->getOne($sql);
+
+        return $size !== null ? $size : 0;
     }
 
     /**
@@ -468,9 +511,6 @@ class VFS_sql extends VFS {
 
         $path = $this->_convertPath($path);
 
-        $files = array();
-        $fileList = array();
-
         // Fix for Oracle not differentiating between '' and NULL.
         if (empty($path) && $this->_db->dbsyntax == 'oci8') {
             $where = 'vfs_path IS NULL';
@@ -478,15 +518,18 @@ class VFS_sql extends VFS {
             $where = 'vfs_path = ' . $this->_db->quote($path);
         }
 
-        $sql = sprintf('SELECT vfs_name, vfs_type, vfs_data, vfs_modified, vfs_owner FROM %s WHERE %s',
-                            $this->_params['table'],
-                            $where);
+        $length_op = $this->_getFileSizeOp();
+        $sql = sprintf('SELECT vfs_name, vfs_type, %s(vfs_data), vfs_modified, vfs_owner FROM %s WHERE %s',
+                       $length_op,
+                       $this->_params['table'],
+                       $where);
         $this->log($sql, PEAR_LOG_DEBUG);
         $fileList = $this->_db->getAll($sql);
         if (is_a($fileList, 'PEAR_Error')) {
             return $fileList;
         }
 
+        $files = array();
         foreach ($fileList as $line) {
             // Filter out dotfiles if they aren't wanted.
             if (!$dotfiles && substr($line[0], 0, 1) == '.') {
@@ -504,7 +547,7 @@ class VFS_sql extends VFS {
                     $file['type'] = VFS::strtolower($name[count($name) - 1]);
                 }
 
-                $file['size'] = VFS::strlen($line[2]);
+                $file['size'] = $line[2];
             } elseif ($line[1] == VFS_FOLDER) {
                 $file['type'] = '**dir';
                 $file['size'] = -1;
@@ -715,7 +758,7 @@ class VFS_sql extends VFS {
                 return $error;
             }
 
-            
+
             // Set DB portability options.
             switch ($this->_db->phptype) {
             case 'mssql':
@@ -990,109 +1033,23 @@ class VFS_sql extends VFS {
         return $path;
     }
 
-    /**
-     * Returns the size of a file.
-     *
-     * @access public
-     *
-     * @param string $path  The path of the file.
-     * @param string $name  The filename.
-     *
-     * @return integer  The size of the file in bytes or PEAR_Error on
-     *                  failure.
-     */
-    function getFileSize($path, $name)
+    function _getFileSizeOp()
     {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
-        }
-
         switch ($this->_db->dbsyntax) {
         case 'mysql':
-            $length = 'LENGTH';
-            break;
+            return 'LENGTH';
 
         case 'oci8':
-            $length = 'LENGTHB';
-            break;
+            return 'LENGTHB';
 
         case 'mssql':
         case 'sybase':
-            $length = 'DATALENGTH';
-            break;
+            return 'DATALENGTH';
 
         case 'pgsql':
         default:
-            $length = 'OCTET_LENGTH';
+            return 'OCTET_LENGTH';
         }
-	
-        $sql = sprintf(
-            'SELECT %s(vfs_data) FROM %s WHERE vfs_path = ? AND vfs_name = ?',
-            $length,
-            $this->_params['table']
-        );
-        $values = array($this->_convertPath($path), $name);
-        $this->log($sql, PEAR_LOG_DEBUG);
-        $size = $this->_db->getOne($sql, $values);
-
-        if (is_null($size)) {
-            return PEAR::raiseError(sprintf(_("Unable to check file size of \"%s/%s\"."), $path, $name));
-        }
-
-        return $size;
-    }
-
-    /**
-     * Returns the size of a file.
-     *
-     * @access public
-     *
-     * @param string $path  The path of the file.
-     * @param string $name  The filename.
-     *
-     * @return integer  The size of the folder in bytes or PEAR_Error on
-     *                  failure.
-     */
-    function getFolderSize($path = null, $name = null)
-    {
-        $conn = $this->_connect();
-        if (is_a($conn, 'PEAR_Error')) {
-            return $conn;
-        }
-
-        $where = (is_null($path)) ? null : sprintf('WHERE vfs_path = %s', ((empty($path)) ? '""' : $this->_db->quote($this->_convertPath($path))));
-
-        switch ($this->_db->dbsyntax) {
-        case 'mysql':
-            $length = 'LENGTH';
-            break;
-
-        case 'oci8':
-            $length = 'LENGTHB';
-            break;
-
-        case 'mssql':
-        case 'sybase':
-            $length = 'DATALENGTH';
-            break;
-
-        case 'pgsql':
-        default:
-            $length = 'OCTET_LENGTH';
-        }
-
-
-        $sql = sprintf(
-            'SELECT SUM(%s(vfs_data)) FROM %s %s',
-            $length,
-            $this->_params['table'],
-            $where
-        );
-        $this->log($sql, PEAR_LOG_DEBUG);
-        $size = $this->_db->getOne($sql);
-
-        return ((!is_null($size)) ? $size : 0);
     }
 
 }
