@@ -5,7 +5,7 @@ include_once 'XML/WBXML/DTD/SyncMLMetInf.php';
 include_once 'XML/WBXML/DTD/SyncMLDevInf.php';
 
 /**
- * $Horde: framework/XML_WBXML/WBXML/DTDManager.php,v 1.3.12.8 2006/03/13 15:50:23 jan Exp $
+ * $Horde: framework/XML_WBXML/WBXML/DTDManager.php,v 1.3.12.11 2006/05/01 12:05:15 jan Exp $
  *
  * Copyright 2003-2006 Anthony Mills <amills@pyramid6.com>
  *
@@ -19,9 +19,18 @@ include_once 'XML/WBXML/DTD/SyncMLDevInf.php';
  */
 class XML_WBXML_DTDManager {
 
+    /**
+     * @var array
+     */
     var $_strDTD = array();
+
+    /**
+     * @var array
+     */
     var $_strDTDURI = array();
 
+    /**
+     */
     function XML_WBXML_DTDManager()
     {
         $this->registerDTD('-//SYNCML//DTD SyncML 1.0//EN', 'syncml:syncml1.0', new XML_WBXML_DTD_SyncML(0));
@@ -34,21 +43,49 @@ class XML_WBXML_DTDManager {
         $this->registerDTD('-//SYNCML//DTD DevInf 1.1//EN', 'syncml:devinf1.1', new XML_WBXML_DTD_SyncMLDevInf(1));
     }
 
+    /**
+     */
     function &getInstance($publicIdentifier)
     {
-        $dtd = isset($this->_strDTD[$publicIdentifier]) ? &$this->_strDTD[$publicIdentifier] : null;
+        $publicIdentifier = strtolower($publicIdentifier);
+        if (isset($this->_strDTD[$publicIdentifier])) {
+            $dtd = &$this->_strDTD[$publicIdentifier];
+        } else {
+            $dtd = null;
+        }
         return $dtd;
     }
 
+    /**
+     */
     function &getInstanceURI($uri)
     {
         $uri = strtolower($uri);
-        $dtd = isset($this->_strDTDURI[$uri]) ? &$this->_strDTDURI[$uri] : null;
+
+        // some manual hacks:
+        if ($uri == 'syncml:syncml') {
+            $uri = 'syncml:syncml1.0';
+        }
+        if ($uri == 'syncml:metinf') {
+            $uri = 'syncml:metinf1.0';
+        }
+        if ($uri == 'syncml:devinf') {
+            $uri = 'syncml:devinf1.0';
+        }
+
+        if (isset($this->_strDTDURI[$uri])) {
+            $dtd = &$this->_strDTDURI[$uri];
+        } else {
+            $dtd = null;
+        }
         return $dtd;
     }
 
+    /**
+     */
     function registerDTD($publicIdentifier, $uri, &$dtd)
     {
+        $publicIdentifier = strtolower($publicIdentifier);
         $dtd->setDPI($publicIdentifier);
 
         $this->_strDTD[$publicIdentifier] = $dtd;
