@@ -10,9 +10,9 @@
  * avoid an infinite loop on the Horde login page. You'll need to do
  * it yourself in framework-level pages.
  *
- * $Horde: horde/lib/base.php,v 1.40.10.1 2005/01/03 12:25:41 jan Exp $
+ * $Horde: horde/lib/base.php,v 1.40.10.3 2006/01/01 21:29:05 jan Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -28,14 +28,17 @@ if (!defined('HORDE_BASE')) {
 require_once HORDE_BASE . '/lib/core.php';
 
 // Registry.
-if (Util::nonInputVar('session_control') == 'none') {
+$session_control = Util::nonInputVar('session_control');
+if ($session_control == 'none') {
     $registry = &Registry::singleton(HORDE_SESSION_NONE);
+} elseif ($session_control == 'readonly') {
+    $registry = &Registry::singleton(HORDE_SESSION_READONLY);
 } else {
     $registry = &Registry::singleton();
 }
 if (is_a(($pushed = $registry->pushApp('horde', !defined('AUTH_HANDLER'))), 'PEAR_Error')) {
     if ($pushed->getCode() == 'permission_denied') {
-        Horde::authenticationFailureRedirect(); 
+        Horde::authenticationFailureRedirect();
     }
     Horde::fatal($pushed, __FILE__, __LINE__, false);
 }
