@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: horde/lib/prefs.php,v 1.19.4.4 2005/02/16 21:55:30 jan Exp $
+ * $Horde: horde/lib/prefs.php,v 1.19.4.10 2006/01/01 21:29:05 jan Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -41,12 +41,19 @@ function handle_categorymanagement($updated)
     $cManager = &new Prefs_CategoryManager();
 
     /* Always save colors of all categories. */
-    $colors = array_unique(array_merge($cManager->get(), array_keys($cManager->colors())));
-    foreach ($colors as $category) {
+    $colors = array();
+    $categories = $cManager->get();
+    foreach ($categories as $category) {
         if ($color = Util::getFormData('color_' . base64_encode($category))) {
             $colors[$category] = $color;
         }
     }
+    if ($color = Util::getFormData('color_' . base64_encode('_default_'))) {
+        $colors['_default_'] = $color;
+    }
+    if ($color = Util::getFormData('color_' . base64_encode('_unfiled_'))) {
+        $colors['_unfiled_'] = $color;
+    }
     $cManager->setColors($colors);
 
     $action = Util::getFormData('cAction');
@@ -75,15 +82,16 @@ function handle_categorymanagement($updated)
  */
 function prefs_callback()
 {
-    global $prefs, $registry, $notification;
+    global $prefs, $registry, $notification, $nls;
 
-    if ($prefs->isDirty('language')) {
-        NLS::setLang($prefs->getValue('language'));
-        NLS::setTextdomain($registry->getApp(), $registry->get('fileroot') . '/locale', NLS::getCharset());
-        String::setDefaultCharset(NLS::getCharset());
-    }
+    if ($prefs->isDirty('language') ||
+        $prefs->isDirty('show_sidebar')) {
+        if ($prefs->isDirty('language')) {
+            NLS::setLang($prefs->getValue('language'));
+            NLS::setTextdomain($registry->getApp(), $registry->get('fileroot') . '/locale', NLS::getCharset());
+            String::setDefaultCharset(NLS::getCharset());
+        }
 
-    if ($prefs->isDirty('language')) {
         $url = $registry->get('webroot', 'horde');
         if (substr($url, -1) != '/') {
             $url .= '/';
@@ -97,14 +105,15 @@ function prefs_callback()
     }
 
     if ($prefs->isDirty('theme') ||
-        $prefs->isDirty('menu_view')) {
+        $prefs->isDirty('menu_view') ||
+        $prefs->isDirty('menu_refresh_time')) {
         $notification->push('if (window.parent.frames.horde_menu) window.parent.frames.horde_menu.location.reload();', 'javascript');
     }
 }
 
 /* Assign variables for select lists. */
 if (!$prefs->isLocked('timezone')) {
-    $timezone_options = &$tz;
+    $timezone_options = $tz;
     array_unshift($timezone_options, _("Default"));
 }
 if (!$prefs->isLocked('initial_application')) {
