@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: horde/login.php,v 2.175 2004/12/08 16:28:17 chuck Exp $
+ * $Horde: horde/login.php,v 2.175.2.11 2006/01/16 15:57:53 jan Exp $
  *
- * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2004 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -30,12 +30,23 @@ $url_param = Util::getFormData('url');
 $ie_version = Util::getFormData('ie_version');
 
 if ($logout_reason) {
-    $login_screen = $auth->_getLoginScreen();
+    $login_screen = $auth->getLoginScreen();
+    if (Util::getFormData('nosidebar') &&
+        isset($GLOBALS['notification'])) {
+        $url = Auth::addLogoutParameters($login_screen);
+        if ($url_param) {
+            $url = Util::addParameter($url, 'url', $url_param);
+        }
+        $notification->push('window.parent.location.href = \'' . $url . '\';', 'javascript');
+        echo '<html><body>' . $GLOBALS['notification']->notify(array('listeners' => array('javascript'))) . '</body></html>';
+        exit;
+    }
+
     if (Util::removeParameter($login_screen, array('url', 'nocache')) !=
         Util::removeParameter(Horde::selfUrl(false, false, true), array('url', 'nocache'))) {
         $url = Auth::addLogoutParameters($login_screen);
         if ($url_param) {
-            $url = Util::addParameter($login_screen, 'url', $url_param);
+            $url = Util::addParameter($url, 'url', $url_param);
         }
         header('Location: ' . $url);
         exit;
@@ -45,16 +56,19 @@ if ($logout_reason) {
 
     $entry = sprintf('User %s [%s] logged out of Horde',
                      Auth::getAuth(), $_SERVER['REMOTE_ADDR']);
-    Horde::logMessage($entry, __FILE__, __LINE__, PEAR_LOG_INFO);
+    Horde::logMessage($entry, __FILE__, __LINE__, PEAR_LOG_NOTICE);
     Auth::clearAuth();
     @session_destroy();
 
-    /* FIXME: Add a redirect-on-logout setting and check for that
-     * here. */
-    // if () {
-    //     header('Location: ' . Horde::applicationUrl());
-    //     exit;
-    // }
+    /* Redirect the user on logout if redirection is enabled. */
+    if (!empty($conf['auth']['redirect_on_logout'])) {
+        $logout_url = $conf['auth']['redirect_on_logout'];
+        if (!isset($_COOKIE[session_name()])) {
+            $logout_url = Util::addParameter($logout_url, session_name(), session_id());
+        }
+        header('Location: ' . $logout_url);
+        exit;
+    }
 
     Horde::setupSessionHandler();
     @session_start();
@@ -73,7 +87,7 @@ if (isset($_POST['horde_user']) && isset($_POST['horde_pass'])) {
                             array('password' => Util::getPost('horde_pass')))) {
         $entry = sprintf('Login success for %s [%s] to Horde',
                          Auth::getAuth(), $_SERVER['REMOTE_ADDR']);
-        Horde::logMessage($entry, __FILE__, __LINE__, PEAR_LOG_INFO);
+        Horde::logMessage($entry, __FILE__, __LINE__, PEAR_LOG_NOTICE);
 
         if ($ie_version) {
             $browser->setIEVersion($ie_version);
@@ -84,10 +98,17 @@ if (isset($_POST['horde_user']) && isset($_POST['horde_pass'])) {
             $horde_url = $registry->get('webroot', 'horde') . '/index.php';
             $horde_url = Util::addParameter($horde_url, 'url', $url);
         } else {
-            $horde_url = 'index.php';
+            $horde_url = Horde::url($registry->get('webroot', 'horde') . '/index.php');
         }
 
-        header('Refresh: 0; URL=' . Horde::applicationUrl($horde_url, true));
+        $url = Horde::applicationUrl($horde_url, true);
+        if ($browser->isBrowser('msie') &&
+            $conf['use_ssl'] == 3 &&
+            strlen($url) < 160) {
+            header('Refresh: 0; URL=' . $url);
+        } else {
+            header('Location: ' . $url);
+        }
         exit;
     } else {
         $entry = sprintf('FAILED LOGIN for %s [%s] to Horde',
@@ -122,14 +143,27 @@ if (Auth::isAuthenticated()) {
     exit;
 }
 
+/* Redirect the user if an alternate login page has been specified. */
+if (!empty($conf['auth']['alternate_login'])) {
+    $url = Auth::addLogoutParameters($conf['auth']['alternate_login']);
+    if (!isset($_COOKIE[session_name()])) {
+        $url = Util::addParameter($url, session_name(), session_id(), false);
+    }
+    if ($url_param) {
+        $url = Util::addParameter($url, 'url', $url_param, false);
+    }
+    header('Location: ' . $url);
+    exit;
+}
+
 $login_screen = $auth->_getLoginScreen();
 if (Util::removeParameter($login_screen, array('url', 'nocache')) !=
     Horde::selfUrl(false, false, true)) {
     if ($url_param) {
-        $login_screen = Util::addParameter($login_screen, 'url', $url_param);
+        $login_screen = Util::addParameter($login_screen, 'url', $url_param, false);
     }
     if ($ie_version) {
-        $login_screen = Util::addParameter($login_screen, 'ie_version', $ie_version);
+        $login_screen = Util::addParameter($login_screen, 'ie_version', $ie_version, false);
     }
     header('Location: ' . $login_screen);
     exit;
