@@ -1,5 +1,26 @@
 #!/usr/bin/php
 <?php
+/**
+ * This script creates softlinks to the library files you retrieved from
+ * the CVS "framework" module.
+ *
+ * It creates the same directory structure the packages would have if they
+ * were installed with "pear install package.xml".
+ * For creating this structure it uses the information given in the
+ * package.xml files inside each package directory.
+ *
+ * $Horde: horde/scripts/create-symlinks.php,v 1.14.10.7 2006/01/01 21:29:09 jan Exp $
+ *
+ * Copyright 2002 Wolfram Kriesing <wolfram@kriesing.de>
+ * Copyright 2003-2006 Jan Schneider <jan@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
+ * @author Wolfram Kriesing <wolfram@kriesing.de>
+ * @author Jan Schneider <jan@horde.org>
+ * @since Horde 3.0
+ */
 
 // Find the base file path of Horde.
 @define('HORDE_BASE', dirname(__FILE__) . '/..');
@@ -15,30 +36,8 @@ $srcDir = HORDE_BASE . '/framework';
 // after creating the links.
 $destDir = HORDE_BASE . '/libs';
 
-/**
- * This script creates softlinks to the library files you retrieved from
- * the CVS "framework" module.
- *
- * It creates the same directory structure the packages would have if they
- * were installed with "pear install package.xml".
- * For creating this structure it uses the information given in the
- * package.xml files inside each package directory.
- *
- * $Horde: horde/scripts/create-symlinks.php,v 1.14.10.3 2005/01/03 12:25:44 jan Exp $
- *
- * Copyright 2002 Wolfram Kriesing <wolfram@kriesing.de>
- * Copyright 2003-2005 Jan Schneider <jan@horde.org>
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
- *
- * @author Wolfram Kriesing <wolfram@kriesing.de>
- * @author Jan Schneider <jan@horde.org>
- * @version $Revision: 1.14.10.3 $
- * @since Horde 3.0
- */
-
 $copy = false;
+
 if (isset($argv)) {
     /* Get rid of the first arg which is the script name. */
     array_shift($argv);
@@ -149,6 +148,7 @@ class Linker {
             if ($baseInstallDir != '/') {
                 $this->_baseInstallDir .= '/' . $baseInstallDir;
             }
+            $this->_baseInstallDir = preg_replace('|/+|', '/', $this->_baseInstallDir);
 
             if (!is_dir($this->_baseInstallDir)) {
                 require_once 'System.php';
@@ -221,11 +221,29 @@ class Linker {
         if ($this->_copy) {
             $cmd = "cp {$this->_srcDir}$dir/$filename {$this->_baseInstallDir}$dir/$filename";
         } else {
-            $cmd = "ln -sf {$this->_srcDir}$dir/$filename {$this->_baseInstallDir}$dir/$filename";
+            $parent = $this->_findCommonParent($this->_srcDir . $dir,
+                                               $this->_baseInstallDir . $dir);
+            $dirs = substr_count(substr($this->_baseInstallDir . $dir,
+                                        strlen($parent)),
+                                 '/');
+            $src = str_repeat('../', $dirs) .
+                substr($this->_srcDir . $dir, strlen($parent) + 1);
+            $cmd = "ln -sf $src/$filename {$this->_baseInstallDir}$dir/$filename";
         }
         exec($cmd);
     }
 
+    function _findCommonParent($a, $b)
+    {
+        for ($common = '', $lastpos = 0, $pos = strpos($a, '/', 1);
+             $pos !== false && strpos($b, substr($a, 0, $pos)) === 0;
+             $pos = strpos($a, '/', $pos + 1)) {
+            $common .= substr($a, $lastpos, $pos - $lastpos);
+            $lastpos = $pos;
+        }
+        return $common;
+    }
+
 }
 
 function print_usage($message = '') {
