@@ -1,4 +1,4 @@
--- $Horde: horde/scripts/sql/horde_datatree.mysql.sql,v 1.1 2004/09/18 17:20:59 chuck Exp $
+-- $Horde: horde/scripts/sql/horde_datatree.mysql.sql,v 1.1.10.1 2006/05/22 21:27:33 jan Exp $
 
 CREATE TABLE horde_datatree (
        datatree_id INT NOT NULL,
@@ -9,7 +9,6 @@ CREATE TABLE horde_datatree (
        datatree_order INT,
        datatree_data TEXT,
        datatree_serialized SMALLINT DEFAULT 0 NOT NULL,
-       datatree_updated TIMESTAMP,
        PRIMARY KEY (datatree_id)
 );
 
