@@ -1,4 +1,4 @@
--- $Horde: horde/scripts/sql/horde_prefs.sql,v 1.2 2004/09/21 03:34:06 chuck Exp $
+-- $Horde: horde/scripts/sql/horde_prefs.sql,v 1.2.10.1 2006/06/29 16:29:03 jan Exp $
 
 CREATE TABLE horde_prefs (
     pref_uid        VARCHAR(255) NOT NULL,
@@ -9,4 +9,7 @@ CREATE TABLE horde_prefs (
     PRIMARY KEY (pref_uid, pref_scope, pref_name)
 );
 
+CREATE INDEX pref_uid_idx ON horde_prefs (pref_uid);
+CREATE INDEX pref_scope_idx ON horde_prefs (pref_scope);
+
 GRANT SELECT, INSERT, UPDATE, DELETE ON horde_prefs TO horde;
