@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/services/javascript.php,v 1.37 2004/10/23 04:37:00 chuck Exp $
+ * $Horde: horde/services/javascript.php,v 1.37.10.4 2006/01/01 21:29:10 jan Exp $
  *
- * Copyright 2000-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 2000-2006 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -29,9 +29,7 @@ if (!empty($app) && !empty($file) && strpos($file, '..') === false) {
              * don't include base.php in this file. */
             Horde::compressOutput();
 
-            $mod_gmt = gmdate('D, d M Y H:i:s', filemtime($script_file)) . ' GMT';
-            header('Last-Modified: ' . $mod_gmt);
-            header('Cache-Control: public, max-age=86400');
+            header('Cache-Control: no-cache');
             header('Content-Type: text/javascript');
         }
 
