@@ -1,14 +1,14 @@
 <?php
 /*
- * $Horde: horde/services/keyboard.php,v 1.13.10.1 2005/01/03 12:25:45 jan Exp $
+ * $Horde: horde/services/keyboard.php,v 1.13.10.3 2006/01/01 21:29:10 jan Exp $
  *
- * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
-define('HORDE_BASE', dirname(__FILE__) . '/..');
+@define('HORDE_BASE', dirname(__FILE__) . '/..');
 require_once HORDE_BASE . '/lib/base.php';
 
 $title = _("Special Character Input");
@@ -16,13 +16,13 @@ require HORDE_TEMPLATES . '/common-header.inc';
 
 ?>
 
-<script language="Javascript" type="text/javascript">
+<script type="text/javascript">
 
 var target;
 
 function handleListChange(theList) {
     var numSelected = theList.selectedIndex;
-    
+
     if (numSelected != 0) {
         document.characters.textbox.value += theList.options[numSelected].value;
         theList.selectedIndex = 0;
@@ -31,15 +31,15 @@ function handleListChange(theList) {
 </script>
 
 <form name="characters">
-<table border="0" cellspacing="0" cellpadding="2">
+<table cellspacing="0">
   <tr>
-    <td align="left" class="item">
+    <td class="item leftAlign">
       <p><?php echo _("Select the characters you need from the boxes below. You can then copy and paste them from the text area.") ?></p>
     </td>
   </tr>
   <tr>
-    <td align="left">
-      <table border="0" cellspacing="0" cellpadding="0">
+    <td class="leftAlign">
+      <table cellspacing="0">
         <tr>
           <td align="center">
             <select name="a" onchange="handleListChange(this)">
@@ -58,7 +58,7 @@ function handleListChange(theList) {
               <option value="&#229;"> &#229; </option>
             </select>
           </td>
-          <td align="center"> 
+          <td align="center">
             <select name="e" onchange="handleListChange(this)">
               <option value="e" selected> e </option>
               <option value="&#200;"> &#200; </option>
@@ -71,7 +71,7 @@ function handleListChange(theList) {
               <option value="&#235;"> &#235; </option>
             </select>
           </td>
-          <td align="center"> 
+          <td align="center">
             <select name="i" onchange="handleListChange(this)">
               <option value="i" selected> i </option>
               <option value="&#204;"> &#204; </option>
@@ -84,7 +84,7 @@ function handleListChange(theList) {
               <option value="&#239;"> &#207; </option>
             </select>
           </td>
-          <td align="center"> 
+          <td align="center">
             <select name="o" onchange="handleListChange(this)">
               <option value="o" selected> o </option>
               <option value="&#210;"> &#210; </option>
@@ -99,7 +99,7 @@ function handleListChange(theList) {
               <option value="&#246;"> &#246; </option>
             </select>
           </td>
-          <td align="center"> 
+          <td align="center">
             <select name="u" onchange="handleListChange(this)">
               <option value="u" selected> u </option>
               <option value="&#217;"> &#217; </option>
@@ -112,7 +112,7 @@ function handleListChange(theList) {
               <option value="&#252;"> &#252; </option>
             </select>
           </td>
-          <td align="center"> 
+          <td align="center">
             <select name="Other" onchange="handleListChange(this)">
               <option value="misc" selected> <?php echo _("Other"); ?></option>
               <option value="&#162;"> &#162; </option>
@@ -137,7 +137,7 @@ function handleListChange(theList) {
     </td>
   </tr>
   <tr>
-    <td align="left" class="fixed">
+    <td class="fixed leftAlign">
       <textarea rows="4" cols="25" class="fixed" name="textbox"></textarea>
     </td>
   </tr>
