@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/services/obrowser/index.php,v 1.6.10.6.2.1 2008/06/13 21:50:17 chuck Exp $
+ * $Horde: horde/services/obrowser/index.php,v 1.6.10.5 2006/01/01 21:29:14 jan Exp $
  *
- * Copyright 2004-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 2004-2006 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -90,10 +90,10 @@ foreach ($list as $path => $values) {
     if (!empty($values['browseable'])) {
         $url = Horde::applicationUrl('services/obrowser/');
         $url = Util::addParameter($url, 'path', $path);
-        $row['name'] = Horde::link($url) . htmlspecialchars($values['name']) . '</a>';
+        $row['name'] = Horde::link($url) . $values['name'] . '</a>';
     } else {
         $js = "return chooseObject('" . addslashes($path) . "');";
-        $row['name'] = Horde::link('#', sprintf(_("Choose %s"), $values['name']), '', '', $js) . htmlspecialchars($values['name']) . '</a>';
+        $row['name'] = Horde::link('#', sprintf(_("Choose %s"), $values['name']), '', '', $js) . $values['name'] . '</a>';
     }
 
     $rows[] = $row;
