@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/services/shares/edit.php,v 1.26.10.7 2006/01/01 21:29:15 jan Exp $
+ * $Horde: horde/services/shares/edit.php,v 1.26.10.8 2006/05/01 21:16:41 chuck Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -250,7 +250,7 @@ if ($auth->hasCapability('list')) {
     $userList = array();
 }
 
-$groupList = $groups->listGroups();
+$groupList = $groups->getGroupMemberships(Auth::getAuth(), true);
 if (is_a($groupList, 'PEAR_Error')) {
     Horde::logMessage($groupList, __FILE__, __LINE__, PEAR_LOG_NOTICE);
     $groupList = array();
