@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/signup.php,v 1.17.10.10 2007/01/02 13:42:40 jan Exp $
+ * $Horde: horde/signup.php,v 1.17.10.8 2006/01/01 21:28:04 jan Exp $
  *
- * Copyright 2002-2007 Marko Djukic <marko@oblo.com>
+ * Copyright 2002-2006 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -24,8 +24,8 @@ if ($conf['signup']['allow'] !== true ||
     exit;
 }
 
-$vars = Variables::getDefaultVariables();
-$signup = new Auth_Signup();
+$vars = &Variables::getDefaultVariables();
+$signup = &Auth_Signup::singleton();
 $renderer = &new Horde_Form_Renderer();
 
 $formsignup = &Horde_Form::singleton('HordeSignupForm', $vars);
