@@ -6,12 +6,11 @@
  * of listening for keypresses and mapping them to the callback functions, or
  * doing nothing if no callback is set.
  *
- * $Horde: horde/templates/javascript/keybindings.js,v 1.5 2004/11/29 14:50:27 jan Exp $
+ * $Horde: horde/templates/javascript/keybindings.js,v 1.5.4.6 2006/03/24 16:05:24 chuck Exp $
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @version $Revision: 1.5 $
  * @package Horde
  */
 
@@ -25,11 +24,11 @@ var _keyMap = new Array();
 /**
  * Set up the keypress listener.
  */
-if (window.document.captureEvents != null) {
-    window.document.captureEvents(Event.KEYPRESS);
-    window.document.onkeypress = keyHandler;
+if (typeof document.captureEvents != 'undefined') {
+    document.captureEvents(Event.KEYPRESS);
+    document.onkeypress = keyHandler;
 } else {
-    window.document.onkeydown = keyHandler;
+    document.onkeydown = keyHandler;
 }
 
 /**
@@ -44,16 +43,20 @@ if (window.document.captureEvents != null) {
 function setKeybinding(key, callback)
 {
     if (typeof _keyMap[key] == 'undefined') {
-        _keyMap[key] = new Array();
+        _keyMap[key] = [];
     }
 
-    _keyMap[key][_keyMap[key].length] = callback;
+    if (typeof callback == 'function') {
+        _keyMap[key].push(callback);
+    } else {
+        _keyMap[key].push(new Function('e', 'key', callback + '(e, key);'));
+    }
 }
 
 /**
- * Invoked by the JavaScript event model when a key is pressed. Gets the
- * keycode (attempts to handle all browsers) and looks to see if we have a
- * keybinding defined for that key. If so, eval() it.
+ * Invoked by the JavaScript event model when a key is pressed. Gets
+ * the keycode (attempts to handle all browsers) and looks to see if
+ * we have a handler defined for that key. If so, call it.
  *
  * @param e  The event to handle. Should be a keypress.
  */
@@ -61,23 +64,23 @@ function keyHandler(e)
 {
     var e = e || window.event;
 
-    /* Look in all the various places we might have to check for the
-     * keycode. */
-    if (document.layers) {
-        key = e.which;
-    } else {
+    if (e.keyCode) {
         key = e.keyCode;
+    } else if (e.which) {
+        key = e.which;
     }
 
-    /* If there's a keybinding defined for the key that was pressed, eval()
+    /* If there's a handler defined for the key that was pressed, call
      * it, passing in the keycode and the event. */
     if (_keyMap[key]) {
-        for (var i = 0; i < _keyMap[key].length; i++) {
-            if (eval(_keyMap[key][i] + '(e, ' + key + ');')) {
+        for (var i = 0; i < _keyMap[key].length; ++i) {
+            if (_keyMap[key][i](e, key)) {
                 e.returnValue = false;
-<?php if ($GLOBALS['browser']->isBrowser('mozilla')): ?>
-                e.preventDefault();
-<?php endif; ?>
+                if (typeof e.preventDefault == 'function') {
+                    e.preventDefault();
+                } else {
+                    e.returnValue = true;
+                }
                 break;
             }
         }
