@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/test.php,v 1.122.6.16 2006/01/01 21:28:04 jan Exp $
+ * $Horde: horde/test.php,v 1.122.6.17 2006/06/10 23:16:51 chuck Exp $
  *
  * Copyright 2002-2006 Brent J. Nordquist <bjn@horde.org>
  * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
@@ -250,12 +250,12 @@ if (!empty($_GET['mode'])) {
         exit;
 
     case 'phpinfo':
-        echo '<a href="' . $url . '?mode=test">&lt;&lt; Back to test.php</a>';
+        echo '<a href="' . htmlspecialchars($url) . '?mode=test">&lt;&lt; Back to test.php</a>';
         phpinfo();
         exit;
 
     case 'filetest':
-        echo '<a href="' . $url . '?mode=test">&lt;&lt; Back to test.php</a>';
+        echo '<a href="' . htmlspecialchars($url) . '?mode=test">&lt;&lt; Back to test.php</a>';
         ?>
         <html>
         <body bgcolor="white" text="black">
